@@ -1,7 +1,7 @@
 <?php
 /**
  * A few constants that might be needed during LocalSettings.php
- * @package MediaWiki
+ * @file
  */
 
 /**
@@ -52,8 +52,8 @@ define('NS_USER', 2);
 define('NS_USER_TALK', 3);
 define('NS_PROJECT', 4);
 define('NS_PROJECT_TALK', 5);
-define('NS_IMAGE', 6);
-define('NS_IMAGE_TALK', 7);
+define('NS_FILE', 6);
+define('NS_FILE_TALK', 7);
 define('NS_MEDIAWIKI', 8);
 define('NS_MEDIAWIKI_TALK', 9);
 define('NS_TEMPLATE', 10);
@@ -62,6 +62,16 @@ define('NS_HELP', 12);
 define('NS_HELP_TALK', 13);
 define('NS_CATEGORY', 14);
 define('NS_CATEGORY_TALK', 15);
+/**
+ * NS_IMAGE and NS_IMAGE_TALK are the pre-v1.14 names for NS_FILE and
+ * NS_FILE_TALK respectively, and are kept for compatibility.
+ *
+ * When writing code that should be compatible with older MediaWiki
+ * versions, either stick to the old names or define the new constants
+ * yourself, if they're not defined already.
+ */
+define('NS_IMAGE', NS_FILE);
+define('NS_IMAGE_TALK', NS_FILE_TALK);
 /**#@-*/
 
 /**
@@ -85,30 +95,6 @@ define( 'MW_MATH_MODERN', 4 );
 define( 'MW_MATH_MATHML', 5 );
 /**#@-*/
 
-/**
- * User rights list
- * @deprecated
- */
-$wgAvailableRights = array(
-	'block',
-	'bot',
-	'createaccount',
-	'delete',
-	'edit',
-	'editinterface',
-	'import',
-	'importupload',
-	'move',
-	'patrol',
-	'protect',
-	'read',
-	'rollback',
-	'siteadmin',
-	'unwatchedpages',
-	'upload',
-	'userrights',
-);
-
 /**#@+
  * Cache type
  */
@@ -189,15 +175,15 @@ define( 'RC_MOVE_OVER_REDIRECT', 4);
  */
 define( 'EDIT_NEW', 1 );
 define( 'EDIT_UPDATE', 2 );
-define( 'EDIT_MINOR', 4 ); 
+define( 'EDIT_MINOR', 4 );
 define( 'EDIT_SUPPRESS_RC', 8 );
 define( 'EDIT_FORCE_BOT', 16 );
 define( 'EDIT_DEFER_UPDATES', 32 );
 define( 'EDIT_AUTOSUMMARY', 64 );
 /**#@-*/
 
-/** 
- * Flags for Database::makeList() 
+/**
+ * Flags for Database::makeList()
  * These are also available as Database class constants
  */
 define( 'LIST_COMMA', 0 );
@@ -206,5 +192,38 @@ define( 'LIST_SET', 2 );
 define( 'LIST_NAMES', 3);
 define( 'LIST_OR', 4);
 
+/**
+ * Unicode and normalisation related
+ */
+require_once dirname(__FILE__).'/normal/UtfNormalDefines.php';
 
-?>
+# Hook support constants
+define( 'MW_SUPPORTS_EDITFILTERMERGED', 1 );
+define( 'MW_SUPPORTS_PARSERFIRSTCALLINIT', 1 );
+
+# Allowed values for Parser::$mOutputType
+# Parameter to Parser::startExternalParse().
+define( 'OT_HTML', 1 );
+define( 'OT_WIKI', 2 );
+define( 'OT_PREPROCESS', 3 );
+define( 'OT_MSG' , 3 );  // b/c alias for OT_PREPROCESS
+
+# Flags for Parser::setFunctionHook
+define( 'SFH_NO_HASH', 1 );
+define( 'SFH_OBJECT_ARGS', 2 );
+
+# Flags for Parser::setLinkHook
+define( 'SLH_PATTERN', 1 );
+
+# Flags for Parser::replaceLinkHolders
+define( 'RLH_FOR_UPDATE', 1 );
+
+# Autopromote conditions (must be here and not in Autopromote.php, so that
+# they're loaded for DefaultSettings.php before AutoLoader.php)
+define( 'APCOND_EDITCOUNT', 1 );
+define( 'APCOND_AGE', 2 );
+define( 'APCOND_EMAILCONFIRMED', 3 );
+define( 'APCOND_INGROUPS', 4 );
+define( 'APCOND_ISIP', 5 );
+define( 'APCOND_IPINRANGE', 6 );
+define( 'APCOND_AGE_FROM_EDIT', 7 );
