@@ -2,33 +2,30 @@
 /**
  * SpecialPage: handling special pages and lists thereof.
  *
- * To add a special page in an extension, add to $wgSpecialPages either 
- * an object instance or an array containing the name and constructor 
- * parameters. The latter is preferred for performance reasons. 
+ * To add a special page in an extension, add to $wgSpecialPages either
+ * an object instance or an array containing the name and constructor
+ * parameters. The latter is preferred for performance reasons.
  *
- * The object instantiated must be either an instance of SpecialPage or a 
- * sub-class thereof. It must have an execute() method, which sends the HTML 
- * for the special page to $wgOut. The parent class has an execute() method 
- * which distributes the call to the historical global functions. Additionally, 
- * execute() also checks if the user has the necessary access privileges 
+ * The object instantiated must be either an instance of SpecialPage or a
+ * sub-class thereof. It must have an execute() method, which sends the HTML
+ * for the special page to $wgOut. The parent class has an execute() method
+ * which distributes the call to the historical global functions. Additionally,
+ * execute() also checks if the user has the necessary access privileges
  * and bails out if not.
  *
- * To add a core special page, use the similar static list in 
+ * To add a core special page, use the similar static list in
  * SpecialPage::$mList. To remove a core static special page at runtime, use
  * a SpecialPage_initList hook.
  *
- * @package MediaWiki
- * @subpackage SpecialPage
- */
-
-/**
- * @access private
+ * @file
+ * @ingroup SpecialPage
+ * @defgroup SpecialPage SpecialPage
  */
 
 /**
  * Parent special page class, also static functions for handling the special
- * page list
- * @package MediaWiki
+ * page list.
+ * @ingroup SpecialPage
  */
 class SpecialPage
 {
@@ -73,76 +70,122 @@ class SpecialPage
 	 * Query parameters that can be passed through redirects
 	 */
 	var $mAllowedRedirectParams = array();
-
+	/**
+	 * List of special pages, followed by parameters.
+	 * If the only parameter is a string, that is the page name.
+	 * Otherwise, it is an array. The format is one of:
+	 ** array( 'SpecialPage', name, right )
+	 ** array( 'IncludableSpecialPage', name, right, listed? )
+	 ** array( 'UnlistedSpecialPage', name, right )
+	 ** array( 'SpecialRedirectToSpecial', name, page to redirect to, special page param, ... )
+	 */
 	static public $mList = array(
-		'DoubleRedirects'           => array( 'SpecialPage', 'DoubleRedirects' ),
+		# Maintenance Reports
 		'BrokenRedirects'           => array( 'SpecialPage', 'BrokenRedirects' ),
-		'Disambiguations'           => array( 'SpecialPage', 'Disambiguations' ),
-
-		'Userlogin'                 => array( 'SpecialPage', 'Userlogin' ),
-		'Userlogout'                => array( 'UnlistedSpecialPage', 'Userlogout' ),
-		'Preferences'               => array( 'SpecialPage', 'Preferences' ),
-		'Watchlist'                 => array( 'SpecialPage', 'Watchlist' ),
-
-		'Recentchanges'             => array( 'IncludableSpecialPage', 'Recentchanges' ),
-		'Upload'                    => array( 'SpecialPage', 'Upload' ),
-		'Imagelist'                 => array( 'SpecialPage', 'Imagelist' ),
-		'Newimages'                 => array( 'IncludableSpecialPage', 'Newimages' ),
-		'Listusers'                 => array( 'SpecialPage', 'Listusers' ),
-		'Statistics'                => array( 'SpecialPage', 'Statistics' ),
-		'Randompage'                => array( 'SpecialPage', 'Randompage' ),
-		'Lonelypages'               => array( 'SpecialPage', 'Lonelypages' ),
-		'Uncategorizedpages'        => array( 'SpecialPage', 'Uncategorizedpages' ),
-		'Uncategorizedcategories'   => array( 'SpecialPage', 'Uncategorizedcategories' ),
-		'Uncategorizedimages'       => array( 'SpecialPage', 'Uncategorizedimages' ),
-		'Unusedcategories'          => array( 'SpecialPage', 'Unusedcategories' ),
-		'Unusedimages'              => array( 'SpecialPage', 'Unusedimages' ),
-		'Wantedpages'               => array( 'IncludableSpecialPage', 'Wantedpages' ),
-		'Wantedcategories'          => array( 'SpecialPage', 'Wantedcategories' ),
-		'Mostlinked'                => array( 'SpecialPage', 'Mostlinked' ),
-		'Mostlinkedcategories'      => array( 'SpecialPage', 'Mostlinkedcategories' ),
-		'Mostcategories'            => array( 'SpecialPage', 'Mostcategories' ),
-		'Mostimages'                => array( 'SpecialPage', 'Mostimages' ),
-		'Mostrevisions'             => array( 'SpecialPage', 'Mostrevisions' ),
-		'Shortpages'                => array( 'SpecialPage', 'Shortpages' ),
-		'Longpages'                 => array( 'SpecialPage', 'Longpages' ),
-		'Newpages'                  => array( 'IncludableSpecialPage', 'Newpages' ),
-		'Ancientpages'              => array( 'SpecialPage', 'Ancientpages' ),
 		'Deadendpages'              => array( 'SpecialPage', 'Deadendpages' ),
-		'Allpages'                  => array( 'IncludableSpecialPage', 'Allpages' ),
-		'Prefixindex'               => array( 'IncludableSpecialPage', 'Prefixindex' ) ,
-		'Ipblocklist'               => array( 'SpecialPage', 'Ipblocklist' ),
-		'Specialpages'              => array( 'UnlistedSpecialPage', 'Specialpages' ),
-		'Contributions'             => array( 'UnlistedSpecialPage', 'Contributions' ),
-		'Emailuser'                 => array( 'UnlistedSpecialPage', 'Emailuser' ),
-		'Whatlinkshere'             => array( 'UnlistedSpecialPage', 'Whatlinkshere' ),
-		'Recentchangeslinked'       => array( 'UnlistedSpecialPage', 'Recentchangeslinked' ),
-		'Movepage'                  => array( 'UnlistedSpecialPage', 'Movepage' ),
-		'Blockme'                   => array( 'UnlistedSpecialPage', 'Blockme' ),
-		'Resetpass'                 => array( 'UnlistedSpecialPage', 'Resetpass' ),
-		'Booksources'               => 'SpecialBookSources',
+		'DoubleRedirects'           => array( 'SpecialPage', 'DoubleRedirects' ),
+		'Longpages'                 => array( 'SpecialPage', 'Longpages' ),
+		'Ancientpages'              => array( 'SpecialPage', 'Ancientpages' ),
+		'Lonelypages'               => array( 'SpecialPage', 'Lonelypages' ),
+		'Fewestrevisions'           => array( 'SpecialPage', 'Fewestrevisions' ),
+		'Withoutinterwiki'          => array( 'SpecialPage', 'Withoutinterwiki' ),
+		'Protectedpages'            => array( 'SpecialPage', 'Protectedpages' ),
+		'Protectedtitles'           => array( 'SpecialPage', 'Protectedtitles' ),	
+		'Shortpages'                => array( 'SpecialPage', 'Shortpages' ),	
+		'Uncategorizedcategories'   => array( 'SpecialPage', 'Uncategorizedcategories' ),	
+		'Uncategorizedimages'       => array( 'SpecialPage', 'Uncategorizedimages' ),	
+		'Uncategorizedpages'        => array( 'SpecialPage', 'Uncategorizedpages' ),	
+		'Uncategorizedtemplates'    => array( 'SpecialPage', 'Uncategorizedtemplates' ),
+		'Unusedcategories'          => array( 'SpecialPage', 'Unusedcategories' ),
+		'Unusedimages'              => array( 'SpecialPage', 'Unusedimages' ),		
+		'Unusedtemplates'           => array( 'SpecialPage', 'Unusedtemplates' ),
+		'Unwatchedpages'            => array( 'SpecialPage', 'Unwatchedpages', 'unwatchedpages' ),	
+		'Wantedcategories'          => array( 'SpecialPage', 'Wantedcategories' ),
+		'Wantedfiles'               => array( 'SpecialPage', 'Wantedfiles' ),
+		'Wantedpages'               => array( 'IncludableSpecialPage', 'Wantedpages' ),
+		'Wantedtemplates'           => array( 'SpecialPage', 'Wantedtemplates' ),
+
+		# List of pages
+		'Allpages'                  => 'SpecialAllpages',		
+		'Prefixindex'               => 'SpecialPrefixindex',		
 		'Categories'                => array( 'SpecialPage', 'Categories' ),
-		'Export'                    => array( 'SpecialPage', 'Export' ),
-		'Version'                   => array( 'SpecialPage', 'Version' ),
-		'Allmessages'               => array( 'SpecialPage', 'Allmessages' ),
-		'Log'                       => array( 'SpecialPage', 'Log' ),
+		'Disambiguations'           => array( 'SpecialPage', 'Disambiguations' ),
+		'Listredirects'             => array( 'SpecialPage', 'Listredirects' ),	
+
+		# Login/create account
+		'Userlogin'                 => array( 'SpecialPage', 'Userlogin' ),		
+		'CreateAccount'             => array( 'SpecialRedirectToSpecial', 'CreateAccount', 'Userlogin', 'signup', array( 'uselang' ) ),
+
+		# Users and rights
 		'Blockip'                   => array( 'SpecialPage', 'Blockip', 'block' ),
-		'Undelete'                  => array( 'SpecialPage', 'Undelete', 'deletedhistory' ),
-		'Import'                    => array( 'SpecialPage', "Import", 'import' ),
+		'Ipblocklist'               => array( 'SpecialPage', 'Ipblocklist' ),
+		'Resetpass'                 => 'SpecialResetpass',
+		'DeletedContributions'      => 'DeletedContributionsPage',
+		'Preferences'               => array( 'SpecialPage', 'Preferences' ),	
+		'Contributions'             => 'SpecialContributions',	
+		'Listgrouprights'           => 'SpecialListGroupRights',
+		'Listusers'                 => array( 'SpecialPage', 'Listusers' ),	
+		'Userrights'                => 'UserrightsPage',
+
+		# Recent changes and logs
+		'Newimages'                 => array( 'IncludableSpecialPage', 'Newimages' ),	
+		'Log'                       => array( 'SpecialPage', 'Log' ),
+		'Watchlist'                 => array( 'SpecialPage', 'Watchlist' ),
+		'Newpages'                  => 'SpecialNewpages',
+		'Recentchanges'             => 'SpecialRecentchanges',
+		'Recentchangeslinked'       => 'SpecialRecentchangeslinked',
+		'Tags'                      => 'SpecialTags',
+
+		# Media reports and uploads
+		'Listfiles'                 => array( 'SpecialPage', 'Listfiles' ),
+		'Filepath'                  => array( 'SpecialPage', 'Filepath' ),
+		'MIMEsearch'                => array( 'SpecialPage', 'MIMEsearch' ),
+		'FileDuplicateSearch'       => array( 'SpecialPage', 'FileDuplicateSearch' ),
+		'Upload'                    => array( 'SpecialPage', 'Upload' ),
+
+		# Wiki data and tools
+		'Statistics'				=> 'SpecialStatistics',
+		'Allmessages'               => array( 'SpecialPage', 'Allmessages' ),
+		'Version'                   => 'SpecialVersion',
 		'Lockdb'                    => array( 'SpecialPage', 'Lockdb', 'siteadmin' ),
 		'Unlockdb'                  => array( 'SpecialPage', 'Unlockdb', 'siteadmin' ),
-		'Userrights'                => array( 'SpecialPage', 'Userrights', 'userrights' ),
-		'MIMEsearch'                => array( 'SpecialPage', 'MIMEsearch' ),
-		'Unwatchedpages'            => array( 'SpecialPage', 'Unwatchedpages', 'unwatchedpages' ),
-		'Listredirects'             => array( 'SpecialPage', 'Listredirects' ),
-		'Revisiondelete'            => array( 'SpecialPage', 'Revisiondelete', 'deleterevision' ),
-		'Unusedtemplates'           => array( 'SpecialPage', 'Unusedtemplates' ),
-		'Randomredirect'            => array( 'SpecialPage', 'Randomredirect' ),
 
+		# Redirecting special pages
+		'LinkSearch'                => array( 'SpecialPage', 'LinkSearch' ),
+		'Randompage'                => 'Randompage',
+		'Randomredirect'            => 'SpecialRandomredirect',
+
+		# High use pages
+		'Mostlinkedcategories'      => array( 'SpecialPage', 'Mostlinkedcategories' ),
+		'Mostimages'                => array( 'SpecialPage', 'Mostimages' ),
+		'Mostlinked'                => array( 'SpecialPage', 'Mostlinked' ),
+		'Mostlinkedtemplates'       => array( 'SpecialPage', 'Mostlinkedtemplates' ),
+		'Mostcategories'            => array( 'SpecialPage', 'Mostcategories' ),
+		'Mostrevisions'             => array( 'SpecialPage', 'Mostrevisions' ),
+
+		# Page tools
+		'Export'                    => 'SpecialExport',
+		'Import'                    => 'SpecialImport',
+		'Undelete'                  => array( 'SpecialPage', 'Undelete', 'deletedhistory' ),
+		'Whatlinkshere'             => array( 'SpecialPage', 'Whatlinkshere' ),
+		'MergeHistory'              => array( 'SpecialPage', 'MergeHistory', 'mergehistory' ),	
+		
+		# Other
+		'Booksources'               => 'SpecialBookSources',
+		
+		# Unlisted / redirects
+		'Blankpage'                 => array( 'UnlistedSpecialPage', 'Blankpage' ),
+		'Blockme'                   => array( 'UnlistedSpecialPage', 'Blockme' ),	
+		'Emailuser'                 => array( 'UnlistedSpecialPage', 'Emailuser' ),
+		'Listadmins'                => array( 'SpecialRedirectToSpecial', 'Listadmins', 'Listusers', 'sysop' ),
+		'Listbots'                  => array( 'SpecialRedirectToSpecial', 'Listbots', 'Listusers', 'bot' ),
+		'Movepage'                  => array( 'UnlistedSpecialPage', 'Movepage' ),
+		'Mycontributions'           => array( 'SpecialMycontributions' ),
 		'Mypage'                    => array( 'SpecialMypage' ),
 		'Mytalk'                    => array( 'SpecialMytalk' ),
-		'Mycontributions'           => array( 'SpecialMycontributions' ),
-		'Listadmins'                => array( 'SpecialRedirectToSpecial', 'Listadmins', 'Listusers', 'sysop' ),
+		'Revisiondelete'            => 'SpecialRevisionDelete',
+		'Specialpages'              => array( 'UnlistedSpecialPage', 'Specialpages' ),
+		'Userlogout'                => array( 'UnlistedSpecialPage', 'Userlogout' ),
 	);
 
 	static public $mAliases;
@@ -162,7 +205,7 @@ class SpecialPage
 			return;
 		}
 		wfProfileIn( __METHOD__ );
-		
+
 		# Better to set this now, to avoid infinite recursion in carelessly written hooks
 		self::$mListInitialised = true;
 
@@ -175,7 +218,8 @@ class SpecialPage
 		}
 
 		if( $wgEmailAuthentication ) {
-			self::$mList['Confirmemail'] = array( 'UnlistedSpecialPage', 'Confirmemail' );
+			self::$mList['Confirmemail'] = 'EmailConfirmation';
+			self::$mList['Invalidateemail'] = 'EmailInvalidation';
 		}
 
 		# Add extension special pages
@@ -225,7 +269,7 @@ class SpecialPage
 	}
 
 	/**
-	 * Given a special page name with a possible subpage, return an array 
+	 * Given a special page name with a possible subpage, return an array
 	 * where the first element is the special page name and the second is the
 	 * subpage.
 	 */
@@ -241,14 +285,11 @@ class SpecialPage
 	}
 
 	/**
-	 * Add a page to the list of valid special pages. This used to be the preferred 
-	 * method for adding special pages in extensions. It's now suggested that you add 
+	 * Add a page to the list of valid special pages. This used to be the preferred
+	 * method for adding special pages in extensions. It's now suggested that you add
 	 * an associative record to $wgSpecialPages. This avoids autoloading SpecialPage.
 	 *
-	 * @param mixed $page Must either be an array specifying a class name and 
-	 *                    constructor parameters, or an object. The object,
-	 *                    when constructed, must have an execute() method which
-	 *                    sends HTML to $wgOut.
+	 * @param SpecialPage $page
 	 * @static
 	 */
 	static function addPage( &$page ) {
@@ -258,11 +299,48 @@ class SpecialPage
 		self::$mList[$page->mName] = $page;
 	}
 
+	/**
+	 * Add a page to a certain display group for Special:SpecialPages
+	 *
+	 * @param mixed $page (SpecialPage or string)
+	 * @param string $group
+	 * @static
+	 */
+	static function setGroup( $page, $group ) {
+		global $wgSpecialPageGroups;
+		$name = is_object($page) ? $page->mName : $page;
+		$wgSpecialPageGroups[$name] = $group;
+	}
+
+	/**
+	 * Add a page to a certain display group for Special:SpecialPages
+	 *
+	 * @param SpecialPage $page
+	 * @static
+	 */
+	static function getGroup( &$page ) {
+		global $wgSpecialPageGroups;
+		static $specialPageGroupsCache = array();
+		if( isset($specialPageGroupsCache[$page->mName]) ) {
+			return $specialPageGroupsCache[$page->mName];
+		}
+		$group = wfMsg('specialpages-specialpagegroup-'.strtolower($page->mName));
+		if( $group == ''
+		 || wfEmptyMsg('specialpages-specialpagegroup-'.strtolower($page->mName), $group ) ) {
+			$group = isset($wgSpecialPageGroups[$page->mName])
+				? $wgSpecialPageGroups[$page->mName]
+				: '-';
+		}
+		if( $group == '-' ) $group = 'other';
+		$specialPageGroupsCache[$page->mName] = $group;
+		return $group;
+	}
+
 	/**
 	 * Remove a special page from the list
-	 * Formerly used to disable expensive or dangerous special pages. The 
+	 * Formerly used to disable expensive or dangerous special pages. The
 	 * preferred method is now to add a SpecialPage_initList hook.
-	 * 
+	 *
 	 * @static
 	 */
 	static function removePage( $name ) {
@@ -272,6 +350,30 @@ class SpecialPage
 		unset( self::$mList[$name] );
 	}
 
+	/**
+	 * Check if a given name exist as a special page or as a special page alias
+	 * @param $name string: name of a special page
+	 * @return boolean: true if a special page exists with this name
+	 */
+	static function exists( $name ) {
+		global $wgContLang;
+		if ( !self::$mListInitialised ) {
+			self::initList();
+		}
+		if( !self::$mAliases ) {
+			self::initAliasList();
+		}
+
+		# Remove special pages inline parameters:
+		$bits = explode( '/', $name );
+		$name = $wgContLang->caseFold($bits[0]);
+
+		return
+			array_key_exists( $name, self::$mList )
+			or array_key_exists( $name, self::$mAliases )
+		;
+	}
+
 	/**
 	 * Find the object with a given name and return it (or NULL)
 	 * @static
@@ -309,6 +411,32 @@ class SpecialPage
 		}
 	}
 
+	/**
+	 * Return categorised listable special pages which are available
+	 * for the current user, and everyone.
+	 * @static
+	 */
+	static function getUsablePages() {
+		global $wgUser;
+		if ( !self::$mListInitialised ) {
+			self::initList();
+		}
+		$pages = array();
+
+		foreach ( self::$mList as $name => $rec ) {
+			$page = self::getPage( $name );
+			if ( $page->isListed()
+				&& (
+					!$page->isRestricted()
+					|| $page->userCanExecute( $wgUser )
+				)
+			) {
+				$pages[$name] = $page;
+			}
+		}
+		return $pages;
+	}
+
 	/**
 	 * Return categorised listable special pages for all users
 	 * @static
@@ -321,7 +449,7 @@ class SpecialPage
 
 		foreach ( self::$mList as $name => $rec ) {
 			$page = self::getPage( $name );
-			if ( $page->isListed() && $page->getRestriction() == '' ) {
+			if ( $page->isListed() && !$page->isRestricted() ) {
 				$pages[$name] = $page;
 			}
 		}
@@ -335,18 +463,19 @@ class SpecialPage
 	 */
 	static function getRestrictedPages() {
 		global $wgUser;
-		if ( !self::$mListInitialised ) {
+		if( !self::$mListInitialised ) {
 			self::initList();
 		}
 		$pages = array();
 
-		foreach ( self::$mList as $name => $rec ) {
+		foreach( self::$mList as $name => $rec ) {
 			$page = self::getPage( $name );
-			if ( $page->isListed() ) {
-				$restriction = $page->getRestriction();
-				if ( $restriction != '' && $wgUser->isAllowed( $restriction ) ) {
-					$pages[$name] = $page;
-				}
+			if(
+				$page->isListed()
+				&& $page->isRestricted()
+				&& $page->userCanExecute( $wgUser )
+			) {
+				$pages[$name] = $page;
 			}
 		}
 		return $pages;
@@ -376,12 +505,11 @@ class SpecialPage
 			$par = $bits[1];
 		}
 		$page = SpecialPage::getPageByAlias( $name );
-
 		# Nonexistent?
 		if ( !$page ) {
 			if ( !$including ) {
 				$wgOut->setArticleRelated( false );
-				$wgOut->setRobotpolicy( 'noindex,nofollow' );
+				$wgOut->setRobotPolicy( 'noindex,nofollow' );
 				$wgOut->setStatusCode( 404 );
 				$wgOut->showErrorPage( 'nosuchspecialpage', 'nospecialpagetext' );
 			}
@@ -402,9 +530,9 @@ class SpecialPage
 		}
 
 		# Redirect to canonical alias for GET commands
-		# Not for POST, we'd lose the post data, so it's best to just distribute 
-		# the request. Such POST requests are possible for old extensions that 
-		# generate self-links without being aware that their default name has 
+		# Not for POST, we'd lose the post data, so it's best to just distribute
+		# the request. Such POST requests are possible for old extensions that
+		# generate self-links without being aware that their default name has
 		# changed.
 		if ( !$including && $name != $page->getLocalName() && !$wgRequest->wasPosted() ) {
 			$query = $_GET;
@@ -458,6 +586,11 @@ class SpecialPage
 
 	/**
 	 * Get the local name for a specified canonical name
+	 *
+	 * @param $name
+	 * @param mixed $subpage Boolean false, or string
+	 *
+	 * @return string
 	 */
 	static function getLocalNameFor( $name, $subpage = false ) {
 		global $wgContLang;
@@ -468,7 +601,7 @@ class SpecialPage
 		if ( $subpage !== false && !is_null( $subpage ) ) {
 			$name = "$name/$subpage";
 		}
-		return $name;
+		return ucfirst( $name );
 	}
 
 	/**
@@ -535,7 +668,7 @@ class SpecialPage
 			$this->mFunction = $function;
 		}
 		if ( $file === 'default' ) {
-			$this->mFile = "Special{$name}.php";
+			$this->mFile = dirname(__FILE__) . "/specials/Special$name.php";
 		} else {
 			$this->mFile = $file;
 		}
@@ -575,10 +708,27 @@ class SpecialPage
 	}
 
 	/**
-	 * Checks if the given user (identified by an object) can execute this
-	 * special page (as defined by $mRestriction)
+	 * Can be overridden by subclasses with more complicated permissions
+	 * schemes.
+	 *
+	 * @return bool Should the page be displayed with the restricted-access
+	 *   pages?
 	 */
-	function userCanExecute( &$user ) {
+	public function isRestricted() {
+		global $wgGroupPermissions;
+		// DWIM: If all anons can do something, then it is not restricted
+		return $this->mRestriction != '' && empty($wgGroupPermissions['*'][$this->mRestriction]);
+	}
+
+	/**
+	 * Checks if the given user (identified by an object) can execute this
+	 * special page (as defined by $mRestriction).  Can be overridden by sub-
+	 * classes with more complicated permissions schemes.
+	 *
+	 * @param User $user The user to check
+	 * @return bool Does the user have permission to view the page?
+	 */
+	public function userCanExecute( $user ) {
 		return $user->isAllowed( $this->mRestriction );
 	}
 
@@ -604,7 +754,7 @@ class SpecialPage
 	 * Default execute method
 	 * Checks user permissions, calls the function given in mFunction
 	 *
-	 * This may be overridden by subclasses. 
+	 * This may be overridden by subclasses.
 	 */
 	function execute( $par ) {
 		global $wgUser;
@@ -614,29 +764,36 @@ class SpecialPage
 		if ( $this->userCanExecute( $wgUser ) ) {
 			$func = $this->mFunction;
 			// only load file if the function does not exist
-			if(!function_exists($func) and $this->mFile) {
+			if(!is_callable($func) and $this->mFile) {
 				require_once( $this->mFile );
 			}
-			# FIXME: these hooks are broken for extensions and anything else that subclasses SpecialPage. 
-			if ( wfRunHooks( 'SpecialPageExecuteBeforeHeader', array( &$this, &$par, &$func ) ) )
-				$this->outputHeader();
-			if ( ! wfRunHooks( 'SpecialPageExecuteBeforePage', array( &$this, &$par, &$func ) ) )
-				return;
-			$func( $par, $this );
-			if ( ! wfRunHooks( 'SpecialPageExecuteAfterPage', array( &$this, &$par, &$func ) ) )
-				return;
+			$this->outputHeader();
+			call_user_func( $func, $par, $this );
 		} else {
 			$this->displayRestrictionError();
 		}
 	}
 
-	function outputHeader() {
+	/**
+	 * Outputs a summary message on top of special pages
+	 * Per default the message key is the canonical name of the special page
+	 * May be overriden, i.e. by extensions to stick with the naming conventions
+	 * for message keys: 'extensionname-xxx' 
+	 *
+	 * @param string message key of the summary
+	 */
+	function outputHeader( $summaryMessageKey = '' ) {
 		global $wgOut, $wgContLang;
 
-		$msg = $wgContLang->lc( $this->name() ) . '-summary';
-		$out = wfMsg( $msg );
-		if ( ! wfEmptyMsg( $msg, $out ) and  $out !== '' and ! $this->including() )
-			$wgOut->addWikiText( $out );
+		if( $summaryMessageKey == '' ) {
+			$msg = $wgContLang->lc( $this->name() ) . '-summary';
+		} else {
+			$msg = $summaryMessageKey;
+		}
+		$out = wfMsgNoTrans( $msg );
+		if ( ! wfEmptyMsg( $msg, $out ) and  $out !== '' and ! $this->including() ) {
+			$wgOut->wrapWikiMsg( "<div class='mw-specialpage-summary'>\n$1</div>", $msg );
+		}
 
 	}
 
@@ -664,7 +821,7 @@ class SpecialPage
 	}
 
 	/**
-	 * If the special page is a redirect, then get the Title object it redirects to. 
+	 * If the special page is a redirect, then get the Title object it redirects to.
 	 * False otherwise.
 	 */
 	function getRedirect( $subpage ) {
@@ -684,14 +841,14 @@ class SpecialPage
 			if( $val = $wgRequest->getVal( $arg, false ) )
 				$params[] = $arg . '=' . $val;
 		}
-		
+
 		return count( $params ) ? implode( '&', $params ) : false;
 	}
 }
 
 /**
  * Shortcut to construct a special page which is unlisted by default
- * @package MediaWiki
+ * @ingroup SpecialPage
  */
 class UnlistedSpecialPage extends SpecialPage
 {
@@ -702,7 +859,7 @@ class UnlistedSpecialPage extends SpecialPage
 
 /**
  * Shortcut to construct an includable special  page
- * @package MediaWiki
+ * @ingroup SpecialPage
  */
 class IncludableSpecialPage extends SpecialPage
 {
@@ -711,6 +868,10 @@ class IncludableSpecialPage extends SpecialPage
 	}
 }
 
+/**
+ * Shortcut to construct a special page alias.
+ * @ingroup SpecialPage
+ */
 class SpecialRedirectToSpecial extends UnlistedSpecialPage {
 	var $redirName, $redirSubpage;
 
@@ -730,10 +891,21 @@ class SpecialRedirectToSpecial extends UnlistedSpecialPage {
 	}
 }
 
+/** SpecialMypage, SpecialMytalk and SpecialMycontributions special pages
+ * are used to get user independant links pointing to the user page, talk
+ * page and list of contributions.
+ * This can let us cache a single copy of any generated content for all
+ * users.
+ */
+
+/**
+ * Shortcut to construct a special page pointing to current user user's page.
+ * @ingroup SpecialPage
+ */
 class SpecialMypage extends UnlistedSpecialPage {
 	function __construct() {
 		parent::__construct( 'Mypage' );
-		$this->mAllowedRedirectParams = array( 'action' );
+		$this->mAllowedRedirectParams = array( 'action' , 'preload' , 'editintro', 'section' );
 	}
 
 	function getRedirect( $subpage ) {
@@ -746,10 +918,14 @@ class SpecialMypage extends UnlistedSpecialPage {
 	}
 }
 
+/**
+ * Shortcut to construct a special page pointing to current user talk page.
+ * @ingroup SpecialPage
+ */
 class SpecialMytalk extends UnlistedSpecialPage {
 	function __construct() {
 		parent::__construct( 'Mytalk' );
-		$this->mAllowedRedirectParams = array( 'action' );
+		$this->mAllowedRedirectParams = array( 'action' , 'preload' , 'editintro', 'section' );
 	}
 
 	function getRedirect( $subpage ) {
@@ -762,6 +938,10 @@ class SpecialMytalk extends UnlistedSpecialPage {
 	}
 }
 
+/**
+ * Shortcut to construct a special page pointing to current user contributions.
+ * @ingroup SpecialPage
+ */
 class SpecialMycontributions extends UnlistedSpecialPage {
 	function __construct() {
 		parent::__construct(  'Mycontributions' );
@@ -772,5 +952,3 @@ class SpecialMycontributions extends UnlistedSpecialPage {
 		return SpecialPage::getTitleFor( 'Contributions', $wgUser->getName() );
 	}
 }
-
-?>
