@@ -1,12 +1,11 @@
 <?php
 
-
 /*
  * Created on Sep 24, 2006
  *
  * API for MediaWiki 1.8+
  *
- * Copyright (C) 2006 Yuri Astrakhan <FirstnameLastname@gmail.com>
+ * Copyright (C) 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,25 +28,48 @@ if (!defined('MEDIAWIKI')) {
 	require_once ('ApiQueryBase.php');
 }
 
+/**
+ * This class contains a list of pages that the client has requested.
+ * Initially, when the client passes in titles=, pageids=, or revisions=
+ * parameter, an instance of the ApiPageSet class will normalize titles,
+ * determine if the pages/revisions exist, and prefetch any additional page
+ * data requested.
+ *
+ * When a generator is used, the result of the generator will become the input
+ * for the second instance of this class, and all subsequent actions will use
+ * the second instance for all their work.
+ *
+ * @ingroup API
+ */
 class ApiPageSet extends ApiQueryBase {
 
-	private $mAllPages; // [ns][dbkey] => page_id or 0 when missing
-	private $mTitles, $mGoodTitles, $mMissingTitles, $mMissingPageIDs, $mRedirectTitles, $mNormalizedTitles;
+	private $mAllPages; // [ns][dbkey] => page_id or negative when missing
+	private $mTitles, $mGoodTitles, $mMissingTitles, $mInvalidTitles;
+	private $mMissingPageIDs, $mRedirectTitles;
+	private $mNormalizedTitles, $mInterwikiTitles;
 	private $mResolveRedirects, $mPendingRedirectIDs;
 	private $mGoodRevIDs, $mMissingRevIDs;
+	private $mFakePageId;
 
 	private $mRequestedPageFields;
 
+	/**
+	 * Constructor
+	 * @param $query ApiQuery
+	 * @param $resolveRedirects bool Whether redirects should be resolved
+	 */
 	public function __construct($query, $resolveRedirects = false) {
-		parent :: __construct($query, __CLASS__);
+		parent :: __construct($query, 'query');
 
 		$this->mAllPages = array ();
 		$this->mTitles = array();
 		$this->mGoodTitles = array ();
 		$this->mMissingTitles = array ();
+		$this->mInvalidTitles = array ();
 		$this->mMissingPageIDs = array ();
 		$this->mRedirectTitles = array ();
 		$this->mNormalizedTitles = array ();
+		$this->mInterwikiTitles = array ();
 		$this->mGoodRevIDs = array();
 		$this->mMissingRevIDs = array();
 
@@ -55,38 +77,70 @@ class ApiPageSet extends ApiQueryBase {
 		$this->mResolveRedirects = $resolveRedirects;
 		if($resolveRedirects)
 			$this->mPendingRedirectIDs = array();
+
+		$this->mFakePageId = -1;
 	}
 
+	/**
+	 * Check whether this PageSet is resolving redirects
+	 * @return bool
+	 */
 	public function isResolvingRedirects() {
 		return $this->mResolveRedirects;
 	}
 
+	/**
+	 * Request an additional field from the page table. Must be called
+	 * before execute()
+	 * @param $fieldName string Field name
+	 */
 	public function requestField($fieldName) {
 		$this->mRequestedPageFields[$fieldName] = null;
 	}
 
+	/**
+	 * Get the value of a custom field previously requested through
+	 * requestField()
+	 * @param $fieldName string Field name
+	 * @return mixed Field value
+	 */
 	public function getCustomField($fieldName) {
 		return $this->mRequestedPageFields[$fieldName];
 	}
 
 	/**
-	 * Get fields that modules have requested from the page table
+	 * Get the fields that have to be queried from the page table:
+	 * the ones requested through requestField() and a few basic ones
+	 * we always need
+	 * @return array of field names
 	 */
 	public function getPageTableFields() {
 		// Ensure we get minimum required fields
+		// DON'T change this order
 		$pageFlds = array (
-			'page_id' => null,
 			'page_namespace' => null,
-			'page_title' => null
+			'page_title' => null,
+			'page_id' => null,
 		);
 
-		// only store non-default fields
-		$this->mRequestedPageFields = array_diff_key($this->mRequestedPageFields, $pageFlds);
-
 		if ($this->mResolveRedirects)
 			$pageFlds['page_is_redirect'] = null;
 
-		return array_keys(array_merge($pageFlds, $this->mRequestedPageFields));
+		// only store non-default fields
+		$this->mRequestedPageFields = array_diff_key($this->mRequestedPageFields, $pageFlds);
+
+		$pageFlds = array_merge($pageFlds, $this->mRequestedPageFields);
+		return array_keys($pageFlds);
+	}
+
+	/**
+	 * Returns an array [ns][dbkey] => page_id for all requested titles.
+	 * page_id is a unique negative number in case title was not found.
+	 * Invalid titles will also have negative page IDs and will be in namespace 0
+	 * @return array
+	 */
+	public function getAllTitlesByNamespace() {
+		return $this->mAllPages;
 	}
 
 	/**
@@ -99,6 +153,7 @@ class ApiPageSet extends ApiQueryBase {
 
 	/**
 	 * Returns the number of unique pages (not revisions) in the set.
+	 * @return int
 	 */
 	public function getTitleCount() {
 		return count($this->mTitles);
@@ -114,6 +169,7 @@ class ApiPageSet extends ApiQueryBase {
 
 	/**
 	 * Returns the number of found unique pages (not revisions) in the set.
+	 * @return int
 	 */
 	public function getGoodTitleCount() {
 		return count($this->mGoodTitles);
@@ -121,12 +177,22 @@ class ApiPageSet extends ApiQueryBase {
 
 	/**
 	 * Title objects that were NOT found in the database.
+	 * The array's index will be negative for each item
 	 * @return array of Title objects
 	 */
 	public function getMissingTitles() {
 		return $this->mMissingTitles;
 	}
 
+	/**
+	 * Titles that were deemed invalid by Title::newFromText()
+	 * The array's index will be unique and negative for each item
+	 * @return array of strings (not Title objects)
+	 */
+	public function getInvalidTitles() {
+		return $this->mInvalidTitles;
+	}
+
 	/**
 	 * Page IDs that were not found in the database
 	 * @return array of page IDs
@@ -136,7 +202,8 @@ class ApiPageSet extends ApiQueryBase {
 	}
 
 	/**
-	 * Get a list of redirects when doing redirect resolution
+	 * Get a list of redirect resolutions - maps a title to its redirect
+	 * target.
 	 * @return array prefixed_title (string) => prefixed_title (string)
 	 */
 	public function getRedirectTitles() {
@@ -144,16 +211,25 @@ class ApiPageSet extends ApiQueryBase {
 	}
 
 	/**
-	 * Get a list of title normalizations - maps the title given 
-	 * with its normalized version.
-	 * @return array raw_prefixed_title (string) => prefixed_title (string) 
+	 * Get a list of title normalizations - maps a title to its normalized
+	 * version.
+	 * @return array raw_prefixed_title (string) => prefixed_title (string)
 	 */
 	public function getNormalizedTitles() {
 		return $this->mNormalizedTitles;
 	}
 
 	/**
-	 * Get the list of revision IDs (requested with revids= parameter)
+	 * Get a list of interwiki titles - maps a title to its interwiki
+	 * prefix.
+	 * @return array raw_prefixed_title (string) => interwiki_prefix (string)
+	 */
+	public function getInterwikiTitles() {
+		return $this->mInterwikiTitles;
+	}
+
+	/**
+	 * Get the list of revision IDs (requested with the revids= parameter)
 	 * @return array revID (int) => pageID (int)
 	 */
 	public function getRevisionIDs() {
@@ -169,30 +245,30 @@ class ApiPageSet extends ApiQueryBase {
 	}
 
 	/**
-	 * Returns the number of revisions (requested with revids= parameter)
+	 * Returns the number of revisions (requested with revids= parameter)\
+	 * @return int
 	 */
 	public function getRevisionCount() {
 		return count($this->getRevisionIDs());
 	}
 
 	/**
-	 * Populate from the request parameters
+	 * Populate the PageSet from the request parameters.
 	 */
 	public function execute() {
 		$this->profileIn();
-		$titles = $pageids = $revids = null;
-		extract($this->extractRequestParams());
+		$params = $this->extractRequestParams();
 
 		// Only one of the titles/pageids/revids is allowed at the same time
 		$dataSource = null;
-		if (isset ($titles))
+		if (isset ($params['titles']))
 			$dataSource = 'titles';
-		if (isset ($pageids)) {
+		if (isset ($params['pageids'])) {
 			if (isset ($dataSource))
 				$this->dieUsage("Cannot use 'pageids' at the same time as '$dataSource'", 'multisource');
 			$dataSource = 'pageids';
 		}
-		if (isset ($revids)) {
+		if (isset ($params['revids'])) {
 			if (isset ($dataSource))
 				$this->dieUsage("Cannot use 'revids' at the same time as '$dataSource'", 'multisource');
 			$dataSource = 'revids';
@@ -200,15 +276,17 @@ class ApiPageSet extends ApiQueryBase {
 
 		switch ($dataSource) {
 			case 'titles' :
-				$this->initFromTitles($titles);
+				$this->initFromTitles($params['titles']);
 				break;
 			case 'pageids' :
-				$this->initFromPageIds($pageids);
+				$this->initFromPageIds($params['pageids']);
 				break;
 			case 'revids' :
 				if($this->mResolveRedirects)
-					$this->dieUsage('revids may not be used with redirect resolution', 'params');
-				$this->initFromRevIDs($revids);
+					$this->setWarning('Redirect resolution cannot be used together with the revids= parameter. '.
+					'Any redirects the revids= point to have not been resolved.');
+				$this->mResolveRedirects = false;
+				$this->initFromRevIDs($params['revids']);
 				break;
 			default :
 				// Do nothing - some queries do not need any of the data sources.
@@ -218,7 +296,8 @@ class ApiPageSet extends ApiQueryBase {
 	}
 
 	/**
-	 * Initialize PageSet from a list of Titles
+	 * Populate this PageSet from a list of Titles
+	 * @param $titles array of Title objects
 	 */
 	public function populateFromTitles($titles) {
 		$this->profileIn();
@@ -227,17 +306,19 @@ class ApiPageSet extends ApiQueryBase {
 	}
 
 	/**
-	 * Initialize PageSet from a list of Page IDs
+	 * Populate this PageSet from a list of page IDs
+	 * @param $pageIDs array of page IDs
 	 */
 	public function populateFromPageIDs($pageIDs) {
 		$this->profileIn();
-		$pageIDs = array_map('intval', $pageIDs); // paranoia
 		$this->initFromPageIds($pageIDs);
 		$this->profileOut();
 	}
 
 	/**
-	 * Initialize PageSet from a rowset returned from the database
+	 * Populate this PageSet from a rowset returned from the database
+	 * @param $db Database object
+	 * @param $queryResult Query result object
 	 */
 	public function populateFromQueryResult($db, $queryResult) {
 		$this->profileIn();
@@ -246,74 +327,77 @@ class ApiPageSet extends ApiQueryBase {
 	}
 
 	/**
-	 * Initialize PageSet from a list of Revision IDs
+	 * Populate this PageSet from a list of revision IDs
+	 * @param $revIDs array of revision IDs
 	 */
 	public function populateFromRevisionIDs($revIDs) {
 		$this->profileIn();
-		$revIDs = array_map('intval', $revIDs); // paranoia
 		$this->initFromRevIDs($revIDs);
 		$this->profileOut();
 	}
 
 	/**
 	 * Extract all requested fields from the row received from the database
+	 * @param $row Result row
 	 */
 	public function processDbRow($row) {
-	
+
 		// Store Title object in various data structures
 		$title = Title :: makeTitle($row->page_namespace, $row->page_title);
-	
-		// skip any pages that user has no rights to read
-		if ($title->userCanRead()) {
 
-			$pageId = intval($row->page_id);	
-			$this->mAllPages[$row->page_namespace][$row->page_title] = $pageId;
-			$this->mTitles[] = $title;
-	
-			if ($this->mResolveRedirects && $row->page_is_redirect == '1') {
-				$this->mPendingRedirectIDs[$pageId] = $title;
-			} else {
-				$this->mGoodTitles[$pageId] = $title;
-			}
-	
-			foreach ($this->mRequestedPageFields as $fieldName => & $fieldValues)
-				$fieldValues[$pageId] = $row-> $fieldName;
+		$pageId = intval($row->page_id);
+		$this->mAllPages[$row->page_namespace][$row->page_title] = $pageId;
+		$this->mTitles[] = $title;
+
+		if ($this->mResolveRedirects && $row->page_is_redirect == '1') {
+			$this->mPendingRedirectIDs[$pageId] = $title;
+		} else {
+			$this->mGoodTitles[$pageId] = $title;
 		}
+
+		foreach ($this->mRequestedPageFields as $fieldName => & $fieldValues)
+			$fieldValues[$pageId] = $row-> $fieldName;
 	}
-	
+
+	/**
+	 * Resolve redirects, if applicable
+	 */
 	public function finishPageSetGeneration() {
 		$this->profileIn();
 		$this->resolvePendingRedirects();
 		$this->profileOut();
 	}
-	
+
 	/**
 	 * This method populates internal variables with page information
 	 * based on the given array of title strings.
-	 * 
+	 *
 	 * Steps:
 	 * #1 For each title, get data from `page` table
 	 * #2 If page was not found in the DB, store it as missing
-	 * 
+	 *
 	 * Additionally, when resolving redirects:
 	 * #3 If no more redirects left, stop.
-	 * #4 For each redirect, get its links from `pagelinks` table.
+	 * #4 For each redirect, get its target from the `redirect` table.
 	 * #5 Substitute the original LinkBatch object with the new list
-	 * #6 Repeat from step #1     
+	 * #6 Repeat from step #1
+	 *
+	 * @param $titles array of Title objects or strings
 	 */
 	private function initFromTitles($titles) {
 
 		// Get validated and normalized title objects
-		$linkBatch = $this->processTitlesStrArray($titles);
+		$linkBatch = $this->processTitlesArray($titles);
 		if($linkBatch->isEmpty())
 			return;
-			
-		$db = & $this->getDB();
+
+		$db = $this->getDB();
 		$set = $linkBatch->constructSet('page', $db);
 
 		// Get pageIDs data from the `page` table
 		$this->profileDBIn();
-		$res = $db->select('page', $this->getPageTableFields(), $set, __METHOD__);
+		$res = $db->select('page', $this->getPageTableFields(), $set,
+					__METHOD__);
 		$this->profileDBOut();
 
 		// Hack: get the ns:titles stored in array(ns => array(titles)) format
@@ -323,43 +407,48 @@ class ApiPageSet extends ApiQueryBase {
 		$this->resolvePendingRedirects();
 	}
 
+	/**
+	 * Does the same as initFromTitles(), but is based on page IDs instead
+	 * @param $pageids array of page IDs
+	 */
 	private function initFromPageIds($pageids) {
-		if(empty($pageids))
+		if(!count($pageids))
 			return;
-			
+
+		$pageids = array_map('intval', $pageids); // paranoia
 		$set = array (
 			'page_id' => $pageids
 		);
-
-		$db = & $this->getDB();
+		$db = $this->getDB();
 
 		// Get pageIDs data from the `page` table
 		$this->profileDBIn();
-		$res = $db->select('page', $this->getPageTableFields(), $set, __METHOD__);
+		$res = $db->select('page', $this->getPageTableFields(), $set,
+					__METHOD__);
 		$this->profileDBOut();
-		
-		$this->initFromQueryResult($db, $res, array_flip($pageids), false);	// process PageIDs
+
+		$remaining = array_flip($pageids);
+		$this->initFromQueryResult($db, $res, $remaining, false);	// process PageIDs
 
 		// Resolve any found redirects
 		$this->resolvePendingRedirects();
 	}
-	
+
 	/**
 	 * Iterate through the result of the query on 'page' table,
 	 * and for each row create and store title object and save any extra fields requested.
 	 * @param $db Database
 	 * @param $res DB Query result
-	 * @param $remaining Array of either pageID or ns/title elements (optional).
+	 * @param $remaining array of either pageID or ns/title elements (optional).
 	 *        If given, any missing items will go to $mMissingPageIDs and $mMissingTitles
 	 * @param $processTitles bool Must be provided together with $remaining.
 	 *        If true, treat $remaining as an array of [ns][title]
 	 *        If false, treat it as an array of [pageIDs]
-	 * @return Array of redirect IDs (only when resolving redirects)
 	 */
 	private function initFromQueryResult($db, $res, &$remaining = null, $processTitles = null) {
 		if (!is_null($remaining) && is_null($processTitles))
 			ApiBase :: dieDebug(__METHOD__, 'Missing $processTitles parameter when $remaining is provided');
-			
+
 		while ($row = $db->fetchObject($res)) {
 
 			$pageId = intval($row->page_id);
@@ -371,21 +460,22 @@ class ApiPageSet extends ApiQueryBase {
 				else
 					unset ($remaining[$pageId]);
 			}
-			
+
 			// Store any extra fields requested by modules
 			$this->processDbRow($row);
 		}
 		$db->freeResult($res);
-		
+
 		if(isset($remaining)) {
 			// Any items left in the $remaining list are added as missing
 			if($processTitles) {
-				// The remaining titles in $remaining are non-existant pages
+				// The remaining titles in $remaining are non-existent pages
 				foreach ($remaining as $ns => $dbkeys) {
 					foreach ( $dbkeys as $dbkey => $unused ) {
 						$title = Title :: makeTitle($ns, $dbkey);
-						$this->mMissingTitles[] = $title;
-						$this->mAllPages[$ns][$dbkey] = 0;
+						$this->mAllPages[$ns][$dbkey] = $this->mFakePageId;
+						$this->mMissingTitles[$this->mFakePageId] = $title;
+						$this->mFakePageId--;
 						$this->mTitles[] = $title;
 					}
 				}
@@ -393,7 +483,7 @@ class ApiPageSet extends ApiQueryBase {
 			else
 			{
 				// The remaining pageids do not exist
-				if(empty($this->mMissingPageIDs))
+				if(!$this->mMissingPageIDs)
 					$this->mMissingPageIDs = array_keys($remaining);
 				else
 					$this->mMissingPageIDs = array_merge($this->mMissingPageIDs, array_keys($remaining));
@@ -401,166 +491,176 @@ class ApiPageSet extends ApiQueryBase {
 		}
 	}
 
+	/**
+	 * Does the same as initFromTitles(), but is based on revision IDs
+	 * instead
+	 * @param $revids array of revision IDs
+	 */
 	private function initFromRevIDs($revids) {
 
-		if(empty($revids))
+		if(!count($revids))
 			return;
-			
-		$db = & $this->getDB();
+
+		$revids = array_map('intval', $revids); // paranoia
+		$db = $this->getDB();
 		$pageids = array();
 		$remaining = array_flip($revids);
-		
-		$tables = array('revision');
-		$fields = array('rev_id','rev_page');
-		$where = array('rev_deleted' => 0, 'rev_id' => $revids);
-		
+
+		$tables = array('revision', 'page');
+		$fields = array('rev_id', 'rev_page');
+		$where = array('rev_id' => $revids, 'rev_page = page_id');
+
 		// Get pageIDs data from the `page` table
 		$this->profileDBIn();
-		$res = $db->select( $tables, $fields, $where,  __METHOD__ );
-		while ( $row = $db->fetchObject( $res ) ) {
+		$res = $db->select($tables, $fields, $where,  __METHOD__);
+		while ($row = $db->fetchObject($res)) {
 			$revid = intval($row->rev_id);
 			$pageid = intval($row->rev_page);
 			$this->mGoodRevIDs[$revid] = $pageid;
 			$pageids[$pageid] = '';
 			unset($remaining[$revid]);
 		}
-		$db->freeResult( $res );
+		$db->freeResult($res);
 		$this->profileDBOut();
 
 		$this->mMissingRevIDs = array_keys($remaining);
 
 		// Populate all the page information
-		if($this->mResolveRedirects)
-			ApiBase :: dieDebug(__METHOD__, 'revids may not be used with redirect resolution');
 		$this->initFromPageIds(array_keys($pageids));
 	}
 
+	/**
+	 * Resolve any redirects in the result if redirect resolution was
+	 * requested. This function is called repeatedly until all redirects
+	 * have been resolved.
+	 */
 	private function resolvePendingRedirects() {
 
 		if($this->mResolveRedirects) {
-			$db = & $this->getDB();
+			$db = $this->getDB();
 			$pageFlds = $this->getPageTableFields();
-	
+
 			// Repeat until all redirects have been resolved
 			// The infinite loop is prevented by keeping all known pages in $this->mAllPages
-			while (!empty ($this->mPendingRedirectIDs)) {			
-	
+			while ($this->mPendingRedirectIDs) {
+
 				// Resolve redirects by querying the pagelinks table, and repeat the process
 				// Create a new linkBatch object for the next pass
 				$linkBatch = $this->getRedirectTargets();
-	
+
 				if ($linkBatch->isEmpty())
 					break;
-					
+
 				$set = $linkBatch->constructSet('page', $db);
-				if(false === $set)
+				if($set === false)
 					break;
-		
+
 				// Get pageIDs data from the `page` table
 				$this->profileDBIn();
 				$res = $db->select('page', $pageFlds, $set, __METHOD__);
 				$this->profileDBOut();
-			
+
 				// Hack: get the ns:titles stored in array(ns => array(titles)) format
 				$this->initFromQueryResult($db, $res, $linkBatch->data, true);
 			}
 		}
 	}
 
+	/**
+	 * Get the targets of the pending redirects from the database
+	 *
+	 * Also creates entries in the redirect table for redirects that don't
+	 * have one.
+	 * @return LinkBatch
+	 */
 	private function getRedirectTargets() {
+		$lb = new LinkBatch();
+		$db = $this->getDB();
 
-		$linkBatch = new LinkBatch();
-		$db = & $this->getDB();
-
-		// find redirect targets for all redirect pages
 		$this->profileDBIn();
-		$res = $db->select('pagelinks', array (
-			'pl_from',
-			'pl_namespace',
-			'pl_title'
-		), array (
-			'pl_from' => array_keys($this->mPendingRedirectIDs
-		)), __METHOD__);
+		$res = $db->select('redirect', array(
+				'rd_from',
+				'rd_namespace',
+				'rd_title'
+			), array('rd_from' => array_keys($this->mPendingRedirectIDs)),
+			__METHOD__
+		);
 		$this->profileDBOut();
 
-		while ($row = $db->fetchObject($res)) {
-
-			$plfrom = intval($row->pl_from);
-
-			// Bug 7304 workaround 
-			// ( http://bugzilla.wikipedia.org/show_bug.cgi?id=7304 )
-			// A redirect page may have more than one link.
-			// This code will only use the first link returned. 
-			if (isset ($this->mPendingRedirectIDs[$plfrom])) { // remove line when bug 7304 is fixed 
-
-				$titleStrFrom = $this->mPendingRedirectIDs[$plfrom]->getPrefixedText();
-				$titleStrTo = Title :: makeTitle($row->pl_namespace, $row->pl_title)->getPrefixedText();
-				unset ($this->mPendingRedirectIDs[$plfrom]); // remove line when bug 7304 is fixed
-
-				// Avoid an infinite loop by checking if we have already processed this target
-				if (!isset ($this->mAllPages[$row->pl_namespace][$row->pl_title])) {
-					$linkBatch->add($row->pl_namespace, $row->pl_title);
-				}
-			} else {
-				// This redirect page has more than one link.
-				// This is very slow, but safer until bug 7304 is resolved
-				$title = Title :: newFromID($plfrom);
-				$titleStrFrom = $title->getPrefixedText();
-
-				$article = new Article($title);
-				$text = $article->getContent();
-				$titleTo = Title :: newFromRedirect($text);
-				$titleStrTo = $titleTo->getPrefixedText();
-
-				if (is_null($titleStrTo))
-					ApiBase :: dieDebug(__METHOD__, 'Bug7304 workaround: redir target from {$title->getPrefixedText()} not found');
-
-				// Avoid an infinite loop by checking if we have already processed this target
-				if (!isset ($this->mAllPages[$titleTo->getNamespace()][$titleTo->getDBkey()])) {
-					$linkBatch->addObj($titleTo);
-				}
-			}
-
-			$this->mRedirectTitles[$titleStrFrom] = $titleStrTo;
+		while($row = $db->fetchObject($res))
+		{
+			$rdfrom = intval($row->rd_from);
+			$from = $this->mPendingRedirectIDs[$rdfrom]->getPrefixedText();
+			$to = Title::makeTitle($row->rd_namespace, $row->rd_title)->getPrefixedText();
+			unset($this->mPendingRedirectIDs[$rdfrom]);
+			if(!isset($this->mAllPages[$row->rd_namespace][$row->rd_title]))
+				$lb->add($row->rd_namespace, $row->rd_title);
+			$this->mRedirectTitles[$from] = $to;
 		}
 		$db->freeResult($res);
-
-		// All IDs must exist in the page table
-		if (!empty($this->mPendingRedirectIDs[$plfrom]))
-			ApiBase :: dieDebug(__METHOD__, 'Invalid redirect IDs were found');
-
-		return $linkBatch;
+		if($this->mPendingRedirectIDs)
+		{
+			# We found pages that aren't in the redirect table
+			# Add them
+			foreach($this->mPendingRedirectIDs as $id => $title)
+			{
+				$article = new Article($title);
+				$rt = $article->insertRedirect();
+				if(!$rt)
+					# What the hell. Let's just ignore this
+					continue;
+				$lb->addObj($rt);
+				$this->mRedirectTitles[$title->getPrefixedText()] = $rt->getPrefixedText();
+				unset($this->mPendingRedirectIDs[$id]);
+			}
+		}
+		return $lb;
 	}
 
 	/**
 	 * Given an array of title strings, convert them into Title objects.
-	 * This method validates access rights for the title, 
+	 * Alternativelly, an array of Title objects may be given.
+	 * This method validates access rights for the title,
 	 * and appends normalization values to the output.
-	 * 
-	 * @return LinkBatch of title objects.
+	 *
+	 * @param $titles array of Title objects or strings
+	 * @return LinkBatch
 	 */
-	private function processTitlesStrArray($titles) {
+	private function processTitlesArray($titles) {
 
 		$linkBatch = new LinkBatch();
 
-		foreach ($titles as $titleString) {
-			$titleObj = Title :: newFromText($titleString);
+		foreach ($titles as $title) {
 
-			// Validation
+			$titleObj = is_string($title) ? Title :: newFromText($title) : $title;
 			if (!$titleObj)
-				$this->dieUsage("bad title $titleString", 'invalidtitle');
-			if ($titleObj->getNamespace() < 0)
-				$this->dieUsage("No support for special page $titleString has been implemented", 'unsupportednamespace');
-			if (!$titleObj->userCanRead())
-				$this->dieUsage("No read permission for $titleString", 'titleaccessdenied');
+			{
+				# Handle invalid titles gracefully
+				$this->mAllpages[0][$title] = $this->mFakePageId;
+				$this->mInvalidTitles[$this->mFakePageId] = $title;
+				$this->mFakePageId--;
+				continue; // There's nothing else we can do
+			}
+			$iw = $titleObj->getInterwiki();
+			if (strval($iw) !== '') {
+				// This title is an interwiki link.
+				$this->mInterwikiTitles[$titleObj->getPrefixedText()] = $iw;
+			} else {
 
-			$linkBatch->addObj($titleObj);
+				// Validation
+				if ($titleObj->getNamespace() < 0)
+					$this->setWarning("No support for special pages has been implemented");
+				else
+					$linkBatch->addObj($titleObj);
+			}
 
-			// Make sure we remember the original title that was given to us
-			// This way the caller can correlate new titles with the originally requested,
-			// i.e. namespace is localized or capitalization is different
-			if ($titleString !== $titleObj->getPrefixedText()) {
-				$this->mNormalizedTitles[$titleString] = $titleObj->getPrefixedText();
+			// Make sure we remember the original title that was
+			// given to us. This way the caller can correlate new
+			// titles with the originally requested when e.g. the
+			// namespace is localized or the capitalization is
+			// different
+			if (is_string($title) && $title !== $titleObj->getPrefixedText()) {
+				$this->mNormalizedTitles[$title] = $titleObj->getPrefixedText();
 			}
 		}
 
@@ -592,7 +692,6 @@ class ApiPageSet extends ApiQueryBase {
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiPageSet.php 17929 2006-11-25 17:11:58Z tstarling $';
+		return __CLASS__ . ': $Id: ApiPageSet.php 47424 2009-02-18 05:29:11Z werdna $';
 	}
 }
-?>
