@@ -264,10 +264,10 @@ $1',
 'userlogin'               => 'اویدن به سیستم / درست کردن حساب کاربری',
 'logout'                  => 'رهدن زه سیستم',
 'userlogout'              => 'رهدن زه سیستم',
-'nologin'                 => 'آیا ایسا حساب کاربری ندارین? $1.',
+'nologin'                 => "آیا ایسا حساب کاربری ندارین? '''$1'''.",
 'nologinlink'             => 'درست کردن یه حساب کاربری',
 'createaccount'           => 'درست کردن حساب کاربری',
-'gotaccount'              => 'آیا تقریبا یه حساب کاربری دارین? $1.',
+'gotaccount'              => "آیا تقریبا یه حساب کاربری دارین? '''$1'''.",
 'gotaccountlink'          => 'اویدن به',
 'yourrealname'            => 'نام واقعی:',
 'prefs-help-realname'     => 'ذکر نام واقعی اختیاریه ایر تصمیم به گدن بگیرین هنگام ارجاع به آثارتو و انتساب هونو به ایسا زه نام واقعیتو استفاده ابوه',
@@ -332,7 +332,7 @@ $1',
 'anoneditwarning'        => "'''توجه:''' ایسا داخل سیستم نوابیدین.
 آی پی آدرستو درگزارش اصلاح صفحه ضبط ابوه.",
 'summary-preview'        => 'پیش نمایش - خلاصه:',
-'blockedtext'            => ' "<big>\'\'\'دسترسی نام کاربری یا نشانی اینترنتی ایسا بسته وابیده.\'\'\'</big>
+'blockedtext'            => ' "\'\'\'دسترسی نام کاربری یا نشانی اینترنتی ایسا بسته وابیده.\'\'\'
 ای کار توسط $1 انجام شده‌است.
 دلیلی که گده اینه: $2\'\'
 * آغاز قطع دسترسی: $8
@@ -589,7 +589,7 @@ $2',
 بوین $2 سی ثبت حذف آخر.',
 'deletedarticle'        => 'حذف وابید "[[$1]]"',
 'dellogpage'            => 'نمایه _ حذف',
-'deletecomment'         => 'دلیل سی حذف:',
+'deletecomment'         => 'دلیل:',
 'deleteotherreason'     => 'دیه/دلیل اضافی:',
 'deletereasonotherlist' => 'دلیل دیه',
 
@@ -599,7 +599,7 @@ $2',
 # Protect
 'protectlogpage'              => 'نمایه حفاظت وحمایت',
 'prot_1movedto2'              => '[[$1]] جابجا وابید به[[$2]]',
-'protectcomment'              => 'توضیح:',
+'protectcomment'              => 'دلیل:',
 'protectexpiry'               => 'سپری وابیده ها:',
 'protect_expiry_invalid'      => 'با سپری وابیدن وقت غیر معتبره.',
 'protect_expiry_old'          => 'سپری وابیدن وقت مربوط به گذشته.',
@@ -692,7 +692,7 @@ $2',
 'move-watch'       => 'پیگیری ای صفحه',
 'movepagebtn'      => 'جابجایی صفحه',
 'pagemovedsub'     => 'جابجایی با بخت وتوفیق انجام وابید',
-'movepage-moved'   => '<big>\'\'\'"$1" جابجا وابیده به "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved'   => '\'\'\'"$1" جابجا وابیده به "$2"\'\'\'', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'    => 'یه صفحه زه ای  نوم تقریبا موجوده, یا نومی که ایسا انتخاب کردین غیر  معتبره
 لطفا نوم دیه انتخاب کنین.',
 'talkexists'       => "'''آن صفحه خوس با بخت وتوفیق جابجا وابید, ولی صفحه صحبت نتره جابجا بوه چونکه یکی تقریبا موجوده درعنوان تازه 
