@@ -8,9 +8,9 @@
  * @file
  *
  * @author Kaszeba
+ * @author Kuvaly
  * @author Leinad
  * @author MinuteElectron
- * @author RobertL
  * @author Warszk
  * @author לערי ריינהארט
  */
@@ -142,7 +142,7 @@ $messages = array(
 'category-empty'         => "''Ta ktegòrëja nie zamëkô w se terô niżódnëch artiklów ni mediów.''",
 'listingcontinuesabbrev' => 'kònt.',
 
-'mainpagetext' => "<big>'''MediaWiki òsta zainstalowónô.'''</big>",
+'mainpagetext' => "'''MediaWiki òsta zainstalowónô.'''",
 
 'about'          => 'Ò serwise',
 'article'        => 'Artikel',
@@ -306,11 +306,13 @@ Przemëszlë dolmaczënié na [http://translatewiki.net/wiki/Main_Page?setlang=c
 
 # Login and logout pages
 'logouttitle'                => 'Wëlogòwanié brëkòwnika',
-'logouttext'                 => 'Të jes ju wëlogòwóny. Mòżesz prôcowac z {{SITENAME}} jakno anonimòwi brëkòwnik abò wlogòwac sã jakno zaregistrowóny brëkòwnik.',
+'logouttext'                 => 'Të jes ju wëlogòwóny.
+Mòżesz prôcowac z {{SITENAME}} jakno anonimòwi brëkòwnik abò wlogòwac sã jakno zaregistrowóny brëkòwnik.',
 'loginpagetitle'             => 'Logòwanié brëkòwnika',
 'yourname'                   => 'Miono brëkòwnika',
 'yourpassword'               => 'Twòja parola',
 'yourpasswordagain'          => 'Pòwtórzë parolã',
+'remembermypassword'         => 'Wdôrzë mòjé miono brëkòwnika na tim kòmpùtrze',
 'yourdomainname'             => 'Twòjô domena',
 'login'                      => 'Wlogùjë mie',
 'nav-login-createaccount'    => 'Logòwanié',
@@ -319,10 +321,10 @@ Przemëszlë dolmaczënié na [http://translatewiki.net/wiki/Main_Page?setlang=c
 'logout'                     => 'Wëlogùjë mie',
 'userlogout'                 => 'Wëlogòwanié',
 'notloggedin'                => 'Felëje logòwóniô',
-'nologin'                    => 'Ni môsz kònta? $1.',
+'nologin'                    => "Ni môsz kònta? '''$1'''.",
 'nologinlink'                => 'Ùsôdzë kònto',
 'createaccount'              => 'Założë nowé kònto',
-'gotaccount'                 => 'Masz ju kònto? $1.',
+'gotaccount'                 => "Masz ju kònto? '''$1'''.",
 'gotaccountlink'             => 'Wlogùjë',
 'createaccountmail'          => 'òb e-mail',
 'badretype'                  => 'Wprowadzone parole jinaczą sã midze sobą.',
@@ -372,11 +374,13 @@ Ni mòżesz miec ju wicy.',
 'accountcreated'             => 'Konto założone',
 'accountcreatedtext'         => 'Konto brëkòwnika dlô $1 je założone.',
 'createaccount-title'        => 'Kònto ùsôdzoné dlô {{SITENAME}}',
+'loginlanguagelabel'         => 'Jãzëk: $1',
 
 # Password reset dialog
-'oldpassword' => 'Stôrô parola:',
-'newpassword' => 'Nowô parola',
-'retypenew'   => 'Napiszë nową parolã jesz rôz',
+'oldpassword'               => 'Stôrô parola:',
+'newpassword'               => 'Nowô parola',
+'retypenew'                 => 'Napiszë nową parolã jesz rôz',
+'resetpass-submit-loggedin' => 'Zmiana parolë',
 
 # Edit page toolbar
 'bold_sample'     => 'Wëtłëszczony drëk',
@@ -412,7 +416,7 @@ Ni mòżesz miec ju wicy.',
 'showdiff'               => 'Wëskrzëni zmianë',
 'anoneditwarning'        => "'''Bôczë:''' Të nie je wlogòwóny. Twòjô adresa IP mdze zapisónô w historëji edicëji ti starnë.",
 'blockedtitle'           => 'Brëkòwnik je zascëgóny',
-'blockedtext'            => "<big>'''Twòje kònto abò ë IP-adresa òstałë zablokòwóné.'''</big>
+'blockedtext'            => "'''Twòje kònto abò ë IP-adresa òstałë zablokòwóné.'''
 
 Zablokòwôł je $1. 
 Pòdónô przëczëna to:''$2''.
@@ -487,6 +491,7 @@ Administrator, chtëren jã zablokòwôł, pòdôł przëczënã: $1",
 # Revision deletion
 'rev-delundel'   => 'pòkażë/zatacë',
 'revdel-restore' => 'Zjinaczë widzawnotã',
+'pagehist'       => 'Historëjô starnë',
 
 # Merge log
 'revertmerge' => 'Rozdzélë',
@@ -561,6 +566,7 @@ Administrator, chtëren jã zablokòwôł, pòdôł przëczënã: $1",
 'guesstimezone'         => 'Wezmi z przezérnika',
 'allowemail'            => 'Włączë mòżlewòtã sélaniô e-mailów òd jinëch brëkòwników',
 'defaultns'             => 'Domëslno przeszëkùjë nôslédné rëmnotë mionów:',
+'default'               => 'domëszlné',
 'files'                 => 'Lopczi',
 
 # User rights
@@ -569,6 +575,9 @@ Administrator, chtëren jã zablokòwôł, pòdôł przëczënã: $1",
 # Groups
 'group-sysop' => 'Sprôwnicë',
 
+'group-user-member'  => 'Brëkòwnik',
+'group-sysop-member' => 'Sprôwnicë',
+
 'grouppage-sysop' => '{{ns:project}}:Administratorzë',
 
 # Associated actions - in the sentence "You do not have permission to X"
@@ -621,7 +630,8 @@ Abë dodac lopk do starnë, ùżëjë ùniższegò lënka wedle nôslédnëch m
 * '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:Lopk.ogg]]</nowiki></tt>''' òtemknie prosti lënk do lopka bez wëskrzënianiô sómegò lopka",
 'uploadlog'         => 'Lësta wladënków',
 'uploadlogpage'     => 'Dołączoné',
-'uploadlogpagetext' => 'Hewò je lësta slédno wladowónëch lopków.\\nWszëtczé gòdzënë tikają conë ùniwersalnégò czasë.',
+'uploadlogpagetext' => 'Hewò je lësta slédno wladowónëch lopków.
+Wszëtczé gòdzënë tikają conë ùniwersalnégò czasë.',
 'filename'          => 'Miono lopka',
 'filedesc'          => 'Òpisënk',
 'fileuploadsummary' => 'Pòdrechòwanié:',
@@ -778,7 +788,7 @@ Czej chcesz remôc starnã z lëste ùzéronëch artiklów, klikni ''Òprzestôj
 'deletedarticle' => 'rëmniãté przez "[[$1]]"',
 'dellogpage'     => 'Rëmóné',
 'deletionlog'    => 'register rëmaniów',
-'deletecomment'  => 'Przëczëna rëmaniô',
+'deletecomment'  => 'Przëczëna:',
 
 # Rollback
 'rollback'       => 'Copnij edicëjã',
@@ -794,7 +804,7 @@ Slédnym ùsódzcą starnë bëł [[User:$3|$3]] ([[User talk:$3|Diskùsëjô]]{
 'unprotectedarticle'          => 'òdzychrowóny [[$1]]',
 'prot_1movedto2'              => '$1 przeniesłé do $2',
 'protect-legend'              => 'Pòcwierdzë zazychrowanié',
-'protectcomment'              => 'Przëczëna zazychrowóniô',
+'protectcomment'              => 'Przëczëna:',
 'protectexpiry'               => 'Wëgasô pò:',
 'protect_expiry_invalid'      => 'Lëchi czas wëgasniãcô.',
 'protect_expiry_old'          => 'Czas wëgasniãcô leżi w przińdnocë.',
@@ -846,7 +856,7 @@ Slédnym ùsódzcą starnë bëł [[User:$3|$3]] ([[User talk:$3|Diskùsëjô]]{
 # Block/unblock
 'blockip'            => 'Zascëgôj IP-adresã',
 'blockiptext'        => 'Brëkùje formùlarza niżi abë zascëgòwac prawò zapisënkù spòd gwësny adresë IP. To robi sã blós dlôte abë zascëgnąc wandalëznom, a bëc w zgòdze ze [[{{MediaWiki:Policy-url}}|wskôzama]]. Pòdôj przëczënã (np. dając miona starn, na chtërnëch dopùszczono sã wandalëzny).',
-'ipbreason'          => 'Przëczëna',
+'ipbreason'          => 'Przëczëna:',
 'badipaddress'       => 'IP-adresa nie je richtich pòdónô.',
 'blockipsuccesssub'  => 'Zascëgónié dało sã',
 'blockipsuccesstext' => 'Brëkòwnik [[Special:Contributions/$1|$1]] òstał zascëgóny.<br />
@@ -871,11 +881,11 @@ Biéj do [[Special:IPBlockList|lëstë zascëgónëch adresów IP]] abë òbacz
 'move-watch'              => 'Ùzérôj tã starnã',
 'movepagebtn'             => 'Przeniesë starnã',
 'pagemovedsub'            => 'Przeniesenié darzëło sã',
-'movepage-moved'          => '<big>\'\'\'"$1" òsta przeniosłô do "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved'          => '\'\'\'"$1" òsta przeniosłô do "$2"\'\'\'', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'Starna ò taczim mionie ju je abò nie je òno bezzmiłkòwé. Wëbierzë nowé miono.',
 'movedto'                 => 'przeniesłô do',
 'movetalk'                => 'Przeniesë téż starnã <i>Diskùsëje</i>, jeżle je to mòżlëwé.',
-'1movedto2'               => '$1 przeniesłé do $2',
+'1movedto2'               => '[[$1]] przeniesłé do [[$2]]',
 '1movedto2_redir'         => '[[$1]] przeniesłé do [[$2]] nad przeczérowanim',
 'movereason'              => 'Przëczëna:',
 'revertmove'              => 'copnij',
