@@ -122,7 +122,7 @@ $messages = array(
 'hidden-category-category' => 'Skjulte klynger', # Name of the category where hidden categories will be listed
 'listingcontinuesabbrev'   => 'førtgøte',
 
-'mainpagetext'      => "<big>'''MediaWiki er nu installeret.'''</big>",
+'mainpagetext'      => "'''MediaWiki er nu installeret.'''",
 'mainpagedocfooter' => "Se vores engelskspråĝede [http://meta.wikimedia.org/wiki/MediaWiki_localisation dokumentåsje tilpasnenge'm åf æ brugergrænseflade] og [http://meta.wikimedia.org/wiki/MediaWiki_User%27s_Guide æ brugervejlednenge] før åplysnenger åpsætnenge'm og anvendelse.",
 
 'about'          => 'Åm',
@@ -326,10 +326,10 @@ Førespørgsel: $2',
 'userlogin'               => 'Åpret æ konto æller loĝ på',
 'logout'                  => 'Loĝ åf',
 'userlogout'              => 'Loĝ åf',
-'nologin'                 => 'Du har engen brugerkonto? $1.',
+'nologin'                 => "Du har engen brugerkonto? '''$1'''.",
 'nologinlink'             => 'Åpret ny brugerkonto',
 'createaccount'           => 'Åpret en ny konto',
-'gotaccount'              => 'Du har ålerede en brugerkonto? $1.',
+'gotaccount'              => "Du har ålerede en brugerkonto? '''$1'''.",
 'gotaccountlink'          => 'Loĝ på',
 'youremail'               => 'E-mail:',
 'yourrealname'            => 'Dit rigtege navn*',
@@ -393,7 +393,7 @@ Før en e-mail ken modtages åf andre brugere åf æ {{SITENAME}}-mailfunksje, s
 'showdiff'               => 'Ves ændrenger',
 'anoneditwarning'        => "Du arbejder uden at være loĝget på. Estedet før brugernav veses så'n IP-adresse i'n hersenengerskigt.",
 'summary-preview'        => 'Førhåndsvesnenge åf beskrevelselejne:',
-'blockedtext'            => "<big>'''Dit brugernav æller din IP-adresse er blevet blokeret.'''</big>
+'blockedtext'            => "'''Dit brugernav æller din IP-adresse er blevet blokeret.'''
 
 Æ blokerenge er lavet åf $1. Æ begrundelse er ''$2''.
 
@@ -414,7 +414,7 @@ Du ken ekke bruge æ funksje 'e-mail til denne bruger' vemendre der er ångevet
 'previewnote'            => "'''Husk at dette er kun en førhåndsvesnenge, æ side er ekke gemt endnu!'''",
 'editing'                => 'Redigærer $1',
 'editingsection'         => 'Redigærer $1 (åfsnet)',
-'copyrightwarning'       => "'''Husk: <big>åpskrev engen websider</big>, søm ekke tilhører dig selv, brug <big>engen åphavsretsligt beskyttede værker</big> uden tilladelse frå'n ejer!'''<br />
+'copyrightwarning'       => "'''Husk: åpskrev engen websider, søm ekke tilhører dig selv, brug engen åphavsretsligt beskyttede værker uden tilladelse frå'n ejer!'''<br />
 Du lover os hermed, at du selv '''har skrevet skrevselenger''', at skrevselenger tilhører ålmenheden, er ('''åpværer hus'''), æller at æ '''åphavsrets-endehaver''' har gevet sen '''tilladelse'''. Ves denne skrevselenger ålerede er åfentliggkort andre steder, skrev det venligst på æ diskusjesside.
 <i>Bemærk venligst, at ål {{SITENAME}}-ertikler åtomatisk står under „$2“ (se $1 før lileskrevselenger). Ves du ekke vel, at dit arbejde her ændres og udbredes åf andre, så tryk ekke på „Gem“.</i>",
 'longpagewarning'        => "'''ADVARSEL: Denne side er $1 kilobyte stor; nogle browsere ken have pårblæmer ve at redigære sider der nærmer sig æller er større end 32 kb. 
@@ -640,7 +640,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 'addedwatch'        => 'Tilføjet til din åvervågnengsliste',
 'addedwatchtext'    => "Æ side \"[[:\$1]]\" er blevet tilføjet til din [[Special:Watchlist|åvervågningsliste]]. Fremtidige ændrenger til denne side og den tilhørende diskusjeside hvil bleve listet der, og æ side hvil fremstå '''fremhævet''' i'n [[Special:RecentChanges|liste ve de seneste ændrenger]] før at gøre det lettere at finde den. Hves du senere hvilst fjerne'n side frå din åvervågningsliste, så klik \"Fjern åvervågnenge\".",
 'removedwatch'      => 'Fjernet frå åvervågnengsliste',
-'removedwatchtext'  => 'Æ side "<nowiki>$1</nowiki>" er blevet fjernet frå din åvervågnengsliste.',
+'removedwatchtext'  => 'Æ side "[[:$1]]" er blevet fjernet frå din åvervågnengsliste.',
 'watch'             => 'Åvervåg',
 'watchthispage'     => 'Åvervåg side',
 'unwatch'           => 'Fjern åvervågnenge',
@@ -661,7 +661,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 'deletedtext'           => '"<nowiki>$1</nowiki>" er slettet. Sæg $2 før en førtegnelse åver de nyeste sletnenger.',
 'deletedarticle'        => 'slettede "[[$1]]"',
 'dellogpage'            => 'Sletnengslog',
-'deletecomment'         => 'Begrundelse før sletnenge:',
+'deletecomment'         => 'Begrundelse:',
 'deleteotherreason'     => 'Anden/uddybende begrundelse:',
 'deletereasonotherlist' => 'Anden begrundelse',
 
@@ -671,7 +671,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 # Protect
 'protectlogpage'              => 'Liste åver beskyttede sider',
 'prot_1movedto2'              => '[[$1]] flyttet til [[$2]]',
-'protectcomment'              => 'Begrundelse før beskyttelse',
+'protectcomment'              => 'Begrundelse:',
 'protectexpiry'               => 'Udløb:',
 'protect_expiry_invalid'      => 'Æ udløbstiid er ugyldeg.',
 'protect_expiry_old'          => "Æ udløbstiid legger i'n førtiid.",
@@ -687,7 +687,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 'protect-expiring'            => 'til $1 (UTC)',
 'protect-cascade'             => 'Nedarvende spærrenge – ål skabelåner, søm er endbundet i denne side spærres også.',
 'protect-cantedit'            => 'Du kenst ekke ændre beskyttelsesnivå før denne side, da du ekke kenst redigære føden.',
-'protect-expiry-options'      => '1 tême:1 hour,2 têmer:2 hours,6 têmer:6 hours,1 dåĝ:1 day,3 dåĝ:3 days,1 uge:1 week,2 uger:2 weeks,1 måned:1 month,3 måneder:3 months,1 år:1 year,ubegrænset:indefinite', # display1:time1,display2:time2,...
+'protect-expiry-options'      => '1 tême:1 hour,1 dåĝ:1 day,1 uge:1 week,2 uger:2 weeks,1 måned:1 month,3 måneder:3 months,6 måneder:6 months,1 år:1 year,ubegrænset:indefinite', # display1:time1,display2:time2,...
 'restriction-type'            => 'Beskyttelsesståt',
 'restriction-level'           => 'Beskyttelseshøjde',
 
@@ -754,7 +754,7 @@ I disse tilfælde er du nødt til at flytte æller sammenflette'n side manuelt."
 'move-watch'       => 'Denne side åvervåges',
 'movepagebtn'      => 'Flyt side',
 'pagemovedsub'     => 'Flytnenge gennemført',
-'movepage-moved'   => '<big>Æ side \'\'\'"$1" er flyttet til "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved'   => 'Æ side \'\'\'"$1" er flyttet til "$2"\'\'\'', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'    => 'En side ve det navn eksisterer ålrede, æller det
 navn du harst valgt er ekke gyldegt. Vælg et andet navn.',
 'talkexists'       => 'Æ side blev flyttet korrekt, men den tilhørende diskusjeside ken ekke flyttes, førdi der ålrede eksisterer en ve den nye titel. Du erst nødt til at flette dem sammen manuelt.',
