@@ -1,7 +1,14 @@
 <?php
 /** Maori (Māori)
  *
- * @addtogroup Language
+ * See MessagesQqq.php for message documentation incl. usage of parameters
+ * To improve a translation please visit http://translatewiki.net
+ *
+ * @ingroup Language
+ * @file
+ *
+ * @author Kiharoa
+ * @author Sonia
  */
 
 $messages = array(
@@ -26,20 +33,12 @@ $messages = array(
 'november'  => 'Whiringa-ā-rangi',
 'december'  => 'Hakihea',
 
-'mainpage' => 'Hau Kāinga',
-
-'portal'         => 'Tomokanga hapori',
-'portal-url'     => 'Project:Tomokanga hapori',
-'help'           => 'Whakamārama',
-'sitesupport'    => 'Koha',
 'cancel'         => 'Whakakore',
 'qbspecialpages' => 'Whārangi motuhake',
 'mytalk'         => 'Karere mōku',
 'navigation'     => 'Huarahi',
 
-'currentevents'     => 'Kōrero',
-'currentevents-url' => 'Project:Kōrero',
-
+'help'             => 'Whakamārama',
 'search'           => 'Rapua',
 'go'               => 'Haere',
 'history'          => 'Kōrero Nehe',
@@ -49,14 +48,26 @@ $messages = array(
 'edit'             => 'Whakatika',
 'delete'           => 'tangohia',
 'protect'          => 'Whakangungua',
+'talkpagelinktext' => 'Kōrerohia',
 'talk'             => 'Kōrerorero',
 'toolbox'          => 'Pouaka utauta',
 
+# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
+'aboutsite'            => 'Mo {{SITENAME}}',
+'currentevents'        => 'Kōrero',
+'currentevents-url'    => 'Project:Kōrero',
+'mainpage'             => 'Hau Kāinga',
+'mainpage-description' => 'Hau Kāinga',
+'portal'               => 'Tomokanga hapori',
+'portal-url'           => 'Project:Tomokanga hapori',
+'privacy'              => 'Tikanga tūmataiti',
+'privacypage'          => 'Project:Tikanga tūmataiti',
+
 'toc'     => 'Rārangi kōrero',
 'showtoc' => 'whakakite',
 'hidetoc' => 'hunaia',
 
-# Short words for each namespace, by default used in the 'article' tab in monobook
+# Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'     => 'tuhi pānui',
 'nstab-template' => 'papa tauira',
 'nstab-help'     => 'Āwhina',
@@ -77,24 +88,27 @@ $messages = array(
 'hide'          => 'Hunaia',
 'show'          => 'Whakaaturia',
 
+# Recent changes linked
+'recentchangeslinked' => 'Rerekētanga pū tahi',
+
 # Upload
 'upload' => 'Tuku atu',
 
-# Miscellaneous special pages
-'allpages'            => 'Ngā whārangi katoa',
-'randompage'          => 'Tipihaere',
-'specialpages'        => 'Whārangi motuhake',
-'recentchangeslinked' => 'Rerekētanga pū tahi',
-'move'                => 'Nekehia',
+# Random page
+'randompage' => 'Tipihaere',
 
-# Special:Allpages
+# Miscellaneous special pages
+'move' => 'Nekehia',
+
+# Special:AllPages
+'allpages'       => 'Ngā whārangi katoa',
 'allpagessubmit' => 'Haere',
 
 # Watchlist
-'watchlist' => 'Rārangi mātaki',
+'watchlist'   => 'Rārangi mātaki',
 'mywatchlist' => 'Rārangi mātaki',
-'watch'     => 'Mātaki',
-'unwatch'   => 'kāti te mātaki',
+'watch'       => 'Mātaki',
+'unwatch'     => 'kāti te mātaki',
 
 # Contributions
 'contributions' => 'Ngā mahi a tēnei mema',
@@ -106,6 +120,7 @@ $messages = array(
 # Namespace 8 related
 'allmessages' => 'Pānui pūnaha',
 
+# Special:SpecialPages
+'specialpages' => 'Whārangi motuhake',
+
 );
-
-
