@@ -182,14 +182,14 @@ $messages = array(
 'talkpagelinktext'  => 'Bolela',
 'specialpage'       => 'Matlaka a itšeng',
 'personaltools'     => "Dithulusu tša gago (''personal'')",
-'postcomment'       => 'Romela tshwayotshwayo',
+'postcomment'       => 'Sekgao se sempsha',
 'articlepage'       => 'Nyakoretša letlakala la mateng',
 'talk'              => 'Poledišano',
 'views'             => 'Dinyakorêtšo',
 'toolbox'           => 'Lepokisi la dithulusu',
 'userpage'          => 'Nyakorela letlakala la mošomiši',
 'projectpage'       => 'Nyakoretša letlakala la tirotherwa',
-'imagepage'         => 'Nyakoretša letlakala la seswantšho',
+'imagepage'         => "Nyakoretša letlakala la ''file''",
 'mediawikipage'     => 'Nyakoretša letlakala la melaetša',
 'templatepage'      => "Nyakoretša letlakala la ''template''",
 'viewhelppage'      => 'Nyakoretša letlakala la thušo',
@@ -228,7 +228,7 @@ $messages = array(
 
 'badaccess'        => 'Thušo ya tumello',
 'badaccess-group0' => 'Ga wa dumelwa go dira seo o lekago go se dira.',
-'badaccess-groups' => 'Seo o lekago go se dra se dumelwetše go bašomiši bao balego  sehlopheng se tee sa  $1.',
+'badaccess-groups' => 'Seo o lekago go se dira se dumelwetše go bašomiši bao balego {{PLURAL:$2|dihlopeng tša|sehlopheng sa}}: $1.',
 
 'versionrequired'     => 'Version $1 ya MediaWiki ea hlokega',
 'versionrequiredtext' => 'Version $1 ya MediaWiki ea hlokega go šomiša letlakala le. Lebelela [[Special:Version|letlakala la version]].',
@@ -250,12 +250,12 @@ $messages = array(
 'site-rss-feed'           => '$1 RSS Feed',
 'site-atom-feed'          => '$1 Atom Feed',
 'page-rss-feed'           => '"$1" RSS Feed',
-'red-link-title'          => '$1 (ga ese ya ngwadiwa)',
+'red-link-title'          => '$1 (ga e hwetšagale)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Letlakala',
 'nstab-user'      => 'Letlakala la mošomiši',
-'nstab-special'   => 'Itšeng',
+'nstab-special'   => 'Letlakala le itšeng',
 'nstab-project'   => 'Letlakala la tirotherwa',
 'nstab-image'     => 'Faele',
 'nstab-mediawiki' => 'Molaetša',
@@ -303,10 +303,10 @@ Tšhupaleloko (''account'') ya gago e tlhodilwe. O seke wa lebala go fetola [[Sp
 'logout'                     => 'Etšwa/Tswalela',
 'userlogout'                 => 'Etšwa/Tswalela',
 'notloggedin'                => 'Ga wa tsena',
-'nologin'                    => 'A  o nale sedi ya go tsena? $1.',
+'nologin'                    => "A  o nale sedi ya go tsena? '''$1'''.",
 'nologinlink'                => "Bula tšhupaleloko (''account'')",
 'createaccount'              => 'Bula tšhupaleloko',
-'gotaccount'                 => 'O šetše o nale tšhupaleloko? $1.',
+'gotaccount'                 => "O šetše o nale tšhupaleloko? '''$1'''.",
 'gotaccountlink'             => 'Tsena',
 'createaccountmail'          => 'ka e-mail',
 'badretype'                  => 'Ditlhaka-tša-siphiri tše o di šomišitšego ga di swane.',
@@ -323,7 +323,9 @@ Le swanela goba fase ga $1 {{PLURAL:$1|ya tlhaka|ya ditlhaka}}',
 'noname'                     => 'Gawa fana ka leina la mošomiši la go loka.',
 'loginsuccesstitle'          => 'O tsene ka katlego',
 'loginsuccess'               => "'''Bjale o tsene go {{SITENAME}} bjalo ka \"\$1\".'''",
-'nosuchuser'                 => 'Ga gona mošomiši wa leina la "$1". Lebele mopeleto wa gago goba [[Special:UserLogin/signup|o tlhome mošomiši yo mophsa]].',
+'nosuchuser'                 => 'Ga gona mošomiši wa leina la "$1". 
+Maina a huduetša ke ditlhaka.
+Lebele mopeleto wa gago goba [[Special:UserLogin/signup|o tlhome mošomiši yo mophsa]].',
 'nosuchusershort'            => 'Ga gona mošomiši wa leina la "<nowiki>$1</nowiki>". Hlokomela mopeleto wa gago.',
 'nouserspecified'            => 'O swanela ke go fana ka leina la mošomiši.',
 'wrongpassword'              => 'O loketše ditlhaka-tša-siphiri tšeo e sego tšona. Ka kgopelo, leka gape.',
@@ -400,7 +402,7 @@ Ga wa dumelwa go tlhoma tše dingwe.',
 'anoneditwarning'        => "'''Temošo''' Gawa ''tsena'', IP ya gago e tla šumišwa go histori ya diphetogo tša letlakala",
 'summary-preview'        => 'Lebelela kakaretšo:',
 'blockedtitle'           => 'Mošomiši o thibilwe',
-'blockedtext'            => "<big>'''Leina la gago la mošomiši goba IP atrese e thibilwe.'''</big>
+'blockedtext'            => "'''Leina la gago la mošomiši goba IP atrese e thibilwe.'''
 
 O thibilwe ke $1. Makaba a go thiba ke ''$2''.
 
@@ -435,7 +437,7 @@ Ga eba o le fa ka phošo, o ka boela morago ka go šumiša konopo ya '''back'''
 'previewnote'            => "'''Ye ke Taetšo ya sebopego sa letlakala fela; diphetogo ga di ya bolokwa!'''",
 'editing'                => 'O fetola $1',
 'editingsection'         => 'Phetolo ya $1 (sekgoba)',
-'editingcomment'         => 'Fetola $1 (tshwayotshwayo)',
+'editingcomment'         => 'O fetola $1 (sekgao se sempsha)',
 'editconflict'           => 'Tholano ya diphetogo: $1',
 'yourtext'               => 'Mongwalo wa gago',
 'storedversion'          => 'Version yeo e bolokilwego',
@@ -493,7 +495,7 @@ Leka [[Special:Search|go fetleka wikii]] go humana matlakala a mapsha.',
 # Revision deletion
 'rev-delundel'        => 'Bontšha/Fihla',
 'revdelete-hide-text' => 'Fihla dihlaka tša poeletšo',
-'revdelete-log'       => "Ahlaahla ''log'':",
+'revdelete-log'       => 'Lebaka:',
 
 # History merging
 'mergehistory-from' => 'Letlakala la mothopo:',
@@ -544,7 +546,7 @@ Leka [[Special:Search|go fetleka wikii]] go humana matlakala a mapsha.',
 'userrights-editusergroup' => 'Fetola sehlopha sa bašomiši',
 'saveusergroups'           => 'Boloko Dihlopha tša bašomiši',
 'userrights-groupsmember'  => 'Leloko la:',
-'userrights-reason'        => 'Lebaka lago fetola:',
+'userrights-reason'        => 'Lebaka:',
 'userrights-no-interwiki'  => 'Gawa dumelwa go fetola di dumello tša mošumiši go di wiki tše dingwe.',
 
 # Groups
@@ -600,7 +602,7 @@ Matlakala ago ba [[Special:Watchlist|lenanong la gago la matlakala ditlhapetšo]
 'filesource'        => 'Mothopo:',
 'savefile'          => 'Boloka faele',
 'uploadedimage'     => '"[[$1]]" e loketšwe',
-'watchthisupload'   => 'Tlhapetša letlakala le',
+'watchthisupload'   => "Tlhapetša ''faele'' ye",
 
 'license-nopreview'  => '(Ponopele ga e gona)',
 'upload_source_file' => '(faele go khomphuthara ya gago)',
@@ -640,7 +642,7 @@ Matlakala ago ba [[Special:Watchlist|lenanong la gago la matlakala ditlhapetšo]
 'filedelete'                  => 'Phumula $1',
 'filedelete-legend'           => 'Phumula faele',
 'filedelete-intro'            => "O phumula '''[[Media:$1|$1]]'''.",
-'filedelete-comment'          => 'Lebaka la go phumula:',
+'filedelete-comment'          => 'Lebaka:',
 'filedelete-submit'           => 'Phumula',
 'filedelete-success'          => "'''$1''' e phumutšwe.",
 'filedelete-nofile'           => "'''$1''' ga e gona.",
@@ -802,7 +804,7 @@ Ka kgopela sitlediša gore ke se o nyakago  go sedira, le gore o kwešiša ditla
 Lebelela $2 go hweetša sedi ka diphulo tša bjale.',
 'deletedarticle'        => 'E phumutšwe "[[$1]]"',
 'dellogpage'            => "''Log'' yago phumula",
-'deletecomment'         => 'Lebaka la go phumula:',
+'deletecomment'         => 'Lebaka:',
 'deleteotherreason'     => 'Mabaka a mangwe:',
 'deletereasonotherlist' => 'Mabaka a mangwe',
 
@@ -815,7 +817,7 @@ Lebelela $2 go hweetša sedi ka diphulo tša bjale.',
 'protectedarticle'            => 'lotilwe "[[$1]]"',
 'prot_1movedto2'              => '[[$1]] e hudugile goya go [[$2]]',
 'protect-legend'              => 'Tiišetša go lota',
-'protectcomment'              => 'Ahlaahla:',
+'protectcomment'              => 'Lebaka:',
 'protectexpiry'               => 'Fetatšatši:',
 'protect_expiry_invalid'      => 'Fetatšatši, nako ye ga ya dumelwa.',
 'protect_expiry_old'          => 'Fetatšatši ke ya nako yeo e fetilego.',
@@ -927,7 +929,7 @@ Ge go le bjalo,o tla swanela ke go huduša goba go kopanya matlakala ka bowena."
 'move-watch'              => 'Tlhapetša letlakala le',
 'movepagebtn'             => 'Huduša letlakala',
 'pagemovedsub'            => 'Hudugile ka katlego',
-'movepage-moved'          => '<big>\'\'\'"$1" e hudušitšwe go "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved'          => '\'\'\'"$1" e hudušitšwe go "$2"\'\'\'', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'Letlakala la goba le leina le legona, goba
 leina leo o le kgethilego ga la dumelega.
 Ka kgopelo, kgetha leina le lengwe.',
@@ -1024,7 +1026,7 @@ $1',
 'nextdiff'     => 'Diphapano tše dimpšha →',
 
 # Media information
-'widthheightpage'      => '$1×$2, $3 matlakala',
+'widthheightpage'      => '$1×$2, $3 {{PLURAL:$3|letlakala|matlakala}}',
 'file-info-size'       => '($1 × $2 pixel, bogolo ba faele: $3, Mohuta wa MIME: $4)',
 'file-nohires'         => "<small>Gago ''resolution'' ya go feta mo.</small>",
 'svg-long-desc'        => '(SVG faele, nominally $1 × $2 pixels, bogolo ba faele: $3)',
@@ -1092,7 +1094,7 @@ letlakala la seswantšho ge tafola ya metadata e bulwa. Tše dingwe tša di ''fi
 'table_pager_empty' => 'Ga gona sepheto',
 
 # Auto-summaries
-'autosumm-new' => 'Letlakala le lefsa: $1',
+'autosumm-new' => "Tlhodile letlakala ka '$1'",
 
 # Watchlist editor
 'watchlistedit-numitems'      => 'Lenano la gago la ditlhapetšo le na le  {{PLURAL:$1|thaetlele ye tee|di thaetlele tše $1}}, re sa bale matlakala a dipolelo.',
