@@ -8,6 +8,8 @@
  * @file
  *
  * @author Agzennay
+ * @author Aryaz
+ * @author Dalinanir
  * @author Jose77
  * @author Urhixidur
  */
@@ -21,149 +23,155 @@ $messages = array(
 'thu'           => 'Akwas',
 'fri'           => 'Asimwas',
 'sat'           => 'Asiḍyas',
-'january'       => 'Yannayer',
+'january'       => 'Yennayer',
 'february'      => 'Yebrayer',
-'march'         => 'Mars',
-'april'         => 'Yebrir',
-'may_long'      => 'Mayu',
+'march'         => 'Mares',
+'april'         => 'Ibrir',
+'may_long'      => 'May',
 'june'          => 'Yunyu',
-'july'          => 'Yulyu',
-'august'        => 'ɣuct',
+'july'          => 'Yulyuz',
+'august'        => 'Ghuct',
 'september'     => 'Cutanbir',
-'october'       => 'Ktubr',
+'october'       => 'Ktubar',
 'november'      => 'Nuwanbir',
 'december'      => 'Dujanbir',
-'january-gen'   => 'Yannayer',
-'february-gen'  => 'Yebrayer',
+'january-gen'   => 'Ynnayr',
+'february-gen'  => 'Ybrayr',
 'march-gen'     => 'Mars',
-'april-gen'     => 'Yebrir',
-'may-gen'       => 'Mayu',
+'april-gen'     => 'Ibrir',
+'may-gen'       => 'May',
 'june-gen'      => 'Yunyu',
-'july-gen'      => 'Yulyu',
-'august-gen'    => 'ɣuct',
+'july-gen'      => 'Yulyuz',
+'august-gen'    => 'Ghuct',
 'september-gen' => 'Cutanbir',
-'october-gen'   => 'Ktubr',
+'october-gen'   => 'Ktubar',
 'november-gen'  => 'Nuwanbir',
 'december-gen'  => 'Dujanbir',
-'jan'           => 'Yannayer',
+'jan'           => 'Yennayer',
 'feb'           => 'Yebrayer',
 'mar'           => 'Mars',
-'apr'           => 'Yebrir',
-'may'           => 'Mayu',
+'apr'           => 'Ybrir',
+'may'           => 'May',
 'jun'           => 'Yunyu',
-'jul'           => 'Yulyu',
-'aug'           => 'ɣuct',
+'jul'           => 'Yulyuz',
+'aug'           => 'Ghuct',
 'sep'           => 'Cutanbir',
-'oct'           => 'Ktubr',
+'oct'           => 'Ktubar',
 'nov'           => 'Nuwanbir',
 'dec'           => 'Dujanbir',
 
 # Categories related messages
-'category_header'        => 'Tasna di Taggayt "$1"',
+'category_header'        => 'Tasniwin di taggayt "$1"',
 'subcategories'          => 'Tadu-ggayin',
 'category-media-header'  => 'Media di category "$1"',
 'category-empty'         => "''Taggayt a war dags bu ca n Tasna niɣ ca n umedia.''",
-'listingcontinuesabbrev' => 'Amesedfar.',
+'listingcontinuesabbrev' => 'arni-d.',
 
 'about'          => 'Xef',
 'newwindow'      => '(Areẓm di tburjet d-tamaynut)',
-'cancel'         => 'ur tegg ca',
-'qbfind'         => 'Aff',
+'cancel'         => 'Sbdd',
+'qbfind'         => 'Af',
 'qbedit'         => 'Ẓṛeg',
 'qbspecialpages' => 'Tudmawin Special',
-'mytalk'         => 'Asiwl inu',
-'navigation'     => 'Asari',
+'mytalk'         => 'Amsawal inu',
+'navigation'     => 'Tagriwa',
 
 'errorpagetitle'   => 'Anezri',
-'returnto'         => 'Dwal ɣar $1.',
+'returnto'         => 'Dwl ghar $1.',
 'tagline'          => 'Zi {{SITENAME}}',
 'help'             => 'Tallalt',
 'search'           => 'Tarezzut',
-'searchbutton'     => 'Tarezzut',
+'searchbutton'     => 'Rzu',
 'go'               => 'Raḥ ɣa',
-'searcharticle'    => 'Raḥ',
+'searcharticle'    => 'Uyur',
 'history'          => 'Amzruy n Tasna',
-'history_short'    => 'Amzruy',
-'printableversion' => 'Tunɣilt n usiggez',
-'permalink'        => 'Tazdayt war tbeddil',
+'history_short'    => 'Amezruy',
+'printableversion' => 'Tanghelt n usiggez',
+'permalink'        => 'Tamghunt iqqimen',
 'edit'             => 'Ẓṛeg',
-'editthispage'     => 'Ẓṛeg Tasna ya',
-'delete'           => 'Kkes',
-'protect'          => 'ẓarq',
+'create'           => 'Egg',
+'editthispage'     => 'Ẓṛg tasna ya',
+'delete'           => 'Kks',
+'protect'          => 'Mstn',
 'newpage'          => 'Tasna d-tamaynut',
-'talkpage'         => 'siwl x Tasna ya',
+'talkpage'         => 'Siwl xf tasna ya',
 'talkpagelinktext' => 'Awal',
-'personaltools'    => 'imassen inu',
-'talk'             => 'Asiwl',
-'views'            => 'Tiẓritin',
-'toolbox'          => 'imassen',
-'redirectedfrom'   => '(i twassek-ad zi $1)',
+'personaltools'    => 'Imassen inu',
+'talk'             => 'siwel',
+'views'            => 'Timmeẓṛa',
+'toolbox'          => 'Tanakat n imassen',
+'otherlanguages'   => 'S tutlayin nneḍni',
+'redirectedfrom'   => '(Itwasnnmd-d zi $1)',
 'redirectpagesub'  => 'Tasna n (Redirect)',
-'jumpto'           => 'Ndu ɣar:',
-'jumptonavigation' => 'Asari',
+'jumpto'           => 'Nḍu ghar:',
+'jumptonavigation' => 'tagriwa',
 'jumptosearch'     => 'tarezzut',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
-'aboutsite'            => 'Xef {{SITENAME}}',
-'aboutpage'            => 'Project:Xef',
+'aboutsite'            => 'Awal xef {{SITENAME}}',
+'aboutpage'            => 'Project:Awal xef',
 'copyrightpage'        => '{{ns:project}}:izrefan ussenɣel',
 'currentevents'        => 'Mayn itemsaren rux',
 'currentevents-url'    => 'Project:mayn itmesaren ruxa',
-'disclaimers'          => 'ismigilen',
-'disclaimerpage'       => 'Project:Asmigl n umatu',
+'disclaimers'          => 'Ismigilen',
+'disclaimerpage'       => 'Project:Asmigel amatu',
 'edithelp'             => 'Tallalt deg uẓareg',
 'edithelppage'         => 'Help:Aẓareg',
 'helppage'             => 'Help:tallalt',
-'mainpage'             => 'Tasna Tamzwarut',
+'mainpage'             => 'Tasna Tamezwarut',
 'mainpage-description' => 'Tasna Tamzwarut',
 'portal'               => 'Tawwart n timetti',
 'portal-url'           => 'Project:tawwart n timetti',
-'privacy'              => 'Tasertit taslgant',
-'privacypage'          => 'Project:Tasertit taslgant',
+'privacy'              => 'Tasertit n tusligi',
+'privacypage'          => 'Project:Tasertit n tusligi',
 
-'retrievedfrom'       => 'itwar-d zi "$1"',
-'youhavenewmessages'  => 'ɣak $1 ($2).',
+'retrievedfrom'       => 'Itwarr-d zi "$1"',
+'youhavenewmessages'  => 'Ghar-k / Ghar-m $1 ($2).',
 'newmessageslink'     => 'tibratin timaynutin',
 'newmessagesdifflink' => 'Taẓṛigt tanggarut',
 'editsection'         => 'Ẓṛeg',
 'editold'             => 'ẓṛeg',
+'editlink'            => 'ẓṛg',
+'viewsourcelink'      => 'ẓṛ aghbalu',
 'editsectionhint'     => 'Ẓṛeg tigezmi: $1',
-'toc'                 => 'Contents',
-'showtoc'             => 'Ẓar',
+'toc'                 => 'Iktturn',
+'showtoc'             => 'sskn-d',
 'hidetoc'             => 'snuffar',
-'site-rss-feed'       => 'Asudem n RSS n $1',
-'site-atom-feed'      => 'Asudem n Atom n $1',
+'site-rss-feed'       => 'Tilgha n RSS n $1',
+'site-atom-feed'      => 'Talghut n Atom n $1',
 'page-rss-feed'       => 'Asudem n RSS n "$1"',
+'red-link-title'      => '$1 (tasna ur telli)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
+'nstab-main'     => 'Tasna',
 'nstab-user'     => 'Tasna n User',
 'nstab-project'  => 'Tasna usenfar',
-'nstab-image'    => 'Afaylu',
-'nstab-template' => 'Tamudemt',
+'nstab-image'    => 'Asatul',
+'nstab-template' => 'Tamudmt',
 'nstab-category' => 'Taggayt(category)',
 
 # General errors
 'badtitle'       => 'isem war icni ca',
 'badtitletext'   => 'Isem n Tasna itexised war icni ca, ixwa, niɣ  isem n ajar-tutlayt niɣ ajar-wiki war icni ca.
 teqqad ad yilli days ca n usekkil war itwagg deg isem .',
-'viewsource'     => 'Ẓar aɣbal',
+'viewsource'     => 'Ẓṛ aghbalu',
 'viewsourcefor'  => 'i $1',
 'viewsourcetext' => 'Tzemred a tẓerd u atsneɣled aɣbal n Tasna ya :',
 
 # Login and logout pages
-'yourname'                => 'isem useqdac:',
-'yourpassword'            => 'Taguri n wadaf:',
+'yourname'                => 'Izwl-usqdac:',
+'yourpassword'            => 'Tawalt n wadaf:',
 'remembermypassword'      => 'ejj (login) inu deg uselkim a',
-'login'                   => 'Adeff',
-'nav-login-createaccount' => 'Adeff / egg amiḍan',
+'login'                   => 'Adf',
+'nav-login-createaccount' => 'Adef / egg amiḍan',
 'loginprompt'             => "itxessa ad-teṭfed (''cookies'') bac ad tadfed ɣar {{SITENAME}}.",
-'userlogin'               => 'Adeff / egg amiḍan',
-'logout'                  => 'Ffeɣ',
-'userlogout'              => 'Ffeɣ',
-'nologin'                 => 'war ɣark login? $1.',
+'userlogin'               => 'Adf / egg amiḍan',
+'logout'                  => 'Ufugh',
+'userlogout'              => 'Ufugh',
+'nologin'                 => "war ɣark login? '''$1'''.",
 'nologinlink'             => 'Egg amiḍan',
 'createaccount'           => 'Egg amiḍan',
-'gotaccount'              => 'ɣark  amiḍan? $1.',
+'gotaccount'              => "ɣark  amiḍan? '''$1'''.",
 'gotaccountlink'          => 'Adeff',
 'yourrealname'            => 'isem n deṣṣaḥ :',
 'prefs-help-realname'     => 'isem inec n deṣṣaḥ mala txesad waha .
@@ -198,9 +206,9 @@ zzat ma ca n e-mail nniḍen ma ad itwasekk ɣar umiḍan , ixessa ad tegged man
 
 # Edit page toolbar
 'bold_sample'     => 'Tirra tizurarin',
-'bold_tip'        => 'Tirra tizurarin',
+'bold_tip'        => 'Tira tizurarin',
 'italic_sample'   => 'Tirra titalyanin',
-'italic_tip'      => 'Tirra titalyanin',
+'italic_tip'      => 'Tira ifrghn.',
 'link_sample'     => 'isem n tzedayt',
 'link_tip'        => 'Tazdayt n dixl',
 'extlink_sample'  => 'http://www.example.com isem n tezdayt',
@@ -218,17 +226,17 @@ zzat ma ca n e-mail nniḍen ma ad itwasekk ɣar umiḍan , ixessa ad tegged man
 
 # Edit pages
 'summary'                => 'Tagḍwit:',
-'subject'                => 'Subject/headline:',
+'subject'                => 'Abatu/izwl:',
 'minoredit'              => 'Ta d taẓrigt d-tamẓeyant',
-'watchthis'              => 'Ẓar Tasna ya',
-'savearticle'            => 'Ḥaḍ Tasna',
+'watchthis'              => 'Ḥḍa tasna ya',
+'savearticle'            => 'Xmml tasna',
 'preview'                => 'Azar-ascan',
 'showpreview'            => 'Ẓar Azar-ascan',
 'showdiff'               => 'Ẓar mayn teẓṛegd.',
 'anoneditwarning'        => "'''ɣark:''' war tudifd ca s isem inec.
 Tansa n IP inac ad-teqqim deg umezruy n teẓṛigin n Tasna ya .",
 'summary-preview'        => 'Azar-ascan n Tegḍwit:',
-'blockedtext'            => "<big>'''Isem useqdac niɣ tansa IP inecc tewabluca  .'''</big>
+'blockedtext'            => "'''Isem useqdac niɣ tansa IP inecc tewabluca  .'''
 
 iblocat  $1.
 Maynzi ''$2''.
@@ -245,7 +253,10 @@ maṛṛa manaya deg ujenna eggit di tabrat i ɣ-ad tsekked.",
 'newarticletext'         => "Tdefar-d tazdayt n Tasna εad war telli .
 bac ad tegged , arri di taflwit a swadday (xemm i [[{{MediaWiki:Helppage}}| Tasna n Tallalt]] i ineɣmisen ifruryen).
 mala qacek da s ɣalaṭ waha, tecca di tbutunt n '''deffar''' di (browser) inec .",
-'noarticletext'          => 'walu tirra di Tasna ya , tzemred [[Special:Search/{{PAGENAME}}|a tarzud isem n Tasna ya]] di Tasniwin nniḍn niɣ [{{fullurl:{{FULLPAGENAME}}|action=edit}} egg Tasna ya cek].',
+'noarticletext'          => 'Rxxu ur din llint ca tira di tasna ya.
+Tzmmard [[Special:Search/{{PAGENAME}}|rzu xf yizwl n tasna ya]] di tasniwin nnḍni,
+<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} search the related logs],
+nigh [{{fullurl:{{FULLPAGENAME}}|action=edit}} edit this page]</span>.',
 'previewnote'            => "'''Wa d Azar-ascan waha;
 tiẓṛigin εad war twaḥḍent!'''",
 'editing'                => 'Aẓṛag di $1',
@@ -276,49 +287,63 @@ tzemred addewred ɣar deffar, niɣ [[Special:UserLogin|Adeff niɣ egg amiḍan]]
 'previousrevision'       => '←Affegged n zik/zic',
 'nextrevision'           => 'Afegged d amaynu→',
 'currentrevisionlink'    => 'Afegged n rux',
-'cur'                    => 'N ruxa',
+'cur'                    => '',
 'last'                   => 'anggaru',
 'page_first'             => 'amzwaru',
 'page_last'              => 'anggaru',
 'histlegend'             => 'imṣebḍiyen: Sti(ixter) tibuttonin a ɣar wadday n tunɣilin n Tasna bac ad tsmzazal(compare).<br />
 Tasarut: (cur) = imṣebḍiyen ag tunɣilt n ruxa,
 (last) = imṣebḍiyen ag tunɣilt n zik, M = taẓrigt d-tamẓeyant.',
-'history-fieldset-title' => 'Amezruy',
-'histfirst'              => 'Amzwaru qaε',
-'histlast'               => 'Anggaru qaε',
+'history-fieldset-title' => 'Amzruy n min tẓṛid',
+'histfirst'              => 'Amzwaru n marra',
+'histlast'               => 'Anggaru n marra',
 
 # Revision feed
 'history-feed-item-nocomment' => '$1 ɣar $2', # user at time
 
+# Revision deletion
+'rev-delundel' => 'sken/ffer',
+
 # Diffs
 'history-title'           => 'Amezruy n ufegged n "$1"',
 'difference'              => '(Amsebḍi jar ifeggiden)',
 'lineno'                  => 'Tabrit $1:',
 'compareselectedversions' => 'Smequdda tunɣilin a',
-'editundo'                => 'Dwel',
+'editundo'                => 'kkes min ggigh',
 'diff-multi'              => '({{PLURAL:$1|ijj n ufegged|$1 ifeggiden}} war ad twamlen ca.)',
 
 # Search results
-'noexactmatch' => "'''war telli ca n Tasna qarn-as \"\$1\".'''
+'searchresults'             => 'Tifellawin n tarezzut',
+'searchresults-title'       => 'Tifellawin n tarezzut xef "$1"',
+'searchsubtitle'            => 'Trezzud xef \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|marra tasniwin issentan s "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|marra tasniwin iteqqnen ghar "$1"]])',
+'noexactmatch'              => "'''war telli ca n Tasna qarn-as \"\$1\".'''
 tzemred ad [[:\$1|tarnid cek]].",
-'prevn'        => 'zzat $1',
-'nextn'        => 'deffar $1',
-'viewprevnext' => 'Ẓar ($1) ($2) ($3)',
-'searchall'    => 'maṛṛa',
-'powersearch'  => 'Tarezzut cwa-cway',
+'prevn'                     => 'zzat $1',
+'nextn'                     => 'deffar $1',
+'viewprevnext'              => 'Ẓar ($1) ($2) ($3)',
+'search-result-size'        => '$1 ({{PLURAL:$2|1 tawalt|$2 tiwalin}})',
+'search-suggest'            => 'Ttugha txsd a tinid: $1',
+'search-interwiki-caption'  => 'Awmatn n usnfar',
+'search-interwiki-more'     => '(ujar)',
+'search-mwsuggest-enabled'  => 's isumuren',
+'search-mwsuggest-disabled' => 'walu isumuren',
+'searchall'                 => 'maṛṛa',
+'powersearch'               => 'Tarzzut tanmhazt',
+'powersearch-legend'        => 'Tarzzut tanmhazt',
 
 # Preferences page
-'preferences'       => 'Isemyifiyen',
+'preferences'       => 'Ismyifiyn',
 'mypreferences'     => 'Isemyifiyen inu',
 'searchresultshead' => 'Tarzzut',
 
 # Groups
-'group-all' => '(maṛṛa)',
+'group-sysop' => 'Indbaln',
+'group-all'   => '(maṛṛa)',
 
 'grouppage-sysop' => '{{ns:project}}:inedbalen',
 
 # User rights log
-'rightslog' => 'Aɣmis n izerfan n useqdac',
+'rightslog' => 'Aghmis n talghut n izrfan n usqdac',
 
 # Recent changes
 'nchanges'                       => '$1 {{PLURAL:$1|tiẓṛegt|tiẓṛigin}}',
@@ -343,14 +368,15 @@ tzemred ad [[:\$1|tarnid cek]].",
 'boteditletter'                  => 'b',
 
 # Recent changes linked
-'recentchangeslinked'          => 'Tiẓṛigin ag ta',
+'recentchangeslinked'          => 'Isenfilen i yudsen wa',
 'recentchangeslinked-title'    => 'Tiẓṛigin ssaɣant-id ɣar "$1"',
 'recentchangeslinked-noresult' => 'War llint ca n tiẓṛigin di Tasna ya di lwaqt id-tucid .',
-'recentchangeslinked-summary'  => "Ta d Tabdart n tirra itwaggen εad mamk di Tasna id-izedyen zeg ijjen n Tasna nniḍn (niɣ iwdan zi category nniḍn).
-Tasniwin di [[Special:Watchlist|Tabdart uḥṭṭu inec]] d '''tizurarin'''.",
+'recentchangeslinked-summary'  => "Ta d tabdart n isnfiln itwaggn drus zggwami di tasniwin id-iqqnen zg ict tasna nniḍn (nigh iqqnen ghar iwdan zi ca n taggayt).
+Tasniwin di [[Special:Watchlist|your watchlist]] d '''tizurarin'''.",
+'recentchangeslinked-page'     => 'Izwl n tasna:',
 
 # Upload
-'upload'            => 'Zdem-d afaylu',
+'upload'            => 'Zdem-d asatul',
 'uploadbtn'         => 'Zdem-d afaylu',
 'uploadlogpage'     => 'Zdem-d aɣmis',
 'filedesc'          => 'Asgbr',
@@ -362,11 +388,11 @@ Tasniwin di [[Special:Watchlist|Tabdart uḥṭṭu inec]] d '''tizurarin'''.",
 'listfiles' => 'Tabdart n ifayluten',
 
 # File description page
-'filehist'                  => 'Amzruy n ufaylu',
+'filehist'                  => 'Amzruy n usatul',
 'filehist-help'             => 'Tka di date/time bac ad tẓerd afaylu mamec ja d-itban di Lwaqt a .',
 'filehist-deleteone'        => 'sfaḍ',
-'filehist-current'          => 'Lux a',
-'filehist-datetime'         => 'Azemz/Akud',
+'filehist-current'          => 'aturaw',
+'filehist-datetime'         => 'Azmz/Akud',
 'filehist-user'             => 'Aseqdac',
 'filehist-dimensions'       => 'Tisektiwin',
 'filehist-filesize'         => 'Tiddi n ufaylu',
@@ -440,14 +466,14 @@ Tasniwin di [[Special:Watchlist|Tabdart uḥṭṭu inec]] d '''tizurarin'''.",
 'listusers'               => 'Tabdart n iseqdacen',
 'newpages'                => 'Tasniwin timaynutin',
 'ancientpages'            => 'Tasniwin n zik qqaε',
-'move'                    => 'Snaql',
-'movethispage'            => 'snaql Tasna ya',
+'move'                    => 'Smutti',
+'movethispage'            => 'Smutti tasna ya',
 'pager-newer-n'           => '{{PLURAL:$1|amynu 1|amynu $1}}',
 'pager-older-n'           => '{{PLURAL:$1|aqbur 1|aqbur $1}}',
 
 # Book sources
-'booksources'    => 'iɣbalen n udlis',
-'booksources-go' => 'Raḥ ɣa',
+'booksources'    => 'Ighbula n udlis',
+'booksources-go' => 'Uyur',
 
 # Special:Log
 'specialloguserlabel'  => 'Aseqdac:',
@@ -456,13 +482,13 @@ Tasniwin di [[Special:Watchlist|Tabdart uḥṭṭu inec]] d '''tizurarin'''.",
 'all-logs-page'        => 'Maṛṛa iɣmisen',
 
 # Special:AllPages
-'allpages'       => 'Maṛṛa Tasniwin',
+'allpages'       => 'Marra tasniwin',
 'alphaindexline' => '$1 ɣa $2',
 'nextpage'       => 'Tasna zzat ($1)',
 'prevpage'       => 'Tasna zzat ($1)',
 'allpagesfrom'   => 'Scan-d Tasniwin beddant zi:',
-'allarticles'    => 'Maṛṛa Tasniwin',
-'allpagessubmit' => 'Raḥ ɣa',
+'allarticles'    => 'Marra tasniwin',
+'allpagessubmit' => 'Uyur',
 'allpagesprefix' => 'Ẓar Tasniwin s usekkil amzwaru:',
 
 # Special:Categories
@@ -485,48 +511,48 @@ Tasniwin di [[Special:Watchlist|Tabdart uḥṭṭu inec]] d '''tizurarin'''.",
 'addedwatchtext'    => 'Tasna "[[:$1]]" Temmarni ɣar [[Special:Watchlist|Tabdart uḥṭṭu]].',
 'removedwatch'      => 'twakkes zi Tabdart uḥṭṭu',
 'removedwatchtext'  => 'Tasna "[[:$1]]" twakkes zi [[Special:Watchlist|Tabdart uḥṭṭu inec]].',
-'watch'             => 'Ẓar',
-'watchthispage'     => 'Ẓar Tasna ya',
-'unwatch'           => 'War-twaẓer',
+'watch'             => 'Ḥḍa',
+'watchthispage'     => 'Ḥḍa tasna ya',
+'unwatch'           => 'Ur ḥṭṭa',
 'watchlist-details' => '{{PLURAL:$1|$1 n Tasniwin|$1 n Tasniwin}} Twaẓrent bla Tasniwin n usiwl.',
 'wlshowlast'        => 'Sseml-ad $1 tisεεatin $2 ussan $3 inggura',
 
 # Displayed when you click the "watch" button and it is in the process of watching
-'watching'   => 'Twaxmim...',
-'unwatching' => 'War-twaxmim...',
+'watching'   => 'Ḥṭṭigh...',
+'unwatching' => 'Ur ḥṭṭigh...',
 
 # Delete
-'deletepage'            => 'kkes Tasna',
+'deletepage'            => 'Kks tasna',
 'delete-legend'         => 'Sfaḍ',
 'historywarning'        => 'ɣark: Tasna i txisd atekesd ɣars amzruy :',
-'confirmdeletetext'     => 'Ɛlayn ad-tsfded Tasna ag maṛṛa amzruy ines.
-Ma nican txisd ad tekkesd, ma tesned mayn tegged, u tegget am mamec teqqar  [[{{MediaWiki:Policy-url}}|tasretit]].',
+'confirmdeletetext'     => 'Ur d ac iqqim walu a tsfḍed ict tasna ak marra amzruy nns.
+Ma nican txsd a tggd manaya? Ma tssnd min ttggd? Ma ttggd manaya amc teqqaṛ  [[{{MediaWiki:Policy-url}}|tasrtit n Wiki]] ?',
 'actioncomplete'        => 'Tiggawt tsala',
 'deletedtext'           => '"<nowiki>$1</nowiki>" Twakkes.
 Xemm $2 i tikkas timaynutin.',
 'deletedarticle'        => 'twakkes "[[$1]]"',
 'dellogpage'            => 'Aɣmis n uṣfaḍ',
-'deletecomment'         => 'Mayemmi ɣa tteksed:',
+'deletecomment'         => 'Ssebba:',
 'deleteotherreason'     => 'Ca n ssebba nniḍn:',
 'deletereasonotherlist' => 'Ssebba nniḍn',
 
 # Rollback
-'rollbacklink' => 'Ar-ad',
+'rollbacklink' => 'Sdwl ghar dffar',
 
 # Protect
-'protectlogpage'              => 'Aɣmis n uẓarq',
+'protectlogpage'              => 'Aghmis n umstn',
 'prot_1movedto2'              => '[[$1]] twaneql ɣa [[$2]]',
-'protectcomment'              => 'Tinit:',
-'protectexpiry'               => 'itsala:',
-'protect_expiry_invalid'      => 'Akud n usali war icni ca.',
-'protect_expiry_old'          => 'Akud usali yeεda.',
+'protectcomment'              => 'Ssebba:',
+'protectexpiry'               => 'Itsala:',
+'protect_expiry_invalid'      => 'Akud n usali ur illi nican.',
+'protect_expiry_old'          => 'Akud usali izri, idwl d amzruy.',
 'protect-unchain'             => 'Arzem turagin n usnaqel',
 'protect-text'                => "tzemred ad teẓṛed u atbedeld aswir n uḥeṭṭu n Tasna ya da '''<nowiki>$1</nowiki>'''.",
 'protect-locked-access'       => "Amiḍan inecc war ɣars turagt bac ad ibeddel aswir n uḥeṭṭu n Tasna .
 Aqa (settings) n Tasna '''$1''':",
 'protect-cascadeon'           => 'Tasna ya tẓarq ruxa mayenzi tudef di {{PLURAL:$1|Tasna, iɣa illa|Tasniwin, iɣa illa}} aḥeṭṭu n usmuzzar(cascading protection).
 Tezemred ad tbedeld aswir n uḥeṭṭu n Tasna ya, maca war itegg walu i uḥeṭṭu n usmuzzar(cascading protection).',
-'protect-default'             => '(amzwar)',
+'protect-default'             => 'Ejj marra isqdacn.',
 'protect-fallback'            => 'itxessat turagt n "$1"',
 'protect-level-autoconfirmed' => 'Bluka iseqdacen war ɣasen ca amiḍan',
 'protect-level-sysop'         => 'inedbalen waha',
@@ -535,8 +561,8 @@ Tezemred ad tbedeld aswir n uḥeṭṭu n Tasna ya, maca war itegg walu i uḥe
 'protect-cascade'             => 'Ḥḍa Tasniwin i yudfen di Tasna ya (cascading protection)',
 'protect-cantedit'            => 'war tezemred ca ad tbedeld iswiren n uḥeṭṭu n Tasna ya, mayenzi war ɣark turagt bac ad tẓṛegd.',
 'protect-expiry-options'      => '2 tasεεat:2 hours,1 ass:1 day,3 ussan:3 days,1 amalass:1 week,2 imallasen:2 weeks,1 ayur:1 month,3 iyuren:3 months,6 iyuren:6 months,1 asggas:1 year,infinite:infinite', # display1:time1,display2:time2,...
-'restriction-type'            => 'turagt:',
-'restriction-level'           => 'Aswir usekref:',
+'restriction-type'            => 'Turagt:',
+'restriction-level'           => 'Aswir uskref:',
 
 # Restrictions (nouns)
 'restriction-edit' => 'Arri',
@@ -546,46 +572,50 @@ Tezemred ad tbedeld aswir n uḥeṭṭu n Tasna ya, maca war itegg walu i uḥe
 'undelete-search-submit' => 'Tarzzut',
 
 # Namespace form on various pages
-'namespace'      => 'Raq n isem:',
+'namespace'      => 'Tallunt-izwel:',
 'invert'         => 'Dren mayn testid (tixtard)',
-'blanknamespace' => '(Amenzaw)',
+'blanknamespace' => '(Amezwaru)',
 
 # Contributions
 'contributions' => 'Tiggawin n useqdac',
 'mycontris'     => 'Tiggawin inu',
 'contribsub2'   => 'i $1 ($2)',
-'uctop'         => '(ajnna)',
-'month'         => 'Zeg ayur (ar amzwaru):',
-'year'          => 'Zi asgg°as (d zik):',
+'uctop'         => '(snnj)',
+'month'         => 'Zg wayur (d zik):',
+'year'          => 'Zg usggwas (d zik):',
 
 'sp-contributions-newbies'     => 'Ẓar Tabdart n tiggawin n useqdac a deg umiḍan amaynu waha',
 'sp-contributions-newbies-sub' => 'i imiḍan imaynuten',
-'sp-contributions-blocklog'    => 'Aɣmis n iẓariqqen',
+'sp-contributions-blocklog'    => 'sbdd tabdart n talghut',
 'sp-contributions-search'      => 'Arzu x tiggawin',
 'sp-contributions-username'    => 'Tansa IP d isem useqdac:',
 'sp-contributions-submit'      => 'Tarzzut',
 
 # What links here
-'whatlinkshere'       => 'Mayn id-izedyen da',
-'whatlinkshere-title' => 'Tasniwin id-izedyen ɣar "$1"',
-'linkshere'           => "Tasna ya tzedi ɣa '''[[:$1]]''':",
-'nolinkshere'         => "war tlli ca n Tasna tqqen-d da '''[[:$1]]'''.",
-'isredirect'          => 'Tasna n (redirect)',
-'istemplate'          => 'Asidef',
-'whatlinkshere-prev'  => '{{PLURAL:$1|deffar|deffar $1}}',
-'whatlinkshere-next'  => '{{PLURAL:$1|zzat|zzat $1}}',
-'whatlinkshere-links' => '← tizdayin',
+'whatlinkshere'           => 'Min iteqqnen ghar da',
+'whatlinkshere-title'     => 'Tasniwin id-izedyen ɣar "$1"',
+'whatlinkshere-page'      => 'Tasna:',
+'linkshere'               => "Tasna ya tzedi ɣa '''[[:$1]]''':",
+'nolinkshere'             => "war tlli ca n Tasna tqqen-d da '''[[:$1]]'''.",
+'isredirect'              => 'Tasna n (redirect)',
+'istemplate'              => 'Asidef',
+'isimage'                 => 'amaqqan n tugna',
+'whatlinkshere-prev'      => '{{PLURAL:$1|deffar|deffar $1}}',
+'whatlinkshere-next'      => '{{PLURAL:$1|zzat|zzat $1}}',
+'whatlinkshere-links'     => '← tizdayin',
+'whatlinkshere-hidelinks' => '$1 timqqan',
 
 # Block/unblock
-'blockip'            => 'Bluka aseqdac a',
-'ipboptions'         => '2 tasεεat:2 hours,1 ass:1 day,3 ussan:3 days,1 amalass:1 week,2 imallasen:2 weeks,1 ayur:1 month,3 iyuren:3 months,6 iyuren:6 months,1 asggas:1 year,infinite:infinite', # display1:time1,display2:time2,...
-'ipblocklist'        => 'Tabdart n tansiwin IP d isemawen n iseqdacen ig iteblukan',
-'ipblocklist-submit' => 'Tarzzut',
-'blocklink'          => 'Ẓareqq',
-'unblocklink'        => 'Arzem',
-'contribslink'       => 'Tiggawin',
-'blocklogpage'       => 'Ẓareqq aɣmis',
-'blocklogentry'      => 'ibloka [[$1]] ar $2 $3',
+'blockip'                  => 'Sbdd asqdac a',
+'ipboptions'               => '2 n timirin:2 hours,1 n wass:1 day,3 n wussan:3 days,1 imalass:1 week,2 imallassn:2 weeks,1 wayur:1 month,3 wayurn:3 months,6 wayurn:6 months,1 asggwas:1 year,tartalla:infinite', # display1:time1,display2:time2,...
+'ipblocklist'              => 'Tabdart n tansiwin IP d isemawen n iseqdacen ig iteblukan',
+'ipblocklist-submit'       => 'Tarzzut',
+'blocklink'                => 'Sbedd',
+'unblocklink'              => 'Ṛẓem',
+'contribslink'             => 'Tiggawin',
+'blocklogpage'             => 'Ẓareqq aɣmis',
+'blocklogentry'            => 'ibloka [[$1]] ar $2 $3',
+'block-log-flags-nocreate' => 'timggit n imiḍanen imaynutn ttwasbdd',
 
 # Move page
 'movepagetext'     => "mala tesxedmed taseddast(form) a swadday, ad tessenaqled maṛṛa amzruy ines ɣar isem amaynu.
@@ -604,22 +634,22 @@ manaya itebeddal Tasniwin, ixessa ad tesned mliḥ man tegged zzat ma ad tkemled
 *Mala war tixtard tabelludt a swadday.
 
 mala amya, itxessa cekk ad tesnaqled s ufus mala txisd.",
-'movearticle'      => 'Snaqel Tasna:',
-'newtitle'         => 'ɣar isem amaynu:',
+'movearticle'      => 'Smutti tasna:',
+'newtitle'         => 'Ghar yizwl amaynu:',
 'move-watch'       => 'Ẓar Tasna ya',
 'movepagebtn'      => 'Snaqel Tasna',
-'pagemovedsub'     => 'Asnaqel itwagg',
-'movepage-moved'   => '<big>\'\'\'"$1" twanql ɣar "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'pagemovedsub'     => 'Asmutti itwagg',
+'movepage-moved'   => '\'\'\'"$1" twanql ɣar "$2"\'\'\'', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'    => 'Tasna s isem a tella da, niɣ isem itucid war icni.
 ixdar isem nniḍn.',
 'talkexists'       => "'''Tasna twanql , maca Tasna n usiwl ins war twanqel ca maymmi qaddin ict nninḍ.
 snaqlitent s ufus.'''",
-'movedto'          => 'snaql ɣa',
+'movedto'          => 'smutti ghar',
 'movetalk'         => 'Snaqel Tasniwin n usiwl igg illan akid-s',
 '1movedto2'        => '[[$1]] twaneql ɣa [[$2]]',
 'movelogpage'      => 'Snaql aɣmis',
 'movereason'       => 'Ssebba:',
-'revertmove'       => 'war tegg ca',
+'revertmove'       => 'sedwel',
 
 # Export
 'export' => 'Sekk tasniwin',
@@ -628,7 +658,7 @@ snaqlitent s ufus.'''",
 'allmessages' => 'inzan n unagraw',
 
 # Thumbnails
-'thumbnail-more'  => 'Semɣar',
+'thumbnail-more'  => 'Smghar',
 'thumbnail_error' => 'Error creating thumbnail: $1',
 
 # Import log
@@ -640,39 +670,46 @@ snaqlitent s ufus.'''",
 'tooltip-pt-preferences'          => 'Isemyifiyen inu',
 'tooltip-pt-watchlist'            => 'Tabdart n Tasniwin umi txmamd bac ad-ten teẓṛegd',
 'tooltip-pt-mycontris'            => 'Tabdart n tiggawin inu',
-'tooltip-pt-login'                => 'Neqqar-ac adeff, macca war illi bessif .',
-'tooltip-pt-logout'               => 'Ffeɣ',
-'tooltip-ca-talk'                 => 'Asiwl x mayn dag-s di Tasna',
-'tooltip-ca-edit'                 => 'Tzemred ad tẓerged Tasna ya. Tca x tabutunt n Azar-ascan ẓẓat ma ad teḥḥaḍed .',
+'tooltip-pt-login'                => 'Neqqar ac adef s umiḍan nnek; maca malla texsed waha',
+'tooltip-pt-logout'               => 'Ufugh',
+'tooltip-ca-talk'                 => 'Amsawal xef tasna n ukettur',
+'tooltip-ca-edit'                 => 'Tzemmared a tẓeṛged tasna ya.
+Bbeẓ x ufeskar n uzar-timeẓṛi zzat i gha txemmled min turid',
 'tooltip-ca-addsection'           => 'Arni tinit deg usiwl a.',
 'tooltip-ca-viewsource'           => 'Tasna ya tẓarq. tzemred atẓred aɣbal ines.',
+'tooltip-ca-history'              => 'Isughulen izrin n tasna ya.',
 'tooltip-ca-protect'              => 'Ẓarq Tasna ya',
-'tooltip-ca-delete'               => 'Kkes Tasna ya',
+'tooltip-ca-delete'               => 'Kks Tasna ya',
 'tooltip-ca-move'                 => 'Snaql Tasna a',
-'tooltip-ca-watch'                => 'Arni Tasna ya ɣar Tebdart uḥṭṭu inec',
+'tooltip-ca-watch'                => 'Arni tasna ya ghar tbdart uḥṭṭu nnc',
 'tooltip-ca-unwatch'              => 'Kkes Tasna ya zi Tabdart uḥṭṭu inec',
-'tooltip-search'                  => 'Tarezzut {{SITENAME}}',
+'tooltip-search'                  => 'Rzu {{SITENAME}}',
+'tooltip-search-go'               => 'Uyur ghar tasna s yizwel a s imant nnes malla tella',
+'tooltip-search-fulltext'         => 'Rzu di tasniwin x waḍṛis a',
 'tooltip-p-logo'                  => 'Tasbtirt Tamzwarut',
-'tooltip-n-mainpage'              => 'Raḥ ɣar Tasna Tamzwarut',
-'tooltip-n-portal'                => 'Xef usenfar, mayn tezmerd ad tegged, mani ɣa tafed tiɣawsiwin',
-'tooltip-n-currentevents'         => 'Aff tilɣa(informations) x manaya',
-'tooltip-n-recentchanges'         => 'Tabdart n teẓṛigin timaynutin di wiki.',
-'tooltip-n-randompage'            => 'Ẓar Tasna zi ṭṭarf',
-'tooltip-n-help'                  => 'Mani ɣar tafd.',
-'tooltip-t-whatlinkshere'         => 'Tabdart n maṛṛa Tasniwin n wiki id-iqnen da',
+'tooltip-n-mainpage'              => 'Adef ghar tasna tamezwarut',
+'tooltip-n-portal'                => 'Xf usenfar, mayn tzemmared a tegged, mani gha tafed tighawsiwin',
+'tooltip-n-currentevents'         => 'Af tilgha n ugilal xf tmsarin titurawin',
+'tooltip-n-recentchanges'         => 'Tabdart n isenfilen imaynuten di Wiki.',
+'tooltip-n-randompage'            => 'Zdem ict tasna d tagacurant',
+'tooltip-n-help'                  => 'Mani gha tessned',
+'tooltip-t-whatlinkshere'         => 'Tabdart n marra tasniwin n Wiki i d-iteqqnen da',
+'tooltip-t-recentchangeslinked'   => 'Isenfilen n drus zggwami di tasniwin i yetwaqqnen zi tasna ya',
 'tooltip-t-contributions'         => 'Ẓar Tabdart n tiggawin n useqdac a',
 'tooltip-t-emailuser'             => 'Sekk e-mail i bnadem a',
-'tooltip-t-upload'                => 'Zdem-d ifayluten',
-'tooltip-t-specialpages'          => 'Tabdart n maṛṛa Tasniwin timeẓlayin',
+'tooltip-t-upload'                => 'Zdem-d isatulen',
+'tooltip-t-specialpages'          => 'Tabdart n marra tasniwin tinemmezrayin',
+'tooltip-t-print'                 => 'Tanghelt usiggez n tasna ya',
+'tooltip-ca-nstab-main'           => 'Ẓeṛ tasna n ukettur',
 'tooltip-ca-nstab-user'           => 'Ẓar Tasna n user',
-'tooltip-ca-nstab-project'        => 'Ẓar Tasna n usenfar',
+'tooltip-ca-nstab-project'        => 'Ẓṛ tasna n usnfar',
 'tooltip-ca-nstab-image'          => 'Ẓar Tasna n ufaylu',
-'tooltip-ca-nstab-template'       => 'Ẓar Tamudemt',
+'tooltip-ca-nstab-template'       => 'Ẓṛ tamudmt',
 'tooltip-ca-nstab-help'           => 'Ẓar Tasna n tallalt',
-'tooltip-ca-nstab-category'       => 'Ẓar Tasna n taggayt(category)',
+'tooltip-ca-nstab-category'       => 'Ẓṛ tasna n taggayt',
 'tooltip-minoredit'               => 'egg-itt d taẓṛigt tamẓyant',
-'tooltip-save'                    => 'Ḥaḍ-itt',
-'tooltip-preview'                 => 'Ẓar mayn turid, zzat ma ad teḥḥaḍed!',
+'tooltip-save'                    => 'Xmml isnfiln nnk',
+'tooltip-preview'                 => 'Ẓṛ mayn turid, zzat i t gha txmmld!',
 'tooltip-diff'                    => 'Ẓar tiẓṛigin i teggid deg uḍṛiṣ a.',
 'tooltip-compareselectedversions' => 'Ẓar imsebeḍiyen jar tunɣilin n Tasna ya.',
 'tooltip-watch'                   => 'Arni Tasna ya ɣa Tabdart uḥṭṭu inec',
@@ -704,9 +741,9 @@ kur tazdayt tdeffad a tmekkas .',
 'metadata-help'     => 'Afaylu a ɣar-s tilɣa(informations) nniḍn, teqqad ad tili tarnitent camera niɣ scanner i tiggin.
 mala afaylu a itwabeddel x mamec ja illa g umezwaru, ca n tilɣa teqqad ad ilint msebḍant x ufaylu amezwaru.',
 'metadata-expand'   => 'Sicen-d tilɣa nnumɣarent',
-'metadata-collapse' => 'Senuffar tilɣa innumɣarent',
-'metadata-fields'   => 'Tilɣa(informations)n EXIF ig illan di Tasna ya ad banent di Tasna n tewlaft xmi ɣar twassemɣar taflwit(table) n metadata.
-mayn nniḍn ad itwasenfar.
+'metadata-collapse' => 'Snuffar tilgha innumgharn',
+'metadata-fields'   => 'Igran n EXIF metadata i yllan di tbrat a ad adfn di tasna n twlaft xmnni d-gha twḍa  tflwit n metadata.
+Innḍni ad twaffrn dg umzwar.
 * make
 * model
 * datetimeoriginal
@@ -722,9 +759,9 @@ mayn nniḍn ad itwasenfar.
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'maṛṛa',
 'imagelistall'     => 'maṛṛa',
-'watchlistall2'    => 'maṛṛa',
-'namespacesall'    => 'maṛṛa',
-'monthsall'        => 'maṛṛa',
+'watchlistall2'    => 'marra',
+'namespacesall'    => 'marra',
+'monthsall'        => 'marra',
 
 # Multipage image navigation
 'imgmultigo' => 'Raḥ ɣa!',
@@ -745,6 +782,6 @@ mayn nniḍn ad itwasenfar.
 'fileduplicatesearch-submit' => 'Tarzzut',
 
 # Special:SpecialPages
-'specialpages' => 'Tasniwin timeẓlayin',
+'specialpages' => 'Tasniwin tinemmezrayin',
 
 );
