@@ -167,7 +167,9 @@ $messages = array(
 
 # Login and logout pages
 'logouttitle'                => 'San avri akana',
-'logouttext'                 => 'Akana san avryal i {{SITENAME}}. Shai te labyares {{SITENAME}} sar ekh bijanglo jeno vai shai te prinjares tut palem sar o jeno le kadale navesa vai le aver navesa.',
+'logouttext'                 => "'''Akana san avryal i {{SITENAME}}.'''
+
+Shai te labyares {{SITENAME}} sar ekh bijanglo jeno vai shai te prinjares tut palem sar o jeno le kadale navesa vai le aver navesa.",
 'welcomecreation'            => '== Mishto avilyan, $1! ==
 
 Akana si tuke ekh akont. Te na bistares te paruves, kana trebul tuke, tire kamimata kai {{SITENAME}}.',
@@ -183,7 +185,7 @@ Akana si tuke ekh akont. Te na bistares te paruves, kana trebul tuke, tire kamim
 'userlogout'                 => 'De avri',
 'nologinlink'                => 'Ker ek akount',
 'createaccount'              => 'Ker ek nevo akount',
-'gotaccount'                 => 'Si tuke akana ekh akonto? $1.',
+'gotaccount'                 => "Si tuke akana ekh akonto? '''$1'''.",
 'gotaccountlink'             => 'De andre',
 'createaccountmail'          => 'palal o e-mail',
 'badretype'                  => 'Le nakhavipnaske lava so lekhavdyan nai myazutne.',
