@@ -7,10 +7,12 @@
  * @ingroup Language
  * @file
  *
+ * @author Avicennasis
  * @author Derek Ross
  * @author Malafaya
  * @author OchAyeTheNoo
  * @author Omnipaedista
+ * @author The Evil IP address
  * @author Urhixidur
  * @author Ushanka
  * @author sco.wikipedia.org editors
@@ -134,8 +136,9 @@ $messages = array(
 'category-article-count-limited' => 'The follaein {{PLURAL:$1|page|$1 pages}} is in this category.',
 'category-file-count'            => '{{PLURAL:$2|This category hauds juist the ae follaein file.|The follaein {{PLURAL:$1|file|$1 files}}s is in this category, oot o $2 total.}}',
 'category-file-count-limited'    => 'The follaein {{PLURAL:$1|file is|$1 files is}} in this category.',
+'listingcontinuesabbrev'         => 'cont.',
 
-'mainpagetext'      => "<big>'''MediaWiki haes been installit wi speed.'''</big>",
+'mainpagetext'      => "'''MediaWiki haes been installit wi speed.'''",
 'mainpagedocfooter' => "Aks the [http://meta.wikimedia.org/wiki/Help:Contents Uiser's Manual] for speirins aboot using the wiki saftware.
 
 == Gettin startit ==
@@ -259,6 +262,7 @@ $messages = array(
 'editsection'             => 'edit',
 'editold'                 => 'edit',
 'viewsourceold'           => 'ken soorce',
+'editlink'                => 'edit',
 'viewsourcelink'          => 'Scance ower the source',
 'editsectionhint'         => 'Edit section: $1',
 'toc'                     => 'Table o contents',
@@ -294,9 +298,9 @@ $messages = array(
 Ye micht hae mistyped the URL, or follaed a wrang link
 This micht forby be caused by a bug in the saftware uised by {{SITENAME}}.",
 'nosuchspecialpage' => 'Nae sic byordinar page',
-'nospecialpagetext' => "<big>'''Ye hae requestit an invalid byordinar page.'''</big>
+'nospecialpagetext' => '<strong>Ye hae requestit an invalid byordinar page.</strong>
 
-A leet o valid byordinar pages can be funnd at [[Special:SpecialPages|{{int:specialpages}}]].",
+A leet o valid byordinar pages can be funnd at [[Special:SpecialPages|{{int:specialpages}}]].',
 
 # General errors
 'error'                => 'Error',
@@ -319,6 +323,8 @@ Maistly this is caused by follaein an ootdated diff or history link tae a page t
 
 If this isna the case, you micht hae fund a bug in the saftware.
 Please lat an [[Special:ListUsers/sysop|administrator]] ken aboot this, makin note o the URL.',
+'missingarticle-rev'   => '(revision#: $1)',
+'missingarticle-diff'  => '(Diff: $1, $2)',
 'readonly_lag'         => 'The database haes been autaematically lockit while the sclave database servers catch up tae the maister',
 'internalerror'        => 'Internal mishanter',
 'internalerror_info'   => 'Internal error: $1',
@@ -359,7 +365,10 @@ The grunds for this are: ''$2''.",
 
 # Login and logout pages
 'logouttitle'                => 'Uiser logoot',
-'logouttext'                 => "Ye'r nou loggit oot. Ye can continue to uise {{SITENAME}} namelessly, or ye can log in again as the same or as a different uiser. Mynd that some pages micht continue tae be displayed as if ye war aye loggit in, till ye clear yer brouser cache.",
+'logouttext'                 => "'''Ye'r nou loggit oot.'''
+
+Ye can continue to uise {{SITENAME}} namelessly, or ye can log in again as the same or as a different uiser.
+Mynd that some pages micht continue tae be displayed as if ye war aye loggit in, till ye clear yer brouser cache.",
 'welcomecreation'            => '== Guid tae see ye, $1! ==
 
 Yer accoont haes been creatit. 
@@ -378,10 +387,10 @@ Mynd an chynge yer [[Special:Preferences|{{SITENAME}} preferences]].',
 'logout'                     => 'Log oot',
 'userlogout'                 => 'Log oot',
 'notloggedin'                => 'No loggit in',
-'nologin'                    => 'Dinna hae an accoont? $1.',
+'nologin'                    => "Dinna hae an accoont? '''$1'''.",
 'nologinlink'                => 'Mak an accoont',
 'createaccount'              => 'Mak new accoont',
-'gotaccount'                 => 'Got an accoont afore? $1.',
+'gotaccount'                 => "Got an accoont afore? '''$1'''.",
 'gotaccountlink'             => 'Log in',
 'createaccountmail'          => 'bi email',
 'badretype'                  => 'The passwords ye entered disna match.',
@@ -415,7 +424,7 @@ Check yer spellin, or uise [[Special:UserLogin/signup|mak a new accoont]].',
 'wrongpasswordempty'         => 'The password ye entered is blank. Please gie it anither shot.',
 'passwordtooshort'           => 'Yer password is ower short.
 It maun hae at laest $1 characters.',
-'mailmypassword'             => 'E-mail passwaird',
+'mailmypassword'             => 'E-mail new passwaird',
 'passwordremindertitle'      => 'Password reminder frae {{SITENAME}}',
 'passwordremindertext'       => 'Somebodie (maist likely you, frae IP address $1)
 requestit that we send ye a new {{SITENAME}} login password ($4).
@@ -454,15 +463,17 @@ Ye dinna hae tae heed this message, if this accoont wis creatit by mistak.',
 'loginlanguagelabel'         => 'Leid: $1',
 
 # Password reset dialog
-'resetpass'               => 'Chynge passwaird',
-'resetpass_announce'      => 'Ye loggit in wi a short term e-mailed code. To be duin logging in, ye hae tae mak a new passwaird here:',
-'resetpass_header'        => 'Chynge accoont password',
-'oldpassword'             => 'Auld password',
-'resetpass_submit'        => 'Mak passwaird an log in',
-'resetpass_success'       => 'Yer passwaird chynge wis braw! Nou loggin ye in...',
-'resetpass_bad_temporary' => 'Yer short term passwaird wisnae habile. Ye micht hae already chynged yer passwaird or requestit a new short term passwaird.',
-'resetpass_forbidden'     => 'Passwords canna be chynged',
-'resetpass-no-info'       => 'Ye maun be loggit in tae access this page directly.',
+'resetpass'                 => 'Chynge passwaird',
+'resetpass_announce'        => 'Ye loggit in wi a short term e-mailed code. To be duin logging in, ye hae tae mak a new passwaird here:',
+'resetpass_header'          => 'Chynge accoont password',
+'oldpassword'               => 'Auld password',
+'newpassword'               => 'New passwaird:',
+'resetpass_submit'          => 'Mak passwaird an log in',
+'resetpass_success'         => 'Yer passwaird chynge wis braw! Nou loggin ye in...',
+'resetpass_bad_temporary'   => 'Yer short term passwaird wisnae habile. Ye micht hae already chynged yer passwaird or requestit a new short term passwaird.',
+'resetpass_forbidden'       => 'Passwords canna be chynged',
+'resetpass-no-info'         => 'Ye maun be loggit in tae access this page directly.',
+'resetpass-submit-loggedin' => 'Chynge passwaird',
 
 # Edit page toolbar
 'bold_sample'     => 'Bauld text',
@@ -503,7 +514,7 @@ Ye dinna hae tae heed this message, if this accoont wis creatit by mistak.',
 'summary-preview'                  => 'Ootline leuk ower:',
 'subject-preview'                  => 'Subject/headline leuk ower:',
 'blockedtitle'                     => 'Uiser is blockit',
-'blockedtext'                      => '<big>\'\'\'Yer uisername or IP address haes been blockit.\'\'\'</big>
+'blockedtext'                      => '\'\'\'Yer uisername or IP address haes been blockit.\'\'\'
 
 The block was made bi $1. The raeson gien is \'\'$2\'\'.
 
@@ -537,7 +548,7 @@ Yer block ID is $5. Please include this ID in ony argies ye mak.',
 'confirmedittitle'                 => 'E-mail confirmation needit for tae edit',
 'confirmedittext'                  => 'Ye maun confirm yer e-mail address afore editin pages. Please set an validate yer e-mail address throu yer [[Special:Preferences|uiser settins]].',
 'nosuchsectiontitle'               => 'There isnae a section wi that teetle',
-'nosuchsectiontext'                => "Yer tryin tae edit a section that isnae there.  Acause there isnae a section $1, there's naegate to sauf yer edit.",
+'nosuchsectiontext'                => 'Yer tryin tae edit a section that isnae there.',
 'loginreqtitle'                    => 'Login Requirit!',
 'loginreqlink'                     => 'log in',
 'loginreqpagetext'                 => 'Ye maun $1 tae view ither pages.',
@@ -614,7 +625,7 @@ Thae arguments hae been left oot.',
 # "Undo" feature
 'undo-success' => 'The edit can be undone. Please check the chynges albo tae check that this is whit ye wint tae dae, an then hain the chynges albo tae be duin undooin the edit.',
 'undo-failure' => 'The edit culdnae be undone acause o conflictin edits inatween.',
-'undo-summary' => 'Undo edit $1 by [[Special:Contributions/$2|$2]] ([[User talk:$2|Collogue]])',
+'undo-summary' => 'Undo reveision $1 by [[Special:Contributions/$2|$2]] ([[User talk:$2|Collogue]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Canna mak accoont',
@@ -664,10 +675,19 @@ there micht be parteeculars in the [{{fullurl:Special:Log/delete|page={{FULLPAGE
 'revisiondelete'                 => 'Delete/undelete revisions',
 'revdelete-nooldid-title'        => 'Nae target revision',
 'revdelete-toomanytargets-title' => 'Ower mony targets',
+'pagehist'                       => 'Page history',
+'revdelete-uname'                => 'uisername',
+
+# History merging
+'mergehistory-from'   => 'Soorce page:',
+'mergehistory-reason' => 'Raeson:',
 
 # Diffs
 'difference'              => '(Difference atween revisions)',
+'lineno'                  => 'Line $1:',
 'compareselectedversions' => 'Compare selectit versions',
+'editundo'                => 'undo',
+'diff-src'                => 'soorce',
 
 # Search results
 'searchresults'            => 'Rake results',
@@ -680,13 +700,17 @@ there micht be parteeculars in the [{{fullurl:Special:Log/delete|page={{FULLPAGE
 'notextmatches'            => 'Nae page text matches',
 'prevn'                    => 'foregaun $1',
 'nextn'                    => 'neist $1',
+'viewprevnext'             => 'View ($1) ($2) ($3)',
 'searchhelp-url'           => 'Help:Contents',
+'search-result-size'       => '$1 ({{PLURAL:$2|1 word|$2 words}})',
+'search-section'           => '(section $1)',
 'search-mwsuggest-enabled' => 'wi suggestions',
 'searchall'                => 'aw',
 'showingresults'           => "Shawin ablo up tae {{PLURAL:$1|'''1''' result|'''$1''' results}} stertin wi #'''$2'''.",
 'showingresultsnum'        => "Shawin ablo {{PLURAL:$3|'''1''' result|'''$3''' results}} stertin wi #'''$2'''.",
 'nonefound'                => "'''Mynd''': unsuccessfu rakes is afttimes caused bi rakin for common words like \"hae\" an \"frae\", that isna indexed, or bi specifeein mair nor ae rake term (juist pages haudin aa the rake terms will kythe in the result).",
 'powersearch'              => 'Rake',
+'powersearch-field'        => 'Rake for',
 'searchdisabled'           => 'Rakin throu {{SITENAME}} is disabled for performance raesons. Ye can rake via Google juist nou. Mynd that thair indexes o {{SITENAME}} content micht be oot o date.',
 
 # Preferences page
@@ -702,6 +726,7 @@ there micht be parteeculars in the [{{fullurl:Special:Log/delete|page={{FULLPAGE
 'prefs-personal'     => 'Uiser data',
 'prefs-rc'           => 'Recent chynges an shawin stubs',
 'prefs-misc'         => 'Antrin settins',
+'prefs-resetpass'    => 'Chynge passwaird',
 'saveprefs'          => 'Hain preferences',
 'textboxsize'        => 'Editin',
 'searchresultshead'  => 'Rake result settins',
@@ -717,11 +742,23 @@ there micht be parteeculars in the [{{fullurl:Special:Log/delete|page={{FULLPAGE
 'allowemail'         => 'Allou email frae ither uisers',
 'defaultns'          => 'Rake in thir namespaces bi defaut:',
 'default'            => 'defaut',
+'prefs-custom-css'   => 'Custom CSS',
+'prefs-custom-js'    => 'Custom JS',
 
 # User rights
 'editinguser'             => "Editin uiser '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
 'userrights-groupsmember' => 'Member o:',
 
+# Groups
+'group-bot' => 'Bots',
+'group-all' => '(aw)',
+
+'group-user-member' => 'Uiser',
+'group-bot-member'  => 'Bot',
+
+# Rights
+'right-delete' => 'Delete pages',
+
 # User rights log
 'rightslogtext' => 'This is a log o chynges tae uiser richts.',
 
@@ -732,9 +769,14 @@ there micht be parteeculars in the [{{fullurl:Special:Log/delete|page={{FULLPAGE
 'rcnote'                            => "Ablo {{PLURAL:$1|is '''1''' chynge|are the last '''$1''' chynges}} in the last {{PLURAL:$2|day|'''$2''' days}}, as of $3.",
 'rcnotefrom'                        => 'Ablo is the chynges syne <b>$2</b> (up tae <b>$1</b> shawn).',
 'rclistfrom'                        => 'Shaw new chynges stertin frae $1',
+'rcshowhidebots'                    => '$1 bots',
 'rclinks'                           => 'Shaw last $1 chynges in last $2 days<br />$3',
+'diff'                              => 'diff',
+'hist'                              => 'hist',
 'show'                              => 'shaw',
 'minoreditletter'                   => 's',
+'newpageletter'                     => 'N',
+'boteditletter'                     => 'b',
 'number_of_watching_users_pageview' => '[$1 watchin {{PLURAL:$1|uiser|uisers}}]',
 'rc_categories_any'                 => 'Ony',
 
@@ -768,7 +810,8 @@ Tae pit the eimage intae a page, uise an airtin i the form
 'illegalfilename'             => 'The filename "$1" haes characters that isna alloud in page teitles. Please rename the file an gie uplaidin it anither shot.',
 'badfilename'                 => 'Eimage name haes been chynged tae "$1".',
 'largefileserver'             => 'This file is bigger nor the server is confeigurt tae allou.',
-'fileexists'                  => "A file wi this name exists aareadies, please check '''<tt>$1</tt>''' gin ye'r no siccar that ye want tae chynge it.",
+'fileexists'                  => "A file wi this name exists aareadies, please check '''<tt>[[:$1]]</tt>''' gin ye'r no siccar that ye want tae chynge it.
+[[$1|thumb]]",
 'fileexists-forbidden'        => 'A file wi this name aareadies exists; please gang back an uplaid this file unner a new name. [[File:$1|thumb|center|$1]]',
 'fileexists-shared-forbidden' => 'A file wi this name aareadies exists in the shared file depose; please gang back an uplaid this file unner a new name. [[File:$1|thumb|center|$1]]',
 'uploadwarning'               => 'Uplaid warnin',
@@ -783,15 +826,33 @@ Tae pit the eimage intae a page, uise an airtin i the form
 'nolicense' => 'Nane selected',
 
 # Special:ListFiles
-'listfiles' => 'Eimage leet',
+'imgfile'        => 'file',
+'listfiles'      => 'Eimage leet',
+'listfiles_name' => 'Name',
+'listfiles_user' => 'Uiser',
+'listfiles_size' => 'Size',
 
 # File description page
-'imagelinks'     => 'Eimage airtins',
-'linkstoimage'   => 'The follaein $1 pages airts tae this image:',
-'nolinkstoimage' => "The'r nae pages airts tae this eimage.",
-'noimage'        => 'Nae file wi this name exists, ye can [$1 uplaid it]',
+'filehist'            => 'File history',
+'filehist-deleteone'  => 'delete',
+'filehist-revert'     => 'revert',
+'filehist-user'       => 'Uiser',
+'filehist-dimensions' => 'Dimensions',
+'imagelinks'          => 'File airtins',
+'linkstoimage'        => 'The follaein $1 pages airts tae this image:',
+'nolinkstoimage'      => "The'r nae pages airts tae this eimage.",
+'noimage'             => 'Nae file wi this name exists, ye can [$1 uplaid it]',
+
+# File reversion
+'filerevert'        => 'Revert $1',
+'filerevert-legend' => 'Revert file',
+'filerevert-submit' => 'Revert',
+
+# File deletion
+'filedelete-submit' => 'Delete',
 
 # MIME search
+'mimetype' => 'MIME type:',
 'download' => 'dounlaid',
 
 # Unused templates
@@ -803,7 +864,12 @@ Tae pit the eimage intae a page, uise an airtin i the form
 'randompage' => 'Wale page allevolie',
 
 # Statistics
+'statistics'              => 'Statistics',
+'statistics-header-pages' => 'Page statistics',
+'statistics-header-edits' => 'Edit statistics',
+'statistics-header-views' => 'View statistics',
 'statistics-header-users' => 'Uiser statistics',
+'statistics-pages'        => 'Pages',
 
 'doubleredirects'     => 'Dooble reguidals',
 'doubleredirectstext' => 'Ilka raw hauds airtins tae the first an saicont reguidal, as weel as the first line o the saicont reguidal text, for usual giein the "rael" tairget page, that the first reguidal shuid pynt til.',
@@ -811,10 +877,17 @@ Tae pit the eimage intae a page, uise an airtin i the form
 'brokenredirects'     => 'Brucken reguidals',
 'brokenredirectstext' => 'The follaein reguidals airts tae pages that disna exist.',
 
-'withoutinterwiki' => 'Pages athoot leid links',
+'withoutinterwiki'        => 'Pages athoot leid links',
+'withoutinterwiki-legend' => 'Prefix',
+'withoutinterwiki-submit' => 'Shaw',
 
 # Miscellaneous special pages
+'nbytes'                  => '$1 {{PLURAL:$1|byte|bytes}}',
+'ncategories'             => '$1 {{PLURAL:$1|category|categories}}',
+'nlinks'                  => '$1 {{PLURAL:$1|link|links}}',
+'nmembers'                => '$1 {{PLURAL:$1|membir|membirs}}',
 'nrevisions'              => '$1 {{PLURAL:$1|reveision|reveisions}}',
+'nviews'                  => '$1 {{PLURAL:$1|view|views}}',
 'uncategorizedpages'      => 'Uncategoreised pages',
 'uncategorizedcategories' => 'Uncategoreised categories',
 'unusedcategories'        => 'Unuised categories',
@@ -829,6 +902,8 @@ Tae pit the eimage intae a page, uise an airtin i the form
 'longpages'               => 'Lang pages',
 'deadendpages'            => 'Deid-end pages',
 'listusers'               => 'Uiser leet',
+'newpages'                => 'New pages',
+'newpages-username'       => 'Uisername:',
 'ancientpages'            => 'Auldest pages',
 'move'                    => 'Flit',
 'movethispage'            => 'Flit this page',
@@ -838,12 +913,14 @@ Tae pit the eimage intae a page, uise an airtin i the form
 'notargettext'            => "Ye hivna specifee'd a tairget page or uiser tae perform this function on.",
 
 # Book sources
-'booksources' => 'Beuk sources',
+'booksources'    => 'Beuk sources',
+'booksources-go' => 'Gang',
 
 # Special:Log
 'specialloguserlabel'  => 'Uiser:',
 'speciallogtitlelabel' => 'Teitle:',
-'all-logs-page'        => 'Aw logs',
+'log'                  => 'Logs',
+'all-logs-page'        => 'Aw public logs',
 'alllogstext'          => 'Combined display o uplaid, deletion, protection, blockin, an administrator logs. Ye can narra doon the view bi walin a log type, the uiser name, or the affectit page.',
 'logempty'             => 'Nae matchin items in log.',
 
@@ -851,6 +928,7 @@ Tae pit the eimage intae a page, uise an airtin i the form
 'allpages'          => 'Aa pages',
 'alphaindexline'    => '$1 tae $2',
 'nextpage'          => 'Neist page ($1)',
+'prevpage'          => 'Page afore ($1)',
 'allpagesfrom'      => 'Shaw pages stairtin at:',
 'allarticles'       => 'Aa airticles',
 'allinnamespace'    => 'Aa pages ($1 namespace)',
@@ -868,11 +946,19 @@ Tae pit the eimage intae a page, uise an airtin i the form
 'special-categories-sort-count' => 'sairt bi coont',
 'special-categories-sort-abc'   => 'sairt by the alphabet',
 
+# Special:LinkSearch
+'linksearch-ns' => 'Namespace:',
+'linksearch-ok' => 'Rake',
+
+# Special:ListUsers
+'listusers-submit' => 'Shaw',
+
 # E-mail user
 'mailnologin'     => 'Nae send address',
 'mailnologintext' => 'Ye maun be [[Special:UserLogin|loggit in]] an hae a valid e-mail address in yer [[Special:Preferences|preferences]] tae send e-mail til ither uisers.',
 'noemailtitle'    => 'Nae e-mail address',
 'noemailtext'     => "This uiser haesna specifee'd a valid e-mail address, or haes chuisen no tae receive e-mail frae ither uisers.",
+'emailmessage'    => 'Message:',
 
 # Watchlist
 'watchlist'         => 'Ma watchleet',
@@ -884,6 +970,8 @@ Tae pit the eimage intae a page, uise an airtin i the form
 'addedwatchtext'    => "The page \"<nowiki>\$1</nowiki>\" haes been eikit ti yer [[Special:Watchlist|watchleet]]. Futur chynges ti this page an its associate Collogue page will be leetit thare, an the page will kythe '''bauldit''' in the [[Special:RecentChanges|leet o recent chynges]] ti mak it mair eith tae pick oot. <p>Gin ye want ti remuve the page frae yer watchleet later, dab \"Stop watching\" in the sidebar.",
 'removedwatch'      => 'Remuved frae watchleet',
 'removedwatchtext'  => 'The page "[[:$1]]" haes been remuved frae yer watchleet.',
+'watch'             => 'Watch',
+'unwatch'           => 'Unwatch',
 'notanarticle'      => 'No a content page',
 'watchnochange'     => 'Nane o yer watched items were edited in the time period displayed.',
 'watchlistcontains' => 'Yer watchleet contains $1 {{PLURAL:$1|page|pages}}.',
@@ -891,6 +979,10 @@ Tae pit the eimage intae a page, uise an airtin i the form
 'wlnote'            => "Ablo is the lest $1 {{PLURAL:$1|chynge|chynges}} in the lest {{PLURAL:$2|hour|'''$2''' hours}}.",
 'wlshowlast'        => 'Shaw lest $1 hours $2 days $3',
 
+# Displayed when you click the "watch" button and it is in the process of watching
+'watching'   => 'Watchin...',
+'unwatching' => 'Unwatchin...',
+
 'enotif_reset'       => 'Merk aa pages visitit',
 'changed'            => 'chynged',
 'created'            => 'creatit',
@@ -898,20 +990,26 @@ Tae pit the eimage intae a page, uise an airtin i the form
 'enotif_lastvisited' => 'Hae a leuk at $1 for aa chynges sin yer last visit.',
 
 # Delete
-'excontent'         => "content wis: '$1'",
-'excontentauthor'   => "content wis: '$1' (an the ae contreibutor wis '[[Special:Contributions/$2|$2]]')",
-'exbeforeblank'     => "content afore blankin wis: '$1'",
-'exblank'           => 'page wis tuim',
-'historywarning'    => "Warnin: The page ye're aboot tae delete haes a history:",
-'confirmdeletetext' => "Ye'r aboot tae permanently delete a page or eimage alang wi aa its history frae the database.
+'deletepage'            => 'Delete page',
+'excontent'             => "content wis: '$1'",
+'excontentauthor'       => "content wis: '$1' (an the ae contreibutor wis '[[Special:Contributions/$2|$2]]')",
+'exbeforeblank'         => "content afore blankin wis: '$1'",
+'exblank'               => 'page wis tuim',
+'delete-confirm'        => 'Delete "$1"',
+'delete-legend'         => 'Delete',
+'historywarning'        => "Warnin: The page ye're aboot tae delete haes a history:",
+'confirmdeletetext'     => "Ye'r aboot tae permanently delete a page or eimage alang wi aa its history frae the database.
 Please confirm that ye intend tae dae this, that ye unnerstaun the consequences,
 an that ye'r daein this in accord wi [[{{MediaWiki:Policy-url}}]].",
-'actioncomplete'    => 'Action duin',
-'deletedtext'       => '"<nowiki>$1</nowiki>" haes been delete. See $2 for a record o recent deletions.',
-'deletedarticle'    => 'deletit "[[$1]]"',
-'dellogpagetext'    => 'Ablo is a leet o the maist recent deletions.',
-'reverted'          => 'Revertit tae aulder reveision',
-'deletecomment'     => 'Raeson for deletion',
+'actioncomplete'        => 'Action duin',
+'deletedtext'           => '"<nowiki>$1</nowiki>" haes been delete. See $2 for a record o recent deletions.',
+'deletedarticle'        => 'deletit "[[$1]]"',
+'dellogpage'            => 'Deletion log',
+'dellogpagetext'        => 'Ablo is a leet o the maist recent deletions.',
+'deletionlog'           => 'deletion log',
+'reverted'              => 'Revertit tae aulder reveision',
+'deletecomment'         => 'Raeson:',
+'deletereasonotherlist' => 'Ither raeson',
 
 # Rollback
 'rollback'       => 'Row back edits',
@@ -929,11 +1027,19 @@ an that ye'r daein this in accord wi [[{{MediaWiki:Policy-url}}]].",
 'unprotectedarticle'     => 'unprotectit "[[$1]]"',
 'protect-title'          => 'Protectin "$1"',
 'prot_1movedto2'         => '[[$1]] flittit til [[$2]]',
-'protectcomment'         => 'Raeson for protectin',
+'protectcomment'         => 'Raeson:',
 'protect-text'           => "Ye can see an chynge the protection level here for the page '''<nowiki>$1</nowiki>'''.",
 'protect-level-sysop'    => 'Juist administrators',
+'protect-othertime'      => 'Ither time:',
+'protect-othertime-op'   => 'ither time',
 'protect-expiry-options' => '2 oor:2 hours,1 day:1 day,3 days:3 days,1 week:1 week,2 weeks:2 weeks,1 month:1 month,3 months:3 months,6 months:6 months,1 year:1 year,infinite:infinite', # display1:time1,display2:time2,...
 
+# Restrictions (nouns)
+'restriction-edit'   => 'Edit',
+'restriction-move'   => 'Flit',
+'restriction-create' => 'Mak',
+'restriction-upload' => 'Uplaid',
+
 # Undelete
 'undelete'               => 'Restore delete page',
 'undeletepage'           => 'View an restore delete pages',
@@ -949,26 +1055,38 @@ afore it wis delete. The actual text o thir deletit reveisions is available tae
 'undeletedrevisions'     => '{{PLURAL:$1|1 reveision|$1 reveisions}} restored',
 'cannotundelete'         => 'Undelete didna wirk; some ither bodie micht hae aareadies undeletit the page.',
 
+# Namespace form on various pages
+'namespace'      => 'Namespace:',
+'blanknamespace' => '(Main)',
+
 # Contributions
 'contributions' => 'Uiser contreibutions',
 'mycontris'     => 'Ma contreibutions',
+'contribsub2'   => 'For $1 ($2)',
 'nocontribs'    => 'Nae chynges wis funnd matchin thae criteria.', # Optional parameter: $1 is the user name
 'uctop'         => ' (tap)',
 'month'         => 'Frae month (an afore):',
 'year'          => 'Frae year (an afore):',
 
+'sp-contributions-blocklog' => 'block log',
+'sp-contributions-logs'     => 'logs',
+'sp-contributions-submit'   => 'Rake',
+
 # What links here
-'whatlinkshere' => 'Whit airts tae here',
-'linkshere'     => "The follaein pages airts tae '''[[:$1]]''':",
-'nolinkshere'   => "Nae pages airt tae '''[[:$1]]'''.",
-'isredirect'    => 'reguidal page',
+'whatlinkshere'           => 'Whit airts tae here',
+'linkshere'               => "The follaein pages airts tae '''[[:$1]]''':",
+'nolinkshere'             => "Nae pages airt tae '''[[:$1]]'''.",
+'isredirect'              => 'reguidal page',
+'isimage'                 => 'eimage link',
+'whatlinkshere-links'     => '← links',
+'whatlinkshere-hidelinks' => '$1 links',
 
 # Block/unblock
 'blockip'                     => 'Block uiser',
 'blockiptext'                 => 'Uise the form ablo tae block write access frae a specific IP address or uisername. This shuid be duin juist tae prevent vandalism, and in accord wi [[{{MediaWiki:Policy-url}}|policy]]. Fill in a specific raeson ablo (for exemplar, citin parteicular pages that wis damaged).',
 'ipaddress'                   => 'IP Address',
 'ipadressorusername'          => 'IP Address or uisername',
-'ipbreason'                   => 'Raeson',
+'ipbreason'                   => 'Raeson:',
 'ipbsubmit'                   => 'Block this uiser',
 'ipbother'                    => 'Ither time',
 'ipboptions'                  => '2 oor:2 hours,1 day:1 day,3 days:3 days,1 week:1 week,2 weeks:2 weeks,1 month:1 month,3 months:3 months,6 months:6 months,1 year:1 year,infinite:infinite', # display1:time1,display2:time2,...
@@ -977,6 +1095,7 @@ afore it wis delete. The actual text o thir deletit reveisions is available tae
 'blockipsuccesssub'           => 'Block succeedit',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] haes been blockit.
 <br />See [[Special:IPBlockList|IP block leet]] tae review blocks.',
+'ipb-unblock-addr'            => 'Unblock $1',
 'unblockip'                   => 'Unblock uiser',
 'unblockiptext'               => 'Uise the form ablo tae restore screivin richts
 tae an afore-blockit IP address or uisername.',
@@ -984,6 +1103,9 @@ tae an afore-blockit IP address or uisername.',
 'blocklistline'               => '$1, $2 blockit $3 (expires $4)',
 'anononlyblock'               => 'anon. juist',
 'createaccountblock'          => 'accoont-makkin blockit',
+'blocklink'                   => 'block',
+'unblocklink'                 => 'unblock',
+'change-blocklink'            => 'chynge block',
 'contribslink'                => 'contreibs',
 'autoblocker'                 => 'Autaematically blockit syne yer IP address haes been uised recently bi "[[User:$1|$1]]". The raeson gien for $1\'s block is "\'\'$2\'\'"',
 'blocklogentry'               => 'blockit [[$1]] wi an expiry time o $2 $3',
@@ -1037,7 +1159,8 @@ please be siccar ye unnerstaun the consequences o this afore proceedin.",
 '1movedto2_redir'         => '[[$1]] flittit til [[$2]] ower reguidal',
 'movelogpage'             => 'Flit log',
 'movelogpagetext'         => "A leet o pages that's flitted is ablo.",
-'movereason'              => 'Raeson',
+'movereason'              => 'Raeson:',
+'revertmove'              => 'revert',
 'delete_and_move'         => 'Delete an flit',
 'delete_and_move_text'    => '==Deletion caad for==
 
@@ -1075,9 +1198,13 @@ In the saicont case ye can uise an airtin forbye, for exemplar [[{{#Special:Expo
 # Tooltip help for the actions
 'tooltip-pt-preferences'          => 'Ma preferences',
 'tooltip-pt-login'                => "It's a guid idea tae log i, but ye dinna hae tae.",
+'tooltip-pt-logout'               => 'Log oot',
+'tooltip-ca-move'                 => 'Flit this page',
 'tooltip-search'                  => 'Rake {{SITENAME}}',
 'tooltip-n-mainpage'              => 'Gang tae the Main Page',
 'tooltip-t-contributions'         => "View this uiser's contreibutions",
+'tooltip-t-upload'                => 'Uplaid files',
+'tooltip-t-specialpages'          => 'Leet o byordinar pages',
 'tooltip-minoredit'               => 'Mairk this as a smaa edit',
 'tooltip-save'                    => 'Hain yer chynges',
 'tooltip-preview'                 => 'Scance ower yer chynges, please uise this afore hainin!',
@@ -1127,12 +1254,13 @@ In the saicont case ye can uise an airtin forbye, for exemplar [[{{#Special:Expo
 'deletedrevision' => 'Deletit auld revision $1.',
 
 # Browsing diffs
-'previousdiff' => '← Gang tae previous diff',
-'nextdiff'     => 'Gang tae neist diff →',
+'previousdiff' => '← Aulder edit',
+'nextdiff'     => 'Newer edit →',
 
 # Media information
-'mediawarning' => "'''Warnin''': This file micht haud mislushious code; bi executin it yer seestem micht be compromised.<hr />",
-'imagemaxsize' => 'Limit eimages on eimage description pages tae:',
+'mediawarning'   => "'''Warnin''': This file micht haud mislushious code; bi executin it yer seestem micht be compromised.",
+'imagemaxsize'   => 'Limit eimages on eimage description pages tae:',
+'file-info-size' => '($1 × $2 pixels, file size: $3, MIME type: $4)',
 
 # Special:NewFiles
 'newimages'     => 'Gallery o new files',
@@ -1147,6 +1275,9 @@ In the saicont case ye can uise an airtin forbye, for exemplar [[{{#Special:Expo
 Only list items (lines starting with *) are considered. The first link on a line must be a link to a bad image.
 Any subsequent links on the same line are considered to be exceptions, i.e. pages where the image may occur inline.',
 
+# Metadata
+'metadata' => 'Metadata',
+
 # EXIF tags
 'exif-copyright'               => 'Copyricht hauder',
 'exif-colorspace'              => 'Colour space',
@@ -1221,7 +1352,18 @@ Please confirm that ye really want tae recreate this airticle.",
 'autosumm-replace' => "Replacin page wi '$1'",
 'autoredircomment' => 'Reguidin tae [[$1]]',
 
+# Special:FilePath
+'filepath-page' => 'File:',
+
+# Special:FileDuplicateSearch
+'fileduplicatesearch-filename' => 'Filename:',
+'fileduplicatesearch-submit'   => 'Rake',
+
 # Special:SpecialPages
 'specialpages' => 'Byordinar pages',
 
+# Special:Tags
+'tag-filter-submit' => 'Filter',
+'tags-edit'         => 'edit',
+
 );
