@@ -210,10 +210,10 @@ $messages = array(
 'userlogin'               => 'Logge sïjse / skaepede nuhtjien',
 'logout'                  => 'Logge olkese',
 'userlogout'              => 'Logge ålkone',
-'nologin'                 => 'Lea dov ijje registreered? $1.',
+'nologin'                 => "Lea dov ijje registreered? '''$1'''.",
 'nologinlink'             => 'Skaepede nuhtjien',
 'createaccount'           => 'Skaepede nuhtjien',
-'gotaccount'              => 'Åtna dov joe nuhtjiennomme? $1.',
+'gotaccount'              => "Åtna dov joe nuhtjiennomme? '''$1'''.",
 'gotaccountlink'          => 'Logge sïjse',
 'createaccountmail'       => 'meatan e-påaste',
 'youremail'               => 'E-påaste:',
