@@ -1,5 +1,8 @@
 <?php
 /** Tuvinian (Тыва дыл)
+ *
+ * See MessagesQqq.php for message documentation incl. usage of parameters
+ * To improve a translation please visit http://translatewiki.net
  *
  * @ingroup Language
  * @file
@@ -102,18 +105,20 @@ $messages = array(
 'dec'           => '12.ай',
 
 # Categories related messages
-'pagecategories'        => '{{PLURAL:$1|Бөлүк|Бөлүктер}}',
-'category_header'       => '"$1" деп бөлүкте чүүлдер',
-'subcategories'         => 'Бичии бөлүктер',
-'category-media-header' => '"$1" деп бөлүкте медиа',
-'category-empty'        => "''Амгы бо бөлүкте медиа база арыннар чок.''",
+'pagecategories'           => '{{PLURAL:$1|Бөлүк|Бөлүктер}}',
+'category_header'          => '"$1" деп бөлүкте арыннар',
+'subcategories'            => 'Бичии бөлүктер',
+'category-media-header'    => '"$1" деп бөлүкте медиа',
+'category-empty'           => "''Амгы бо бөлүкте медиа база арыннар чок.''",
+'hidden-categories'        => '{{PLURAL:$1|Чажыт бөлүк|Чажыт бөлүктер}}',
+'hidden-category-category' => 'Чажыт бөлүктер', # Name of the category where hidden categories will be listed
 
 'about'          => 'Дугайында',
 'article'        => 'Допчу арын',
-'newwindow'      => '(чаа козенекке ажыытынар)',
-'cancel'         => 'Соксаар',
-'qbfind'         => 'Тывар',
-'qbbrowse'       => 'Ажыдар',
+'newwindow'      => '(чаа көзенээ ажыытынар)',
+'cancel'         => 'Соксаары',
+'qbfind'         => 'Тывары',
+'qbbrowse'       => 'Каралаары',
 'qbedit'         => 'Өскертир',
 'qbpageoptions'  => 'Бо арын',
 'qbmyoptions'    => 'Мээң арыннарым',
@@ -123,59 +128,64 @@ $messages = array(
 'mytalk'         => 'Мээң чугаалажырым',
 'anontalk'       => 'Бо ИП-адрестиң чугаа',
 'navigation'     => 'Навигация',
+'and'            => '&#32;болгаш',
 
 'errorpagetitle'    => 'Алдаг',
-'returnto'          => '$1 деп арынже эглир.',
+'returnto'          => '$1 деп арынже эглири.',
 'tagline'           => '{{grammar:ablative|{{SITENAME}}}}',
 'help'              => 'Дуза',
-'search'            => 'Дилээр',
-'searchbutton'      => 'Дилээр',
-'go'                => 'Чоруур',
-'searcharticle'     => 'Чоруур',
+'search'            => 'Дилээри',
+'searchbutton'      => 'Дилээри',
+'go'                => 'Баары',
+'searcharticle'     => 'Күүcедири',
 'history'           => 'Арынның Төөгүзү',
 'history_short'     => 'Төөгү',
 'info_short'        => 'Медеглел',
-'printableversion'  => 'Саазынга үндүрерин көөр',
+'printableversion'  => 'Саазынга үндүрерин көөрү',
 'permalink'         => 'Үргүлчү холбаа',
 'print'             => 'Саазынга үндүрер',
-'edit'              => 'Өскертир',
-'editthispage'      => 'Бо арынны өскертир',
-'delete'            => 'Ап каар',
+'edit'              => 'Өскертири',
+'create'            => 'Кылыры',
+'editthispage'      => 'Бо арынны өскертири',
+'create-this-page'  => 'Бо арынны кылыр',
+'delete'            => 'Ап каары',
 'deletethispage'    => 'Бо арынны ап каар',
-'protect'           => 'Камгалаар',
+'protect'           => 'Камгалаары',
+'protect_change'    => 'өскертири',
 'protectthispage'   => 'Бо арынны камгалаар',
 'unprotect'         => 'Камгалалды ап каар',
 'unprotectthispage' => 'Бо арынның камгалалын ап каар',
 'newpage'           => 'Чаа арын',
-'talkpage'          => 'Бо арын дугайында чугаалажыр',
-'talkpagelinktext'  => 'Чугаалажыр',
-'specialpage'       => 'Тускай Арын',
+'talkpage'          => 'Бо арын дугайында чугаалажыры',
+'talkpagelinktext'  => 'Чугаалажыры',
+'specialpage'       => 'Тускай арын',
 'personaltools'     => 'Хууда херекселдер',
-'postcomment'       => 'Комментарийни чогаадыр',
+'postcomment'       => 'Чаа салбыр',
 'articlepage'       => 'Допчу арынны көөр',
-'talk'              => 'Чугаалажыр',
+'talk'              => 'Чугаалажыры',
 'views'             => 'Көрүштер',
 'toolbox'           => 'Херекселдер',
 'userpage'          => 'Ажыглакчының арынын көөр',
 'projectpage'       => 'Проект арынын көөр',
-'imagepage'         => 'Медиа арынын көөр',
+'imagepage'         => 'Файл арнызын көөр',
 'mediawikipage'     => 'Чагаа арынын көөр',
 'templatepage'      => 'Хээ арынын көөр',
 'viewhelppage'      => 'Дуза арынын көөр',
-'categorypage'      => 'Бөлүк арынын көөр',
+'categorypage'      => 'Бөлүктүң арынын көөрү',
 'viewtalkpage'      => 'Чугаалажырыны көөр',
 'otherlanguages'    => 'Өске дылдарга',
 'lastmodifiedat'    => 'Бо арын сөөлгү каттап $2, $1 өскерилген.', # $1 date, $2 time
 'jumptonavigation'  => 'навигация',
-'jumptosearch'      => 'дилээр',
+'jumptosearch'      => 'дилээри',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => '{{SITENAME}} дугайында',
 'aboutpage'            => 'Project:Дугайында',
 'currentevents'        => 'Амгы үеде болуушкуннар',
 'currentevents-url'    => 'Project:Амгы үеде болуушкуннар',
+'disclaimers'          => 'Ажыглаарынка чомпээрежил',
 'edithelp'             => 'Өскертиринге дуза',
-'edithelppage'         => 'Help:Өскертир',
+'edithelppage'         => 'Help:Өскертири',
 'helppage'             => 'Help:Допчузу',
 'mainpage'             => 'Кол Арын',
 'mainpage-description' => 'Кол Арын',
@@ -183,28 +193,32 @@ $messages = array(
 'portal'               => 'Ниитилелдиң хаалгазы',
 'portal-url'           => 'Project:Ниитилелдиң хаалгазы',
 
+'ok'                  => 'Чөп',
 'retrievedfrom'       => '"$1" деп арынында парлаттынган',
+'youhavenewmessages'  => 'Силерде $1 ($2) бар.',
 'newmessageslink'     => 'чаа чагаалар',
 'newmessagesdifflink' => 'бурунгу өскерлиишкин',
-'editsection'         => 'өскертир',
-'editold'             => 'өскертир',
-'editsectionhint'     => 'Бөгүмнү өскертир: $1',
-'toc'                 => 'Допчу',
-'showtoc'             => 'көргүзер',
-'hidetoc'             => 'чажырар',
+'editsection'         => 'өскертири',
+'editold'             => 'өскертири',
+'editlink'            => 'өскертири',
+'editsectionhint'     => '$1 деп салбырны өскертири',
+'toc'                 => 'Допчузу',
+'showtoc'             => 'көргүзери',
+'hidetoc'             => 'чажырары',
 'viewdeleted'         => '{{grammar:accusative|$1}} көөр?',
-'restorelink'         => '$1 балаттынган өскерилгелер',
+'restorelink'         => '{{PLURAL:$1|$1 балаттынган өскерилгелер}}',
 'feedlinks'           => 'Агым:',
 'site-rss-feed'       => '$1 РСС Медээ Агымы',
 'site-atom-feed'      => '$1 Атом Медээ Агымы',
 'page-rss-feed'       => '"$1" РСС Медээ Агымы',
 'page-atom-feed'      => '"$1" Атом Медээ Агымы',
+'red-link-title'      => '$1 (арынны чок)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
-'nstab-main'      => 'Чүүл',
+'nstab-main'      => 'Арын',
 'nstab-user'      => 'Ажыглакчының арыны',
 'nstab-media'     => 'Медиа арыны',
-'nstab-special'   => 'Тускай',
+'nstab-special'   => 'Тускай арын',
 'nstab-project'   => 'Проект арыны',
 'nstab-image'     => 'Файл',
 'nstab-mediawiki' => 'Чагаа',
@@ -226,20 +240,20 @@ $1',
 'internalerror'      => 'Иштики алдаг',
 'internalerror_info' => 'Иштики алдаг: $1',
 'badtitle'           => 'Багай ат',
-'viewsource'         => 'Бажы көөр',
+'viewsource'         => 'Бажы көөрү',
 
 # Login and logout pages
 'logouttitle'        => 'Ажыглакчы үнери',
 'loginpagetitle'     => 'Ажыглакчы кирери',
 'yourname'           => 'Aжыглакчының ады',
 'yourpassword'       => 'Чажыт сөс',
-'remembermypassword' => 'Мени сактып алыр',
-'login'              => 'Кирер',
-'userlogin'          => 'Кирер / кирерини чогаадып кылыр',
-'logout'             => 'Үнер',
-'userlogout'         => 'Үнер',
+'remembermypassword' => 'Адымны сактып алыры',
+'login'              => 'Кирери',
+'userlogin'          => 'Кирери / кирерини чогаадып кылыры',
+'logout'             => 'Үнери',
+'userlogout'         => 'Үнери',
 'notloggedin'        => 'Кирери евес',
-'nologinlink'        => 'Кирерини чогаадып кылыр',
+'nologinlink'        => 'Кирерини чогаадып кылыры',
 'createaccount'      => 'Кирерини чогаадып кылыр',
 'gotaccountlink'     => 'Кирер',
 'createaccountmail'  => 'е-чагаа-биле',
@@ -250,75 +264,81 @@ $1',
 'yourrealname'       => 'Шын адыңар *',
 'yourlanguage'       => 'Дылыңар:',
 'yournick'           => 'Шола ат:',
+'gender-male'        => 'Эр',
+'gender-female'      => 'Кыс',
 'email'              => 'Э-чагаа',
 'loginerror'         => 'Багай кирери',
 'loginsuccesstitle'  => 'Чедимчелиг кирери',
-'mailmypassword'     => 'Э-чагаа чажыт сөзүңер',
+'mailmypassword'     => 'Меңээ чаа чажыт сөсту чорудаары',
 'accountcreated'     => 'Кирерини бүдүрген',
 'accountcreatedtext' => '$1 ажыглакчының кирерин бүдүрген.',
 'loginlanguagelabel' => 'Дыл: $1',
 
 # Password reset dialog
-'resetpass_header'    => 'Чажыт сөстү катап чогаадып кылыр',
-'oldpassword'         => 'Эгри чажыт сөс:',
-'newpassword'         => 'Чаа чажыт сөс:',
-'resetpass_submit'    => 'Чажыт сөстү чоогадып кылыр база кирер.',
-'resetpass_forbidden' => '{{grammar:locative|{{SITENAME}}}} чажыт сөстү өскертивейн болбас',
+'resetpass'                 => 'Чажыт сөзү өскертир',
+'resetpass_header'          => 'Чажыт сөстү катап чогаадып кылыры',
+'oldpassword'               => 'Эгри чажыт сөс:',
+'newpassword'               => 'Чаа чажыт сөс:',
+'resetpass_submit'          => 'Чажыт сөстү чоогадып кылыр база кирер.',
+'resetpass_forbidden'       => 'Чажыт сөстү өскертивейн болбас',
+'resetpass-submit-loggedin' => 'Чажыт сөзү өскертири',
 
 # Edit page toolbar
 'bold_sample'     => 'Карартыр',
 'italic_sample'   => 'Ийлендирер',
-'link_sample'     => 'Холбаа ады',
+'link_sample'     => 'Холбаадың ады',
 'link_tip'        => 'Иштики холбаа',
-'extlink_sample'  => 'http://www.example.com холбаа ады',
+'extlink_sample'  => 'http://www.example.com холбаадың ады',
 'extlink_tip'     => 'Даштыкы холбаа ("http://" чүве сактып алыр)',
 'headline_sample' => 'Кол сөс сөзүглел',
-'nowiki_sample'   => 'Форматтаваан сөзүглелини бээр салыр',
+'math_sample'     => 'Формуланы мынаар киирери',
+'nowiki_sample'   => 'Форматтаваан сөзүглелини бээр салыры',
 'nowiki_tip'      => 'Вики форматтаарын херекке албас',
 'image_sample'    => 'Чижек.jpg',
 'media_sample'    => 'Чижек.ogg',
-'media_tip'       => 'Файл холбаазы',
+'media_tip'       => 'Файлдың холбаазы',
 
 # Edit pages
 'summary'            => 'Түңнел:',
 'subject'            => 'Кол сөс:',
 'minoredit'          => 'Бо өскерлиишкин биче-дир',
-'watchthis'          => 'Бо арынны хайгаараар',
-'savearticle'        => 'Арынны шыгжаар',
-'preview'            => 'Чижеглей көөр',
-'showpreview'        => 'Чижеглей көөр',
-'showdiff'           => 'Өскерлиишкиннерни көргүзер',
+'watchthis'          => 'Бо арынны хайгаараары',
+'savearticle'        => 'Арынны шыгжаары',
+'preview'            => 'Чижеглей көөрү',
+'showpreview'        => 'Чижеглей көөрү',
+'showdiff'           => 'Өскерлиишкиннерни көргүзери',
 'missingcommenttext' => 'Комментарийни адаанда чогаадыңар.',
-'summary-preview'    => 'Түңнелдү чижеглей көөр:',
+'summary-preview'    => 'Түңнелдү чижеглей көөрү:',
 'subject-preview'    => 'Кол сөс чижеглей көөр:',
-'nosuchsectiontitle' => 'Ындыг бөлгүм чок',
+'nosuchsectiontitle' => 'Бо салбыр чок',
 'loginreqlink'       => 'кирер',
 'accmailtitle'       => 'Чажыт сөс чоргустунган.',
-'accmailtext'        => '"{{grammar:genitive|$1}}" чажыт сөстү {{grammar:directive1|$2}} чоргузуптувус.',
+'accmailtext'        => '',
 'newarticle'         => '(Чаа)',
 'editing'            => '$1 деп арынны өскертип турар',
-'editingsection'     => '$1 деп арынның бөлгүмүн өскертип турар',
-'editingcomment'     => '$1 (комментарий) өскертип турар',
+'editingsection'     => '$1 деп арынның салбырын өскертип турар',
+'editingcomment'     => '$1 деп арынны өскертип турар (чаа салбыр)',
 'yourtext'           => 'Силерниң сөзүглелиңер',
 'yourdiff'           => 'Ылгалдар',
 'template-protected' => '(камгалаан)',
 
 # History pages
-'nohistory'           => 'Бо арынның өскерлиишкин төөгүзү чок.',
-'currentrev'          => 'Амгы үе үндүрери',
-'previousrevision'    => '←Артык эрги үндүрери',
-'nextrevision'        => 'Артык чаа үндүрери→',
-'currentrevisionlink' => 'Амгы үе үндүрери',
-'cur'                 => 'амгы',
-'next'                => 'соонда',
-'last'                => 'бурунгу',
-'page_first'          => 'бирги',
-'page_last'           => 'сөөлгү',
-'deletedrev'          => '[ап каан]',
-'histfirst'           => 'Эң эрте',
-'histlast'            => 'Эң дээм чаагы',
-'historysize'         => '($1 байт)',
-'historyempty'        => '(куруг)',
+'nohistory'              => 'Бо арынның өскерлиишкин төөгүзү чок.',
+'currentrev'             => 'Амгы үе үндүрери',
+'previousrevision'       => '←Артык эрги үндүрери',
+'nextrevision'           => 'Артык чаа үндүрери→',
+'currentrevisionlink'    => 'Амгы үе үндүрери',
+'cur'                    => 'амгы',
+'next'                   => 'соонда',
+'last'                   => 'бурунгу',
+'page_first'             => 'бирги',
+'page_last'              => 'сөөлгү',
+'history-fieldset-title' => 'Каралаары төөгүзү',
+'deletedrev'             => '[ап каан]',
+'histfirst'              => 'Эң эрте',
+'histlast'               => 'Эң дээм чаагы',
+'historysize'            => '({{PLURAL:$1|$1 байт}})',
+'historyempty'           => '(куруг)',
 
 # Revision feed
 'history-feed-title' => 'Үндүрериниң төөгүзү',
@@ -326,73 +346,118 @@ $1',
 # Revision deletion
 'rev-deleted-comment'    => '(комментарийни ап каан)',
 'rev-deleted-user'       => '(ажыглакчының адын ап каан)',
-'rev-deleted-event'      => '(болуушкунну ап каан)',
-'rev-delundel'           => 'көргүзер/чажырар',
+'rev-deleted-event'      => '',
+'rev-delundel'           => 'көргүзери/чажырары',
 'revisiondelete'         => 'Үндүрерилерни ап каар/диргисир',
 'revdelete-hide-comment' => 'Өскерлиишкинниң комментарийн чажырар',
 'revdelete-hide-user'    => 'Чогаалчының адын/ИП-адресин чажырар',
+'revdelete-log'          => 'Чылдагаан:',
+'pagehist'               => 'Арынның төөгүзү',
+
+# History merging
+'mergehistory-reason' => 'Чылдагаан:',
 
 # Diffs
 'history-title'           => '"$1" деп арынның үндүрери төөгүзү',
 'lineno'                  => '$1 одуруг:',
-'compareselectedversions' => 'Шилип алган хевирлери деңнээр',
+'compareselectedversions' => 'Шилип алган хевирлери деңнээри',
+'diff-width'              => 'калбаа',
+'diff-height'             => 'бедии',
 
 # Search results
-'searchresults'  => 'Түңнелдер',
-'prevn'          => 'бүрүнгү $1',
-'nextn'          => 'соонда $1',
-'viewprevnext'   => '($1) ($2) ($3) көөр',
-'searchhelp-url' => 'Help:Допчузу',
-'powersearch'    => 'Дилээр',
+'searchresults'            => 'Түңнелдер',
+'prevn'                    => 'бүрүнгү $1',
+'nextn'                    => 'соонда $1',
+'viewprevnext'             => '($1) ($2) ($3) көөрү',
+'searchhelp-url'           => 'Help:Допчузу',
+'searchprofile-everything' => 'Бүгүде',
+'search-result-size'       => '$1 ({{PLURAL:$2|$2 сөс}})',
+'search-section'           => '("$1" деп салбыр)',
+'searchall'                => 'шупту',
+'powersearch'              => '',
 
 # Preferences page
-'preferences'        => 'Дээре деп санаарылар',
-'changepassword'     => 'Чажыт сөстү өскертир',
-'skin'               => 'Кеш',
-'skin-preview'       => 'Чижеглей көөр',
-'math_unknown_error' => 'билбес алдаг',
-'prefs-personal'     => 'Ажыглакчының медээлери',
-'prefs-rc'           => 'Дээм чаагы өскерлиишкиннер',
-'prefs-watchlist'    => 'Хайгаарылга даңзызы',
-'saveprefs'          => 'Шыгжаар',
-'textboxsize'        => 'Өскертир',
-'rows'               => 'Одуруглар:',
-'columns'            => 'Баганалар:',
-'searchresultshead'  => 'Дилээр',
-'servertime'         => 'Сервер шакы',
-'default'            => 'ниити',
-'files'              => 'файлдар',
+'preferences'               => 'Шилиирилер',
+'mypreferences'             => 'Мээң шилиирилерим',
+'changepassword'            => 'Чажыт сөстү өскертир',
+'skin'                      => 'Кеш',
+'skin-preview'              => 'Чижеглей көөр',
+'math_unknown_error'        => 'билбес алдаг',
+'prefs-personal'            => 'Ажыглакчының медээлери',
+'prefs-rc'                  => 'Дээм чаагы өскерлиишкиннер',
+'prefs-watchlist'           => 'Хайгаарылга даңзызы',
+'saveprefs'                 => 'Шыгжаар',
+'textboxsize'               => 'Өскертир',
+'rows'                      => 'Одуруглар:',
+'columns'                   => 'Баганалар:',
+'searchresultshead'         => 'Дилээр',
+'servertime'                => 'Серверниң шагы:',
+'timezoneregion-africa'     => 'Африка',
+'timezoneregion-america'    => 'Америка',
+'timezoneregion-antarctica' => 'Антарктика',
+'timezoneregion-arctic'     => 'Арктика',
+'timezoneregion-asia'       => 'Азия',
+'timezoneregion-australia'  => 'Австралия',
+'timezoneregion-europe'     => 'Европа',
+'default'                   => 'ниити',
+'files'                     => 'файлдар',
 
 # User rights
-'editinguser' => '<b>$1</b> деп ажыглакчыны өскертип турар ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])',
+'editinguser'       => '',
+'userrights-reason' => 'Чылдагаан:',
 
 # Groups
-'group'     => 'Бөлүк:',
-'group-bot' => 'Боттар',
-'group-all' => '(шупту)',
+'group'          => 'Бөлүк кижилер:',
+'group-user'     => 'Ажыглакчылар',
+'group-bot'      => 'Роботтар',
+'group-sysop'    => 'Эргелекчилер',
+'group-suppress' => 'Хынакчылар',
+'group-all'      => '(шупту)',
 
-'group-bot-member' => 'Бот',
+'group-user-member'       => 'ажыглакчы',
+'group-bot-member'        => 'робот',
+'group-sysop-member'      => 'эргелекчи',
+'group-bureaucrat-member' => 'бюрократ',
+'group-suppress-member'   => 'хынакчы',
 
-'grouppage-sysop' => '{{ns:project}}:Администраторлар',
+'grouppage-user'       => '{{ns:project}}:Ажыглакчылар',
+'grouppage-bot'        => '{{ns:project}}:Роботтар',
+'grouppage-sysop'      => '{{ns:project}}:Эргелекчилер',
+'grouppage-bureaucrat' => '{{ns:project}}:Бюрократтар',
+'grouppage-suppress'   => '{{ns:project}}:Хынакчы',
+
+# User rights log
+'rightsnone' => '(чок)',
+
+# Associated actions - in the sentence "You do not have permission to X"
+'action-read' => 'бо арынны номчууру',
+'action-edit' => 'бо арынны өскертири',
+'action-move' => 'бо арынны шимчээри',
 
 # Recent changes
-'nchanges'                          => '$1 өскерлиишкин',
-'recentchanges'                     => 'Өскерлиишкиннер',
+'nchanges'                          => '$1 {{PLURAL:$1|өскерлиишкин}}',
+'recentchanges'                     => 'Амгы өскерлиишкиннер',
 'rcshowhideminor'                   => 'Бичии өскерлиишкиннерни $1',
-'rcshowhidebots'                    => 'Боттарну $1',
+'rcshowhidebots'                    => 'Роботтарну $1',
 'rcshowhideliu'                     => 'Кирер ажыглакчыларны $1',
 'rcshowhideanons'                   => 'Ат эвес ажыглакчыларны $1',
 'rcshowhidemine'                    => 'Мээң өскерлиишкинимни $1',
 'diff'                              => 'ылгал',
 'hist'                              => 'төөгү',
-'hide'                              => 'Чажырар',
-'show'                              => 'көргүзер',
-'number_of_watching_users_pageview' => '[$1 хайгаараар ажыглакчы]',
-'newsectionsummary'                 => '/* $1 */ чаа бөлгүм',
+'hide'                              => 'чажырары',
+'show'                              => 'көргүзери',
+'minoreditletter'                   => 'б',
+'newpageletter'                     => 'Ч',
+'boteditletter'                     => 'р',
+'number_of_watching_users_pageview' => '[$1 хайгаараар {{PLURAL:$1|ажыглакчы}}]',
+'newsectionsummary'                 => '/* $1 */ чаа салбыр',
+
+# Recent changes linked
+'recentchangeslinked-page' => 'Арынның ады:',
 
 # Upload
-'upload'            => 'Файлды киирер',
-'uploadbtn'         => 'Файлды киирер',
+'upload'            => 'Файлды салыры',
+'uploadbtn'         => 'Файлды салыры',
 'reupload'          => 'Катап киирер',
 'uploadnologin'     => 'Кирбес',
 'uploaderror'       => 'Кииреринге алдаг',
@@ -401,7 +466,8 @@ $1',
 'fileuploadsummary' => 'Түңнел:',
 'filesource'        => 'Эгези:',
 'savefile'          => 'файлды шыгжаар',
-'watchthisupload'   => 'Бо арынны хайгаараар',
+'uploadedimage'     => '"[[$1]]" деп файлды салган.',
+'watchthisupload'   => 'Бо арынны хайгаараары',
 
 'upload-file-error' => 'Иштики алдаг',
 'upload-misc-error' => 'Билбес кииреринге алдаг',
@@ -417,26 +483,29 @@ $1',
 # File description page
 'filehist'           => 'Файлдың төөгүзү',
 'filehist-deleteall' => 'шуптуну ап каар',
-'filehist-deleteone' => 'мону ап каар',
-'filehist-current'   => 'амгы үе',
+'filehist-deleteone' => 'ап каары',
+'filehist-current'   => 'амгы',
 'filehist-datetime'  => 'Үе/Шак',
+'filehist-thumb'     => 'Бичии чурук',
 'filehist-user'      => 'Ажыглакчы',
 'filehist-filesize'  => 'Файл хемчээли',
 'filehist-comment'   => 'Комментарий',
-'imagelinks'         => 'Холбаалар',
+'imagelinks'         => 'Файлдың xолбаалары',
 'noimage-linktext'   => 'Ону киирер',
 
 # File reversion
-'filerevert-comment' => 'Комментарий:',
+'filerevert-comment' => 'Чылдагаан:',
 
 # File deletion
-'filedelete'         => '$1 деп файлды ап каар',
-'filedelete-legend'  => 'Файлды ап каар',
-'filedelete-comment' => 'Комментарий:',
-'filedelete-submit'  => 'Ап каар',
+'filedelete'                  => '$1 деп файлды ап каар',
+'filedelete-legend'           => 'Файлды ап каар',
+'filedelete-comment'          => 'Чылдагаан:',
+'filedelete-submit'           => 'Ап каары',
+'filedelete-otherreason'      => 'Өске/немелде чылдагаан:',
+'filedelete-reason-otherlist' => 'Өске чылдагаан',
 
 # MIME search
-'download' => 'алыр',
+'download' => 'алыры',
 
 # Unwatched pages
 'unwatchedpages' => 'Хайгаарабас арыннар',
@@ -448,6 +517,9 @@ $1',
 # Random page
 'randompage' => 'Даап арын',
 
+# Statistics
+'statistics' => 'Статистика',
+
 'brokenredirects-edit'   => '(өскертир)',
 'brokenredirects-delete' => '(ап каар)',
 
@@ -456,12 +528,12 @@ $1',
 'fewestrevisions' => 'Эң эвээш үндүрери арыннар',
 
 # Miscellaneous special pages
-'nbytes'                  => '$1 байт',
-'ncategories'             => '$1 бөлүк',
-'nlinks'                  => '$1 холбаа',
-'nmembers'                => '$1 кежигүн',
-'nrevisions'              => '$1 үндүрери',
-'nviews'                  => '$1 көрүш',
+'nbytes'                  => '$1 {{PLURAL:$1|байт}}',
+'ncategories'             => '$1 {{PLURAL:$1|бөлүк}}',
+'nlinks'                  => '$1 {{PLURAL:$1|холбаа}}',
+'nmembers'                => '$1 {{PLURAL:$1|кежигүн}}',
+'nrevisions'              => '$1 {{PLURAL:$1|үндүрери}}',
+'nviews'                  => '$1 {{PLURAL:$1|көрүш}}',
 'specialpage-empty'       => 'Бо илеткелдиң түңнели чок.',
 'lonelypages'             => 'Чааскаан арыннар',
 'uncategorizedpages'      => 'Бөлүк эвес арыннар',
@@ -481,51 +553,52 @@ $1',
 'shortpages'              => 'Чолдак арыннар',
 'longpages'               => 'Узун арыннар',
 'protectedpages'          => 'Камгалаган арыннар',
-'listusers'               => 'Ажыглакчы даңзызы',
-'newpages'                => 'Чаа Арыннар',
+'listusers'               => 'Ажыглакчылар даңзызы',
+'newpages'                => 'Чаа арыннар',
 'newpages-username'       => 'Ажыглакчының ады:',
 'ancientpages'            => 'Эң эрги арыннар',
-'move'                    => 'Шимчээр',
-'movethispage'            => 'Бо арынны шимчээр',
+'move'                    => 'Шимчээри',
+'movethispage'            => 'Бо арынны шимчээри',
 
 # Book sources
-'booksources-go' => 'Чоруур',
+'booksources-go' => 'Күүcедири',
 
 # Special:Log
 'specialloguserlabel'  => 'Ажыглакчы:',
 'speciallogtitlelabel' => 'Ат:',
+'log'                  => 'Журналдар',
 
 # Special:AllPages
 'allpages'       => 'Шупту арыннар',
 'nextpage'       => 'Соонда арын ($1)',
 'prevpage'       => 'Бүрүнгү арын ($1)',
-'allarticles'    => 'Шупту чүүлдер',
+'allarticles'    => 'Шупту арыннар',
 'allpagesprev'   => 'Пертинде',
 'allpagesnext'   => 'Соонда',
-'allpagessubmit' => 'Чоруур',
+'allpagessubmit' => 'Күүcедири',
 
 # Special:Categories
 'categories' => 'Бөлүктер',
 
 # Special:ListUsers
-'listusers-submit' => 'Көргүзер',
+'listusers-submit' => 'Көргүзери',
 
 # E-mail user
-'emailuser'       => 'Бо ажыглакчыга э-чагааны чорудаар',
+'emailuser'       => 'Бо ажыглакчыга э-чагааны чорудаары',
 'defemailsubject' => '{{grammar:ablative|{{SITENAME}}}} э-чагаа',
-'emailfrom'       => 'Кайыын',
-'emailto'         => 'Каяа',
-'emailsubject'    => 'Кол сөс',
-'emailmessage'    => 'Чагаа',
-'emailsend'       => 'Чорудар',
+'emailfrom'       => 'Кымдан:',
+'emailto'         => 'Кымга:',
+'emailsubject'    => 'Кол сөс:',
+'emailmessage'    => 'Чагаа:',
+'emailsend'       => 'Чорудары',
 
 # Watchlist
 'watchlist'       => 'Мээң хайгаарылга даңзызым',
 'mywatchlist'     => 'Мээң хайгаарылга даңзызым',
 'nowatchlist'     => 'Чүү-даа силерниң хайгаарылга даңзызыда чок.',
 'watchnologin'    => 'Кирбес',
-'watch'           => 'Хайгаараар',
-'watchthispage'   => 'Бо арынны хайгаараар',
+'watch'           => 'Хайгаараары',
+'watchthispage'   => 'Бо арынны хайгаараары',
 'unwatch'         => 'Хайгааравас',
 'unwatchthispage' => 'Бо арынны хайгаарабас',
 
@@ -538,41 +611,52 @@ $1',
 'enotif_anon_editor'           => 'ат эвес ажыглакчы $1',
 
 # Delete
-'deletepage'     => 'Арынны ап каар',
-'exblank'        => 'Арын куруг турган',
-'actioncomplete' => 'Ажыл доосту',
-'deletedarticle' => '"[[$1]]" деп арынны ап каан',
+'deletepage'            => 'Арынны ап каары',
+'exblank'               => 'Арын куруг турган',
+'actioncomplete'        => 'Ажыл доосту',
+'deletedarticle'        => '"[[$1]]" деп арынны ап каан',
+'deletecomment'         => 'Чылдагаан:',
+'deleteotherreason'     => 'Өске/немелде чылдагаан:',
+'deletereasonotherlist' => 'Өске чылдагаан',
 
 # Protect
-'protectcomment'      => 'Комментарий:',
-'protect-default'     => '(ниити)',
-'protect-level-sysop' => 'Чүгле сисоплар',
-'pagesize'            => '(байттар)',
+'protectlogpage'         => 'Камгалал кырында журнал',
+'protectcomment'         => 'Чылдагаан:',
+'protect-default'        => '',
+'protect-level-sysop'    => 'Чүгле эргелекчылар',
+'protect-otherreason'    => 'Өске/немелде чылдагаан:',
+'protect-otherreason-op' => 'Өске чылдагаан',
+'restriction-type'       => 'Чөпшээрел:',
+'pagesize'               => '(байттар)',
 
 # Restrictions (nouns)
-'restriction-edit' => 'Өскертир',
-'restriction-move' => 'Шимчээр',
+'restriction-edit' => 'Өскертири',
+'restriction-move' => 'Шимчээри',
 
 # Undelete
 'undeletebtn'            => 'Диргисир',
-'undeletecomment'        => 'Комментарий:',
+'undeletecomment'        => 'Чылдагаан:',
 'undelete-search-submit' => 'Дилээр',
 
 # Namespace form on various pages
 'blanknamespace' => '(Кол)',
 
 # Contributions
-'contributions' => 'Ажыглакчыниң деткимчемнери',
-'mycontris'     => 'Мээң деткимчемнерим',
+'contributions' => 'Ажыглакчыниң немелделери',
+'mycontris'     => 'Мээң немелделерим',
 'uctop'         => '(баш)',
 
-'sp-contributions-newbies'  => 'Чүгле чаа кирерилерниң деткимчемнерин көргүзер',
+'sp-contributions-newbies'  => 'Чүгле чаа кирерилерниң немелделерин көргүзерн',
+'sp-contributions-logs'     => 'журналдар',
 'sp-contributions-username' => 'ИП-адрес азы ажыглачының ады:',
-'sp-contributions-submit'   => 'Дилээр',
+'sp-contributions-submit'   => 'Дилээри',
 
 # What links here
-'whatlinkshere'       => 'Pages that link here',
-'whatlinkshere-links' => '← холбаалар',
+'whatlinkshere'           => 'Pages that link here',
+'whatlinkshere-page'      => 'Арын:',
+'isimage'                 => 'чуруктуң холбаазы',
+'whatlinkshere-links'     => '← холбаалар',
+'whatlinkshere-hidelinks' => 'холбааларны $1',
 
 # Block/unblock
 'ipaddress'                => 'ИП-адрес',
@@ -580,13 +664,14 @@ $1',
 'ipbreason'                => 'Чылдагаан:',
 'ipbreasonotherlist'       => 'Өске чылдагаан',
 'ipbother'                 => 'Өске шак:',
+'ipboptions'               => '2 шак:2 hours,1 хүн:1 day,3 хүн:3 days,1 чеди-хонук:1 week,2 чеди-хонук:2 weeks,1 ай:1 month,3 ай:3 months,6 ай:6 months,1 чыл:1 year,төнмес-батпас:infinite', # display1:time1,display2:time2,...
 'ipbotheroption'           => 'өске',
 'ipbotherreason'           => 'Өске/немелде чылдагаан:',
 'badipaddress'             => 'Багай ИП-адрес',
 'ipblocklist-username'     => 'Ажыглакчының ады азы ИП-адрес:',
 'ipblocklist-submit'       => 'Дилээр',
 'infiniteblock'            => 'кезээ-мөңгеде',
-'contribslink'             => 'деткимчемнер',
+'contribslink'             => 'немелделер',
 'block-log-flags-anononly' => 'чүгле ат эвес ажыглакчылар',
 
 # Developer tools
@@ -597,9 +682,10 @@ $1',
 
 # Move page
 'move-page-legend' => 'Арынны шимчээр',
-'movearticle'      => 'Арынны шимчээр:',
-'move-watch'       => 'Бо арынны хайгаараар',
-'movepagebtn'      => 'Арынны шимчээр',
+'movearticle'      => 'Бо арынны шимчээри:',
+'newtitle'         => 'Чаа ат:',
+'move-watch'       => 'Бо арынны хайгаараары',
+'movepagebtn'      => 'Арынны шимчээри',
 'movereason'       => 'Чылдагаан:',
 'delete_and_move'  => 'Ап каар болгаш шимчээр',
 
@@ -613,38 +699,39 @@ $1',
 'import-comment' => 'Комментарий:',
 
 # Import log
-'import-logentry-upload-detail' => '$1 үндүрери(лер)',
+'import-logentry-upload-detail' => '$1 {{PLURAL:$1|үндүрери}}',
 
 # Tooltip help for the actions
-'tooltip-pt-userpage'       => 'Мээң ажыглакчы арыным',
-'tooltip-pt-mytalk'         => 'Мээң чугаалажыр арыным',
-'tooltip-pt-mycontris'      => 'Мээң деткимчемнерим даңзызы',
-'tooltip-pt-logout'         => 'Үнер',
-'tooltip-ca-talk'           => 'Допчу арыны дугайында чыгаалажыры',
-'tooltip-ca-protect'        => 'Бо арынны камгалаар',
-'tooltip-ca-delete'         => 'Бо арынны ап каар',
-'tooltip-ca-move'           => 'Бо арынны шимчээр',
-'tooltip-search'            => '{{grammar:locative|{{SITENAME}}}} дилээр',
+'tooltip-pt-userpage'       => 'Силерниң ажыглакчы арыныңнар',
+'tooltip-pt-mytalk'         => 'Силерниң чугаалажыр арныңар',
+'tooltip-pt-mycontris'      => 'Силерниң немелделериңерның даңзызы',
+'tooltip-pt-logout'         => 'Үнери',
+'tooltip-ca-talk'           => 'Бо арынның допчузузу дугайында чыгаалажыры',
+'tooltip-ca-protect'        => 'Бо арынны камгалаары',
+'tooltip-ca-delete'         => 'Бо арынны ап каары',
+'tooltip-ca-move'           => 'Бо арынны шимчээри',
+'tooltip-search'            => '{{grammar:locative|{{SITENAME}}}} дилээри',
 'tooltip-p-logo'            => 'Кол Арын',
-'tooltip-n-mainpage'        => 'Кол Арынны баар',
+'tooltip-n-mainpage'        => 'Кол Арынны баары',
 'tooltip-n-recentchanges'   => 'Викиниң дээм чагы өскерлиишкиннери',
 'tooltip-feed-rss'          => 'Бо арының РСС медээ агымы',
 'tooltip-feed-atom'         => 'Бо арының Атом медээ агымы',
-'tooltip-t-emailuser'       => 'Бо ажыглакчыга э-чагааны чорудаар',
-'tooltip-t-upload'          => 'Файлдар киирер',
+'tooltip-t-contributions'   => 'Бо ажыглакчының немелделериниң даңзазын көөрү.',
+'tooltip-t-emailuser'       => 'Бо ажыглакчыга э-чагааны чорудаары',
+'tooltip-t-upload'          => 'Файлдарны салыры',
 'tooltip-t-specialpages'    => 'Шупту тускай арыннар даңзызы',
-'tooltip-ca-nstab-main'     => 'Допчы арынын көөр',
-'tooltip-ca-nstab-user'     => 'Ажыглакчы арынын көөр',
-'tooltip-ca-nstab-media'    => 'Медиа арынын көөр',
-'tooltip-ca-nstab-project'  => 'Проект арынын көөр',
-'tooltip-ca-nstab-image'    => 'Файл арынын көөр',
-'tooltip-ca-nstab-template' => 'Хээни көөр',
-'tooltip-ca-nstab-help'     => 'Дуза арынын көөр',
-'tooltip-ca-nstab-category' => 'Бөлүк арынын көөр',
-'tooltip-save'              => 'Силерниң өскерлиишкиннериңерни шыгжаар',
+'tooltip-ca-nstab-main'     => 'Допчы арынын көөрү',
+'tooltip-ca-nstab-user'     => 'Ажыглакчының арынын көөрү',
+'tooltip-ca-nstab-media'    => 'Медиа арынын көөрү',
+'tooltip-ca-nstab-project'  => 'Проект арнызын көөрү',
+'tooltip-ca-nstab-image'    => 'Файлдың арынын көөрү',
+'tooltip-ca-nstab-template' => 'Хээни көөрү',
+'tooltip-ca-nstab-help'     => 'Дуза арынын көөрү',
+'tooltip-ca-nstab-category' => 'Бөлүктүң арынын көөрү',
+'tooltip-save'              => 'Силерниң өскерлиишкиннериңерни шыгжаары',
 
 # Attribution
-'anonymous' => '{{grammar:genitive|{{SITENAME}}}} ат эвес ажыглакчызы(лары)',
+'anonymous' => '{{grammar:genitive|{{SITENAME}}}} ат эвес {{PLURAL:$1|ажыглакчызы|ажыглакчылары}}',
 
 # Skin names
 'skinname-standard'    => 'Classic',
@@ -658,12 +745,15 @@ $1',
 'filedelete-missing' => '"$1" деп файл чок, ынчангаш ол ап калдынмас.',
 
 # Browsing diffs
-'previousdiff' => '← Бүрүнгү ылгал',
-'nextdiff'     => 'Соонда ылгал →',
+'previousdiff' => '← Бүрүнгү үндүрери',
+'nextdiff'     => 'Соонда үндүрери →',
+
+# Media information
+'widthheightpage' => '$1x$2, $3 {{PLURAL:$3|арын}}',
 
 # Special:NewFiles
 'showhidebots' => '(боцду $1)',
-'noimages'     => 'Чуруклар чок.',
+'noimages'     => '',
 'ilsubmit'     => 'Дилээр',
 
 # EXIF tags
@@ -686,34 +776,47 @@ $1',
 # Multipage image navigation
 'imgmultipageprev' => '← бүрүнгү арын',
 'imgmultipagenext' => 'соонда арын →',
-'imgmultigo'       => 'Чоруур',
+'imgmultigo'       => '',
 
 # Table pager
 'table_pager_next'         => 'Соонда арын',
 'table_pager_prev'         => 'Бүрүнгү арын',
 'table_pager_first'        => 'Бирги арын',
 'table_pager_last'         => 'Сөөлгү арын',
-'table_pager_limit_submit' => 'Чоруур',
+'table_pager_limit_submit' => 'Күүcедири',
 'table_pager_empty'        => 'Түңнеллер чок',
 
 # Auto-summaries
-'autosumm-new' => 'Чаа арын: $1',
+'autosumm-new' => '',
 
 # Watchlist editor
-'watchlistedit-normal-title'  => 'Хайгаарылга даңзын өскертир',
-'watchlistedit-normal-submit' => 'Адарны ап каар',
+'watchlistedit-normal-title'  => 'Хайгаарылга даңзызын өскертири',
+'watchlistedit-normal-submit' => 'Адарны ап каары',
 'watchlistedit-raw-title'     => 'Чиг хайгаарылга даңзын өскертир',
 'watchlistedit-raw-legend'    => 'Чиг хайгаарылга даңзын өскертир',
 'watchlistedit-raw-titles'    => 'Адар:',
 
 # Watchlist editing tools
-'watchlisttools-edit' => 'Хайгаарылга даңзын көөр болгаш өскертир',
-'watchlisttools-raw'  => 'Чиг хайгаарылга даңзын өскертир',
+'watchlisttools-edit' => 'Хайгаарылга даңзызын көөрү болгаш өскертири',
+'watchlisttools-raw'  => 'Чиг хайгаарылга даңзызын өскертири',
 
 # Special:Version
 'version' => 'Үндүрери', # Not used as normal message but as header for the special page itself
 
+# Special:FilePath
+'filepath-page'   => 'Файл:',
+'filepath-submit' => 'Күүcедири',
+
+# Special:FileDuplicateSearch
+'fileduplicatesearch-filename' => 'Файлдың ады:',
+
 # Special:SpecialPages
 'specialpages' => 'Тускай арыннар',
 
+# Special:BlankPage
+'blankpage' => 'Куруг арын',
+
+# Special:Tags
+'tags-edit' => 'өскертири',
+
 );
