@@ -9,21 +9,54 @@
  * are evaluated separately, so blocks need to be input without a line break.
  * Fatal errors such as use of undeclared functions can kill the shell.
  *
- * To get decent line editing behavior, you should compile PHP with support 
+ * To get decent line editing behavior, you should compile PHP with support
  * for GNU readline (pass --with-readline to configure).
  *
- * @package MediaWiki
- * @subpackage Maintenance
+ * @file
+ * @ingroup Maintenance
  */
 
-$wgForceLoadBalancing = (getenv('MW_BALANCE') ? true : false);
+$wgUseNormalUser = (bool)getenv('MW_WIKIUSER');
+
+$optionsWithArgs = array( 'd' );
 
 /** */
 require_once( "commandLine.inc" );
 
-$line = readconsole( "> " );
+if ( isset( $options['d'] ) ) {
+	$d = $options['d'];
+	if ( $d > 0 ) {
+		$wgDebugLogFile = '/dev/stdout';
+	}
+	if ( $d > 1 ) {
+		$lb = wfGetLB();
+		foreach ( $lb->mServers as $i => $server ) {
+			$lb->mServers[$i]['flags'] |= DBO_DEBUG;
+		}
+	}
+	if ( $d > 2 ) {
+		$wgDebugFunctionEntry = true;
+	}
+}
 
-while ( $line !== false ) {
+if ( function_exists( 'readline_add_history' ) 
+	&& function_exists( 'posix_isatty' ) && posix_isatty( 0 /*STDIN*/ ) ) 
+{
+	$useReadline = true;
+} else {
+	$useReadline = false;
+}
+
+if ( $useReadline ) {
+	$historyFile = "{$_ENV['HOME']}/.mweval_history";
+	readline_read_history( $historyFile );
+}
+
+while ( ( $line = readconsole( '> ' ) ) !== false ) {
+	if ( $useReadline ) {
+		readline_add_history( $line );
+		readline_write_history( $historyFile );
+	}
 	$val = eval( $line . ";" );
 	if( is_null( $val ) ) {
 		echo "\n";
@@ -32,12 +65,8 @@ while ( $line !== false ) {
 	} else {
 		var_dump( $val );
 	}
-	if ( function_exists( "readline_add_history" ) ) {
-		readline_add_history( $line );
-	}
-	$line = readconsole( "> " );
 }
 
 print "\n";
 
-?>
+
