@@ -1,5 +1,12 @@
 <?php
-/* $Id: mctest.php 16738 2006-10-02 17:04:13Z brion $ */
+/**
+ * This script makes several 'set', 'incr' and 'get' requests on every
+ * memcached server and shows a report.
+ *
+ * $Id: mctest.php 37886 2008-07-21 17:06:35Z greg $
+ * @file
+ * @ingroup Maintenance
+ */
 
 $optionsWithArgs = array( 'i' );
 
@@ -16,8 +23,6 @@ function microtime_float()
 
 if ( isset( $args[0] ) ) {
 	$wgMemCachedServers = array( $args[0] );
-} else {
-	$wgMemCachedServers[] = 'localhost';
 }
 if ( isset( $options['i'] ) ) {
 	$iterations = $options['i'];
@@ -57,4 +62,4 @@ foreach ( $wgMemCachedServers as $server ) {
 }
 
 
-?>
+
