@@ -4,12 +4,14 @@
  * Maintenance script to show the cached statistics.
  * Give out the same output as [[Special:Statistics]]
  *
+ * @file
+ * @ingroup Maintenance
  * @author Ashar Voultoiz <hashar@altern.org>
  * Based on initStats.php by:
  * @author Brion Vibber
  * @author Rob Church <robchur@gmail.com>
  *
- * @licence GNU General Public License 2.0 or later
+ * @license GNU General Public License 2.0 or later
  */
 
 require_once( 'commandLine.inc' );
@@ -28,7 +30,7 @@ $fields = array(
 );
 
 // Get cached stats from slave database
-$dbr =& wfGetDB( DB_SLAVE );
+$dbr = wfGetDB( DB_SLAVE );
 $fname = 'showStats';
 $stats = $dbr->selectRow( 'site_stats', '*', '' );
 
@@ -43,4 +45,4 @@ foreach( $fields as $field => $desc ) {
 foreach( $fields as $field => $desc ) {
 	printf( "%-{$max_length_desc}s: %{$max_length_value}d\n", $desc, $stats->$field );
 }
-?>
+
